/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>

#include <stdio.h>
#include <assert.h>
#include <string>
#include <sstream>
#include <iostream>
#include <sstream>
#include <algorithm>
#include <regex>

#include "epparser.h"
#include "generator/pygen.h"
#include "generator/closure.h"
#include "generator/eudplibGlobals.h"
#include "parser.h"
#include "tokenAdapter.h"
#include "parserUtilities.h"

struct ParserStruct {
   PyGenerator gen;
    ClosureManager closure;
};

int currentTokenizingLine;
int lambdaIndex;
std::string currentFunction;
std::string currentModule;
std::string currentFile;
bool PARSER_DEBUG = false;
bool MAP_DEBUG = false;

/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    ParseTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is ParseTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ParseARG_SDECL     A static variable declaration for the %extra_argument
**    ParseARG_PDECL     A parameter declaration for the %extra_argument
**    ParseARG_STORE     Code to store %extra_argument into yypParser
**    ParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned char
#define YYNOCODE 178
#define YYACTIONTYPE unsigned short int
#define ParseTOKENTYPE Token*
typedef union {
  int yyinit;
  ParseTOKENTYPE yy0;
  int yy355;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define ParseARG_SDECL  ParserStruct* ps ;
#define ParseARG_PDECL , ParserStruct* ps 
#define ParseARG_FETCH  ParserStruct* ps  = yypParser->ps 
#define ParseARG_STORE yypParser->ps  = ps 
#define YYNSTATE 480
#define YYNRULE 242
#define YYERRORSYMBOL 86
#define YYERRSYMDT yy355
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (14632)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   519,  273,  519,  519,  519,  519,  519,  519,  519,  519,
 /*    10 */   519,  519,  519,  519,  519,  519,  519,  519,  519,  519,
 /*    20 */   519,  519,  519,  519,  519,  268,  519,  519,  519,  519,
 /*    30 */   519,  519,  519,  295,  519,  519,  519,  519,  519,  122,
 /*    40 */   519,  519,  519,  519,  468,  519,  519,    2,  324,  519,
 /*    50 */   519,  519,  519,  519,  519,  519,  519,  519,  519,  519,
 /*    60 */   519,  236,  120,   12,  374,  373,  390,   39,   14,  330,
 /*    70 */    34,  519,  519,  519,  519,  519,  519,  519,  519,  519,
 /*    80 */   519,  519,  519,  519,  519,  519,  520,  634,  520,  520,
 /*    90 */   520,  520,  520,  520,  520,  520,  520,  520,  520,  520,
 /*   100 */   520,  520,  520,  520,  520,  520,  520,  520,  520,  520,
 /*   110 */   520,  267,  520,  520,  520,  520,  520,  520,  520,  295,
 /*   120 */   520,  520,  520,  520,  520,  295,  520,  520,  520,  520,
 /*   130 */   495,  520,  520,  495,  266,  520,  520,  520,  520,  520,
 /*   140 */   520,  520,  520,  520,  520,  520,  520,  236,  265,   12,
 /*   150 */   374,  373,  391,  236,  343,   12,  372,  520,  520,  520,
 /*   160 */   520,  520,  520,  520,  520,  520,  520,  520,  520,  520,
 /*   170 */   520,  520,  522,  548,  522,  522,  522,  522,  522,  522,
 /*   180 */   522,  522,  522,  522,  522,  522,  522,  522,  522,  522,
 /*   190 */   522,  522,  522,  522,  522,  522,  522,  472,  522,  522,
 /*   200 */   522,  522,  522,  522,  522,  295,  522,  522,  522,  522,
 /*   210 */   522,  463,  522,  522,  522,  522,  379,  522,  522,  342,
 /*   220 */   503,  522,  522,  522,  522,  522,  522,  522,  522,  522,
 /*   230 */   522,  522,  522,  236,  510,   12,  374,  373,  392,  510,
 /*   240 */   510,  723,   18,  522,  522,  522,  522,  522,  522,  522,
 /*   250 */   522,  522,  522,  522,  522,  522,  522,  522,  523,  447,
 /*   260 */   523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
 /*   270 */   523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
 /*   280 */   523,  523,  523,  340,  523,  523,  523,  523,  523,  523,
 /*   290 */   523,  295,  523,  523,  523,  523,  523,  446,  523,  523,
 /*   300 */   523,  523,  496,  523,  523,  496,  469,  523,  523,  523,
 /*   310 */   523,  523,  523,  523,  523,  523,  523,  523,  523,  236,
 /*   320 */   511,   12,  374,  373,  430,  511,  511,  263,  123,  523,
 /*   330 */   523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
 /*   340 */   523,  523,  523,  523,  524,  549,  524,  524,  524,  524,
 /*   350 */   524,  524,  524,  524,  524,  524,  524,  524,  524,  524,
 /*   360 */   524,  524,  524,  524,  524,  524,  524,  524,  524,  132,
 /*   370 */   524,  524,  524,  524,  524,  524,  524,  295,  524,  524,
 /*   380 */   524,  524,  524,  549,  524,  524,  524,  524,  120,  524,
 /*   390 */   524,  465,  464,  524,  524,  524,  524,  524,  524,  524,
 /*   400 */   524,  524,  524,  524,  524,  236,  512,   12,  374,  373,
 /*   410 */   433,  512,  512,  635,  234,  524,  524,  524,  524,  524,
 /*   420 */   524,  524,  524,  524,  524,  524,  524,  524,  524,  524,
 /*   430 */   527,  463,  527,  527,  527,  527,  527,  527,  527,  527,
 /*   440 */   527,  527,  527,  527,  527,  527,  527,  527,  527,  527,
 /*   450 */   527,  527,  527,  527,  527,  235,  527,  527,  527,  527,
 /*   460 */   527,  527,  527,  295,  527,  527,  527,  527,  527,  574,
 /*   470 */   527,  527,  527,  527,  120,  527,  527,  122,  176,  527,
 /*   480 */   527,  527,  527,  527,  527,  527,  527,  527,  527,  527,
 /*   490 */   527,  236,  514,   12,  374,  373,  431,  514,  514,  637,
 /*   500 */   574,  527,  527,  527,  527,  527,  527,  527,  527,  527,
 /*   510 */   527,  527,  527,  527,  527,  527,  528,  172,  528,  528,
 /*   520 */   528,  528,  528,  528,  528,  528,  528,  528,  528,  528,
 /*   530 */   528,  528,  528,  528,  528,  528,  528,  528,  528,  528,
 /*   540 */   528,  169,  528,  528,  528,  528,  528,  528,  528,  295,
 /*   550 */   528,  528,  528,  528,  528,   35,  528,  528,  528,  528,
 /*   560 */   694,  528,  528,  168,  167,  528,  528,  528,  528,  528,
 /*   570 */   528,  528,  528,  528,  528,  528,  528,  236,  515,   12,
 /*   580 */   374,  373,  399,  515,  515,  694,  577,  528,  528,  528,
 /*   590 */   528,  528,  528,  528,  528,  528,  528,  528,  528,  528,
 /*   600 */   528,  528,  529,  166,  529,  529,  529,  529,  529,  529,
 /*   610 */   529,  529,  529,  529,  529,  529,  529,  529,  529,  529,
 /*   620 */   529,  529,  529,  529,  529,  529,  529,  165,  529,  529,
 /*   630 */   529,  529,  529,  529,  529,  295,  529,  529,  529,  529,
 /*   640 */   529,  575,  529,  529,  529,  529,  695,  529,  529,  164,
 /*   650 */   156,  529,  529,  529,  529,  529,  529,  529,  529,  529,
 /*   660 */   529,  529,  529,  236,  387,   12,  374,  373,  397,  126,
 /*   670 */   384,  695,  575,  529,  529,  529,  529,  529,  529,  529,
 /*   680 */   529,  529,  529,  529,  529,  529,  529,  529,  530,  155,
 /*   690 */   530,  530,  530,  530,  530,  530,  530,  530,  530,  530,
 /*   700 */   530,  530,  530,  530,  530,  530,  530,  530,  530,  530,
 /*   710 */   530,  530,  530,  154,  530,  530,  530,  530,  530,  530,
 /*   720 */   530,  295,  530,  530,  530,  530,  530,  239,  530,  530,
 /*   730 */   530,  530,  381,  530,  530,  345,  255,  530,  530,  530,
 /*   740 */   530,  530,  530,  530,  530,  530,  530,  530,  530,  236,
 /*   750 */   696,   12,  374,  373,  383,  236,   46,   12,  426,  530,
 /*   760 */   530,  530,  530,  530,  530,  530,  530,  530,  530,  530,
 /*   770 */   530,  530,  530,  530,  531,  696,  531,  531,  531,  531,
 /*   780 */   531,  531,  531,  531,  531,  531,  531,  531,  531,  531,
 /*   790 */   531,  531,  531,  531,  531,  531,  531,  531,  531,  140,
 /*   800 */   531,  531,  531,  531,  531,  531,  531,  295,  531,  531,
 /*   810 */   531,  531,  531,  258,  531,  531,  531,  531,  375,  531,
 /*   820 */   531,  328,   56,  531,  531,  531,  531,  531,  531,  531,
 /*   830 */   531,  531,  531,  531,  531,  236,  697,   12,  374,  373,
 /*   840 */   382,  420,  419,    4,  240,  531,  531,  531,  531,  531,
 /*   850 */   531,  531,  531,  531,  531,  531,  531,  531,  531,  531,
 /*   860 */   532,  697,  532,  532,  532,  532,  532,  532,  532,  532,
 /*   870 */   532,  532,  532,  532,  532,  532,  532,  532,  532,  532,
 /*   880 */   532,  532,  532,  532,  532,   92,  532,  532,  532,  532,
 /*   890 */   532,  532,  532,  681,  532,  532,  532,  532,  532,  120,
 /*   900 */   532,  532,  532,  532,   20,  532,  532,   91,   90,  532,
 /*   910 */   532,  532,  532,  532,  532,  532,  532,  532,  532,  532,
 /*   920 */   532,   39,   14,  331,   89,   16,  395,  681,  681,  699,
 /*   930 */   675,  532,  532,  532,  532,  532,  532,  532,  532,  532,
 /*   940 */   532,  532,  532,  532,  532,  532,  533,   88,  533,  533,
 /*   950 */   533,  533,  533,  533,  533,  533,  533,  533,  533,  533,
 /*   960 */   533,  533,  533,  533,  533,  533,  533,  533,  533,  533,
 /*   970 */   533,   87,  533,  533,  533,  533,  533,  533,  533,  319,
 /*   980 */   533,  533,  533,  533,  533,  647,  533,  533,  533,  533,
 /*   990 */   321,  533,  533,   50,  554,  533,  533,  533,  533,  533,
 /*  1000 */   533,  533,  533,  533,  533,  533,  533,  236,  698,   12,
 /*  1010 */   647,  501,  501,  208,  366,  501,  647,  533,  533,  533,
 /*  1020 */   533,  533,  533,  533,  533,  533,  533,  533,  533,  533,
 /*  1030 */   533,  533,  534,  698,  534,  534,  534,  534,  534,  534,
 /*  1040 */   534,  534,  534,  534,  534,  534,  534,  534,  534,  534,
 /*  1050 */   534,  534,  534,  534,  534,  534,  534,   49,  534,  534,
 /*  1060 */   534,  534,  534,  534,  534,  319,  534,  534,  534,  534,
 /*  1070 */   534,  649,  534,  534,  534,  534,  207,  534,  534,   29,
 /*  1080 */    28,  534,  534,  534,  534,  534,  534,  534,  534,  534,
 /*  1090 */   534,  534,  534,  236,  120,   12,  649,  474,  504,  202,
 /*  1100 */   333,  473,  649,  534,  534,  534,  534,  534,  534,  534,
 /*  1110 */   534,  534,  534,  534,  534,  534,  534,  534,  535,  563,
 /*  1120 */   535,  535,  535,  535,  535,  535,  535,  535,  535,  535,
 /*  1130 */   535,  535,  535,  535,  535,  535,  535,  535,  535,  535,
 /*  1140 */   535,  535,  535,   27,  535,  535,  535,  535,  535,  535,
 /*  1150 */   535,  319,  535,  535,  535,  535,  535,  120,  535,  535,
 /*  1160 */   535,  535,  201,  535,  535,  200,  199,  535,  535,  535,
 /*  1170 */   535,  535,  535,  535,  535,  535,  535,  535,  535,  236,
 /*  1180 */   120,   12,  645,  502,  502,  127,  332,  502,  645,  535,
 /*  1190 */   535,  535,  535,  535,  535,  535,  535,  535,  535,  535,
 /*  1200 */   535,  535,  535,  535,  536,  636,  536,  536,  536,  536,
 /*  1210 */   536,  536,  536,  536,  536,  536,  536,  536,  536,  536,
 /*  1220 */   536,  536,  536,  536,  536,  536,  536,  536,  536,   55,
 /*  1230 */   536,  536,  536,  536,  536,  536,  536,  120,  536,  536,
 /*  1240 */   536,  536,  536,  120,  536,  536,  536,  536,  120,  536,
 /*  1250 */   536,   47,  337,  536,  536,  536,  536,  536,  536,  536,
 /*  1260 */   536,  536,  536,  536,  536,  497,  497,  587,  676,  497,
 /*  1270 */   471,  262,  242,  638,  470,  536,  536,  536,  536,  536,
 /*  1280 */   536,  536,  536,  536,  536,  536,  536,  536,  536,  536,
 /*  1290 */   537,   11,  537,  537,  537,  537,  537,  537,  537,  537,
 /*  1300 */   537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
 /*  1310 */   537,  537,  537,  537,  537,  666,  537,  537,  537,  537,
 /*  1320 */   537,  537,  537,  682,  537,  537,  537,  537,  537,  701,
 /*  1330 */   537,  537,  537,  537,  339,  537,  537,   60,    9,  537,
 /*  1340 */   537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
 /*  1350 */   537,  498,  498,  669,   44,  498,   45,  682,  682,  323,
 /*  1360 */   701,  537,  537,  537,  537,  537,  537,  537,  537,  537,
 /*  1370 */   537,  537,  537,  537,  537,  537,  538,   59,  538,  538,
 /*  1380 */   538,  538,  538,  538,  538,  538,  538,  538,  538,  538,
 /*  1390 */   538,  538,  538,  538,  538,  538,  538,  538,  538,  538,
 /*  1400 */   538,    8,  538,  538,  538,  538,  538,  538,  538,  177,
 /*  1410 */   538,  538,  538,  538,  538,  294,  538,  538,  538,  538,
 /*  1420 */    41,  538,  538,   40,  415,  538,  538,  538,  538,  538,
 /*  1430 */   538,  538,  538,  538,  538,  538,  538,  236,  643,   12,
 /*  1440 */   643,   53,   36,  236,  426,   12,  148,  538,  538,  538,
 /*  1450 */   538,  538,  538,  538,  538,  538,  538,  538,  538,  538,
 /*  1460 */   538,  538,  539,  690,  539,  539,  539,  539,  539,  539,
 /*  1470 */   539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
 /*  1480 */   539,  539,  539,  539,  539,  539,  539,   58,  539,  539,
 /*  1490 */   539,  539,  539,  539,  539,  314,  539,  539,  539,  539,
 /*  1500 */   539,  194,  539,  539,  539,  539,    7,  539,  539,  277,
 /*  1510 */   317,  539,  539,  539,  539,  539,  539,  539,  539,  539,
 /*  1520 */   539,  539,  539,  236,  322,   12,  708,    6,  405,  236,
 /*  1530 */   710,   12,    5,  539,  539,  539,  539,  539,  539,  539,
 /*  1540 */   539,  539,  539,  539,  539,  539,  539,  539,  540,  323,
 /*  1550 */   540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
 /*  1560 */   540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
 /*  1570 */   540,  540,  540,  713,  540,  540,  540,  540,  540,  540,
 /*  1580 */   540,  278,  540,  540,  540,  540,  540,  313,  540,  540,
 /*  1590 */   540,  540,  714,  540,  540,  715,   26,  540,  540,  540,
 /*  1600 */   540,  540,  540,  540,  540,  540,  540,  540,  540,  236,
 /*  1610 */   427,   12,  299,   25,  298,  236,  245,   12,  686,  540,
 /*  1620 */   540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
 /*  1630 */   540,  540,  540,  540,  541,  323,  541,  541,  541,  541,
 /*  1640 */   541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
 /*  1650 */   541,  541,  541,  541,  541,  541,  541,  541,  541,  555,
 /*  1660 */   541,  541,  541,  541,  541,  541,  541,  228,  541,  541,
 /*  1670 */   541,  541,  541,  227,  541,  541,  541,  541,  131,  541,
 /*  1680 */   541,  197,  196,  541,  541,  541,  541,  541,  541,  541,
 /*  1690 */   541,  541,  541,  541,  541,  236,  388,   12,  195,  329,
 /*  1700 */   326,  236,  121,   12,  386,  541,  541,  541,  541,  541,
 /*  1710 */   541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
 /*  1720 */   542,  323,  542,  542,  542,  542,  542,  542,  542,  542,
 /*  1730 */   542,  542,  542,  542,  542,  542,  542,  542,  542,  542,
 /*  1740 */   542,  542,  542,  542,  542,  130,  542,  542,  542,  542,
 /*  1750 */   542,  542,  542,  226,  542,  542,  542,  542,  542,  225,
 /*  1760 */   542,  542,  542,  542,  257,  542,  542,  297,  296,  542,
 /*  1770 */   542,  542,  542,  542,  542,  542,  542,  542,  542,  542,
 /*  1780 */   542,  236,  349,   12,  173,  174,  376,  236,  377,   12,
 /*  1790 */   369,  542,  542,  542,  542,  542,  542,  542,  542,  542,
 /*  1800 */   542,  542,  542,  542,  542,  542,  543,  323,  543,  543,
 /*  1810 */   543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
 /*  1820 */   543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
 /*  1830 */   543,  338,  543,  543,  543,  543,  543,  543,  543,  224,
 /*  1840 */   543,  543,  543,  543,  543,  223,  543,  543,  543,  543,
 /*  1850 */   352,  543,  543,  347,  344,  543,  543,  543,  543,  543,
 /*  1860 */   543,  543,  543,  543,  543,  543,  543,  236,  429,   12,
 /*  1870 */   438,  436,  249,  236,  250,   12,  248,  543,  543,  543,
 /*  1880 */   543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
 /*  1890 */   543,  543,  544,  321,  544,  544,  544,  544,  544,  544,
 /*  1900 */   544,  544,  544,  544,  544,  544,  544,  544,  544,  544,
 /*  1910 */   544,  544,  544,  544,  544,  544,  544,  724,  544,  544,
 /*  1920 */   544,  544,  544,  544,  544,  222,  544,  544,  544,  544,
 /*  1930 */   544,  221,  544,  544,  544,  544,  724,  544,  544,  724,
 /*  1940 */   724,  544,  544,  544,  544,  544,  544,  544,  544,  544,
 /*  1950 */   544,  544,  544,  236,  724,   12,  724,  724,  724,  236,
 /*  1960 */   724,   12,  724,  544,  544,  544,  544,  544,  544,  544,
 /*  1970 */   544,  544,  544,  544,  544,  544,  544,  544,  662,  724,
 /*  1980 */   662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
 /*  1990 */   662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
 /*  2000 */   662,  662,  662,  724,  662,  662,  662,  662,  662,  662,
 /*  2010 */   662,  220,  662,  662,  662,  662,  662,  219,  662,  662,
 /*  2020 */   662,  662,  724,  662,  662,  724,  724,  662,  662,  662,
 /*  2030 */   662,  662,  662,  662,  662,  662,  662,  662,  662,  236,
 /*  2040 */   724,   12,  724,  724,  724,  236,  724,   12,  724,  662,
 /*  2050 */   662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
 /*  2060 */   662,  662,  662,  662,  664,  724,  664,  664,  664,  664,
 /*  2070 */   664,  664,  664,  664,  664,  664,  664,  664,  664,  664,
 /*  2080 */   664,  664,  664,  664,  664,  664,  664,  664,  664,  724,
 /*  2090 */   664,  664,  664,  664,  664,  664,  664,  218,  664,  664,
 /*  2100 */   664,  664,  664,  193,  664,  664,  664,  664,  724,  664,
 /*  2110 */   664,  724,  724,  664,  664,  664,  664,  664,  664,  664,
 /*  2120 */   664,  664,  664,  664,  664,  236,  724,   12,  724,  724,
 /*  2130 */   724,  236,  724,   12,  724,  664,  664,  664,  664,  664,
 /*  2140 */   664,  664,  664,  664,  664,  664,  664,  664,  664,  664,
 /*  2150 */   665,  724,  665,  665,  665,  665,  665,  665,  665,  665,
 /*  2160 */   665,  665,  665,  665,  665,  665,  665,  665,  665,  665,
 /*  2170 */   665,  665,  665,  665,  665,  724,  665,  665,  665,  665,
 /*  2180 */   665,  665,  665,  192,  665,  665,  665,  665,  665,  191,
 /*  2190 */   665,  665,  665,  665,  724,  665,  665,  724,  724,  665,
 /*  2200 */   665,  665,  665,  665,  665,  665,  665,  665,  665,  665,
 /*  2210 */   665,  236,  724,   12,  724,  724,  724,  236,  724,   12,
 /*  2220 */   724,  665,  665,  665,  665,  665,  665,  665,  665,  665,
 /*  2230 */   665,  665,  665,  665,  665,  665,  668,  724,  668,  668,
 /*  2240 */   668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
 /*  2250 */   668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
 /*  2260 */   668,  724,  668,  668,  668,  668,  668,  668,  668,  190,
 /*  2270 */   668,  668,  668,  668,  668,  189,  668,  668,  668,  668,
 /*  2280 */   724,  668,  668,  724,  724,  668,  668,  668,  668,  668,
 /*  2290 */   668,  668,  668,  668,  668,  668,  668,  236,  724,   12,
 /*  2300 */   724,  724,  724,  236,  724,   12,  724,  668,  668,  668,
 /*  2310 */   668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
 /*  2320 */   668,  668,  671,  724,  671,  671,  671,  671,  671,  671,
 /*  2330 */   671,  671,  671,  671,  671,  671,  671,  671,  671,  671,
 /*  2340 */   671,  671,  671,  671,  671,  671,  671,  724,  671,  671,
 /*  2350 */   671,  671,  671,  671,  671,  188,  671,  671,  671,  671,
 /*  2360 */   671,  217,  671,  671,  671,  671,  724,  671,  671,  724,
 /*  2370 */   724,  671,  671,  671,  671,  671,  671,  671,  671,  671,
 /*  2380 */   671,  671,  671,  236,  724,   12,  724,  724,  724,  236,
 /*  2390 */   724,   12,  724,  671,  671,  671,  671,  671,  671,  671,
 /*  2400 */   671,  671,  671,  671,  671,  671,  671,  671,  689,  724,
 /*  2410 */   689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
 /*  2420 */   689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
 /*  2430 */   689,  689,  689,  724,  689,  689,  689,  689,  689,  689,
 /*  2440 */   689,  216,  689,  689,  689,  689,  689,  187,  689,  689,
 /*  2450 */   689,  689,  724,  689,  689,  724,  724,  689,  689,  689,
 /*  2460 */   689,  689,  689,  689,  689,  689,  689,  689,  689,  236,
 /*  2470 */   724,   12,  724,  724,  724,  236,  724,   12,  724,  689,
 /*  2480 */   689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
 /*  2490 */   689,  689,  689,  689,  692,  724,  692,  692,  692,  692,
 /*  2500 */   692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
 /*  2510 */   692,  692,  692,  692,  692,  692,  692,  692,  692,  724,
 /*  2520 */   692,  692,  692,  692,  692,  692,  692,  312,  692,  692,
 /*  2530 */   692,  692,  692,  311,  692,  692,  692,  692,  724,  692,
 /*  2540 */   692,  724,  724,  692,  692,  692,  692,  692,  692,  692,
 /*  2550 */   692,  692,  692,  692,  692,  236,  724,   12,  724,  724,
 /*  2560 */   724,  236,  724,   12,  724,  692,  692,  692,  692,  692,
 /*  2570 */   692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
 /*  2580 */   709,  724,  709,  709,  709,  709,  709,  709,  709,  709,
 /*  2590 */   709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
 /*  2600 */   709,  709,  709,  709,  709,  724,  709,  709,  709,  709,
 /*  2610 */   709,  709,  709,  310,  709,  709,  709,  709,  709,  309,
 /*  2620 */   709,  709,  709,  709,  724,  709,  709,  724,  724,  709,
 /*  2630 */   709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
 /*  2640 */   709,  236,  724,   12,  724,  724,  724,  236,  724,   12,
 /*  2650 */   724,  709,  709,  709,  709,  709,  709,  709,  709,  709,
 /*  2660 */   709,  709,  709,  709,  709,  709,  712,  724,  712,  712,
 /*  2670 */   712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
 /*  2680 */   712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
 /*  2690 */   712,  724,  712,  712,  712,  712,  712,  712,  712,  308,
 /*  2700 */   712,  712,  712,  712,  712,  307,  712,  712,  712,  712,
 /*  2710 */   724,  712,  712,  724,  724,  712,  712,  712,  712,  712,
 /*  2720 */   712,  712,  712,  712,  712,  712,  712,  236,  724,   12,
 /*  2730 */   724,  724,  724,  236,  724,   12,  724,  712,  712,  712,
 /*  2740 */   712,  712,  712,  712,  712,  712,  712,  712,  712,  712,
 /*  2750 */   712,  712,  718,  724,  718,  718,  718,  718,  718,  718,
 /*  2760 */   718,  718,  718,  718,  718,  718,  718,  718,  718,  718,
 /*  2770 */   718,  718,  718,  718,  718,  718,  718,  724,  718,  718,
 /*  2780 */   718,  718,  718,  718,  718,  306,  718,  718,  718,  718,
 /*  2790 */   718,  206,  718,  718,  718,  718,  724,  718,  718,  724,
 /*  2800 */   724,  718,  718,  718,  718,  718,  718,  718,  718,  718,
 /*  2810 */   718,  718,  718,  236,  724,   12,  724,  724,  724,  236,
 /*  2820 */   724,   12,  724,  718,  718,  718,  718,  718,  718,  718,
 /*  2830 */   718,  718,  718,  718,  718,  718,  718,  718,  719,  724,
 /*  2840 */   719,  719,  719,  719,  719,  719,  719,  719,  719,  719,
 /*  2850 */   719,  719,  719,  719,  719,  719,  719,  719,  719,  719,
 /*  2860 */   719,  719,  719,  724,  719,  719,  719,  719,  719,  719,
 /*  2870 */   719,  205,  719,  719,  719,  719,  719,  204,  719,  719,
 /*  2880 */   719,  719,  724,  719,  719,  724,  724,  719,  719,  719,
 /*  2890 */   719,  719,  719,  719,  719,  719,  719,  719,  719,  236,
 /*  2900 */   724,   12,  724,  724,  724,  236,  724,   12,  724,  719,
 /*  2910 */   719,  719,  719,  719,  719,  719,  719,  719,  719,  719,
 /*  2920 */   719,  719,  719,  719,  674,  724,  674,  674,  674,  674,
 /*  2930 */   674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
 /*  2940 */   674,  674,  674,  674,  674,  674,  674,  674,  674,  724,
 /*  2950 */   674,  674,  674,  674,  674,  674,  674,  203,  674,  674,
 /*  2960 */   674,  674,  674,  186,  674,  674,  674,  674,  724,  674,
 /*  2970 */   674,  724,  724,  674,  674,  674,  674,  674,  674,  674,
 /*  2980 */   674,  674,  674,  674,  674,  236,  724,   12,  724,  724,
 /*  2990 */   724,  236,  724,   12,  724,  674,  674,  674,  674,  674,
 /*  3000 */   674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
 /*  3010 */   673,  724,  251,  673,  673,  673,  673,  673,  673,  673,
 /*  3020 */   673,  673,  673,  673,  673,  673,  673,  673,  673,  673,
 /*  3030 */   673,  673,  673,  673,  673,  724,  673,  673,  673,  673,
 /*  3040 */   673,  673,  673,  185,  673,  673,  673,  673,  673,  184,
 /*  3050 */   673,  673,  673,  673,  724,  673,  673,  724,  724,  673,
 /*  3060 */   673,  673,  673,  673,  673,  673,  673,  673,  673,  673,
 /*  3070 */   673,  236,  724,   12,  724,  724,  724,  236,  724,   12,
 /*  3080 */   724,  673,  673,  673,  673,  673,  673,  673,  673,  673,
 /*  3090 */   673,  673,  673,  673,  673,  673,  617,  617,  617,  617,
 /*  3100 */   617,  617,  617,  617,  617,  617,  617,  617,  104,  103,
 /*  3110 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  617,
 /*  3120 */    30,  117,  462,  617,  556,  617,  556,  617,  617,  617,
 /*  3130 */   183,  617,   48,  617,  633,  617,  617,  646,  617,  617,
 /*  3140 */   426,  724,  617,  617,  617,  617,  617,  617,  617,  617,
 /*  3150 */   617,  617,  617,  617,  724,  556,  724,  724,  236,  633,
 /*  3160 */    12,  724,  646,  724,  617,  617,  617,  617,  646,   38,
 /*  3170 */   617,  617,  617,  617,  617,  617,  617,  617,  617,  623,
 /*  3180 */   623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
 /*  3190 */   623,  104,  103,  105,  107,  106,  112,  111,  109,  110,
 /*  3200 */   108,  724,  623,   30,  117,  462,  623,  557,  623,  557,
 /*  3210 */   623,  623,  623,  467,  623,  648,  623,  394,  623,  623,
 /*  3220 */   702,  623,  623,  724,  724,  623,  623,  623,  623,  623,
 /*  3230 */   623,  623,  623,  623,  623,  623,  623,  724,  557,  724,
 /*  3240 */   648,  724,  323,  724,  724,  724,  648,  623,  623,  623,
 /*  3250 */   623,  702,  724,  623,  623,  623,  623,  623,  623,  623,
 /*  3260 */   623,  623,  624,  624,  624,  624,  624,  624,  624,  624,
 /*  3270 */   624,  624,  624,  624,  104,  103,  105,  107,  106,  112,
 /*  3280 */   111,  109,  110,  108,  724,  624,   30,  117,  462,  624,
 /*  3290 */   687,  624,  393,  624,  624,  624,  394,  624,  305,  624,
 /*  3300 */    37,  624,  624,   22,  624,  624,  724,  724,  624,  624,
 /*  3310 */   624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
 /*  3320 */   724,  323,  724,  724,  318,  396,  236,  632,   12,  724,
 /*  3330 */   624,  624,  624,  624,  705,  724,  624,  624,  624,  624,
 /*  3340 */   624,  624,  624,  624,  624,  625,  625,  625,  625,  625,
 /*  3350 */   625,  625,  625,  625,  625,  625,  625,  104,  103,  105,
 /*  3360 */   107,  106,  112,  111,  109,  110,  108,  724,  625,   30,
 /*  3370 */   117,  462,  625,  688,  625,  385,  625,  625,  625,  394,
 /*  3380 */   625,  182,  625,  724,  625,  625,  703,  625,  625,  724,
 /*  3390 */   724,  625,  625,  625,  625,  625,  625,  625,  625,  625,
 /*  3400 */   625,  625,  625,  724,  323,  724,  724,  318,  724,  236,
 /*  3410 */   724,   12,  724,  625,  625,  625,  625,  703,  724,  625,
 /*  3420 */   625,  625,  625,  625,  625,  625,  625,  625,  626,  626,
 /*  3430 */   626,  626,  626,  626,  626,  626,  626,  626,  626,  626,
 /*  3440 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /*  3450 */   724,  626,   30,  117,  462,  626,  724,  626,  181,  626,
 /*  3460 */   626,  626,  180,  626,  120,  626,  724,  626,  626,   55,
 /*  3470 */   626,  626,  724,  724,  626,  626,  626,  626,  626,  626,
 /*  3480 */   626,  626,  626,  626,  626,  626,  236,  724,   12,  724,
 /*  3490 */   236,  724,   12,  724,  724,  711,  626,  626,  626,  626,
 /*  3500 */   587,  724,  626,  626,  626,  626,  626,  626,  626,  626,
 /*  3510 */   626,  627,  627,  627,  627,  627,  627,  627,  627,  627,
 /*  3520 */   627,  627,  627,  104,  103,  105,  107,  106,  112,  111,
 /*  3530 */   109,  110,  108,  724,  627,   30,  117,  462,  627,  724,
 /*  3540 */   627,  179,  627,  627,  627,  178,  627,  724,  627,  724,
 /*  3550 */   627,  627,  724,  627,  627,  724,  724,  627,  627,  627,
 /*  3560 */   627,  627,  627,  627,  627,  627,  627,  627,  627,  236,
 /*  3570 */   724,   12,  724,  236,  724,   12,  724,  724,  724,  627,
 /*  3580 */   627,  627,  627,  724,  724,  627,  627,  627,  627,  627,
 /*  3590 */   627,  627,  627,  627,  628,  628,  628,  628,  628,  628,
 /*  3600 */   628,  628,  628,  628,  628,  628,  104,  103,  105,  107,
 /*  3610 */   106,  112,  111,  109,  110,  108,  724,  628,   30,  117,
 /*  3620 */   462,  628,  724,  628,  290,  628,  628,  628,  289,  628,
 /*  3630 */   724,  628,  724,  628,  628,  724,  628,  628,  724,  724,
 /*  3640 */   628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
 /*  3650 */   628,  628,  236,  724,   12,  724,  236,  724,   12,  724,
 /*  3660 */   724,  724,  628,  628,  628,  628,  724,  724,  628,  628,
 /*  3670 */   628,  628,  628,  628,  628,  628,  628,  612,  612,  612,
 /*  3680 */   612,  612,  612,  612,  612,  612,  612,  612,  612,  104,
 /*  3690 */   103,  105,  107,  106,  112,  111,  109,  110,  108,  724,
 /*  3700 */   612,   30,  117,  462,  612,  724,  612,  288,  612,  612,
 /*  3710 */   612,  287,  612,  724,  612,  724,  612,  612,  724,  612,
 /*  3720 */   612,  724,  724,  612,  612,  612,  612,  612,  612,  612,
 /*  3730 */   612,  612,  612,  612,  612,  236,  724,   12,  724,  236,
 /*  3740 */   724,   12,  724,  724,  724,  612,  612,  612,  612,  724,
 /*  3750 */   724,  612,  612,  612,  612,  612,  612,  612,  612,  612,
 /*  3760 */   613,  613,  613,  613,  613,  613,  613,  613,  613,  613,
 /*  3770 */   613,  613,  104,  103,  105,  107,  106,  112,  111,  109,
 /*  3780 */   110,  108,  724,  613,   30,  117,  462,  613,  724,  613,
 /*  3790 */   286,  613,  613,  613,  285,  613,  724,  613,  724,  613,
 /*  3800 */   613,  724,  613,  613,  724,  724,  613,  613,  613,  613,
 /*  3810 */   613,  613,  613,  613,  613,  613,  613,  613,  236,  724,
 /*  3820 */    12,  724,  236,  724,   12,  724,  724,  724,  613,  613,
 /*  3830 */   613,  613,  724,  724,  613,  613,  613,  613,  613,  613,
 /*  3840 */   613,  613,  613,  614,  614,  614,  614,  614,  614,  614,
 /*  3850 */   614,  614,  614,  614,  614,  104,  103,  105,  107,  106,
 /*  3860 */   112,  111,  109,  110,  108,  724,  614,   30,  117,  462,
 /*  3870 */   614,  724,  614,  284,  614,  614,  614,  283,  614,  724,
 /*  3880 */   614,  724,  614,  614,  724,  614,  614,  724,  724,  614,
 /*  3890 */   614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
 /*  3900 */   614,  236,  724,   12,  724,  236,  724,   12,  724,  724,
 /*  3910 */   724,  614,  614,  614,  614,  724,  724,  614,  614,  614,
 /*  3920 */   614,  614,  614,  614,  614,  614,  615,  615,  615,  615,
 /*  3930 */   615,  615,  615,  615,  615,  615,  615,  615,  104,  103,
 /*  3940 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  615,
 /*  3950 */    30,  117,  462,  615,  724,  615,  282,  615,  615,  615,
 /*  3960 */   281,  615,  724,  615,  724,  615,  615,  724,  615,  615,
 /*  3970 */   724,  724,  615,  615,  615,  615,  615,  615,  615,  615,
 /*  3980 */   615,  615,  615,  615,  236,  724,   12,  724,  236,  724,
 /*  3990 */    12,  724,  724,  724,  615,  615,  615,  615,  724,  724,
 /*  4000 */   615,  615,  615,  615,  615,  615,  615,  615,  615,  616,
 /*  4010 */   616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
 /*  4020 */   616,  104,  103,  105,  107,  106,  112,  111,  109,  110,
 /*  4030 */   108,  724,  616,   30,  117,  462,  616,  724,  616,  280,
 /*  4040 */   616,  616,  616,  304,  616,  724,  616,  724,  616,  616,
 /*  4050 */   724,  616,  616,  724,  724,  616,  616,  616,  616,  616,
 /*  4060 */   616,  616,  616,  616,  616,  616,  616,  236,  724,   12,
 /*  4070 */   724,  236,  724,   12,  724,  724,  724,  616,  616,  616,
 /*  4080 */   616,  724,  724,  616,  616,  616,  616,  616,  616,  616,
 /*  4090 */   616,  616,  618,  618,  618,  618,  618,  618,  618,  618,
 /*  4100 */   618,  618,  618,  618,  104,  103,  105,  107,  106,  112,
 /*  4110 */   111,  109,  110,  108,  724,  618,   30,  117,  462,  618,
 /*  4120 */   724,  618,  303,  618,  618,  618,  302,  618,  724,  618,
 /*  4130 */   724,  618,  618,  724,  618,  618,  724,  724,  618,  618,
 /*  4140 */   618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
 /*  4150 */   236,  724,   12,  724,  236,  724,   12,  724,  724,  724,
 /*  4160 */   618,  618,  618,  618,  724,  724,  618,  618,  618,  618,
 /*  4170 */   618,  618,  618,  618,  618,  619,  619,  619,  619,  619,
 /*  4180 */   619,  619,  619,  619,  619,  619,  619,  104,  103,  105,
 /*  4190 */   107,  106,  112,  111,  109,  110,  108,  724,  619,   30,
 /*  4200 */   117,  462,  619,  724,  619,  301,  619,  619,  619,  300,
 /*  4210 */   619,  724,  619,  724,  619,  619,  724,  619,  619,  724,
 /*  4220 */   724,  619,  619,  619,  619,  619,  619,  619,  619,  619,
 /*  4230 */   619,  619,  619,  236,  724,   12,  724,  236,  724,   12,
 /*  4240 */   724,  724,  724,  619,  619,  619,  619,  724,  724,  619,
 /*  4250 */   619,  619,  619,  619,  619,  619,  619,  619,  620,  620,
 /*  4260 */   620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
 /*  4270 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /*  4280 */   724,  620,   30,  117,  462,  620,  724,  620,  293,  620,
 /*  4290 */   620,  620,  724,  620,  724,  620,  724,  620,  620,  724,
 /*  4300 */   620,  620,  724,  724,  620,  620,  620,  620,  620,  620,
 /*  4310 */   620,  620,  620,  620,  620,  620,  236,  724,   12,  724,
 /*  4320 */   724,  724,  724,  724,  724,  724,  620,  620,  620,  620,
 /*  4330 */   724,  724,  620,  620,  620,  620,  620,  620,  620,  620,
 /*  4340 */   620,  621,  621,  621,  621,  621,  621,  621,  621,  621,
 /*  4350 */   621,  621,  621,  104,  103,  105,  107,  106,  112,  111,
 /*  4360 */   109,  110,  108,  724,  621,   30,  117,  462,  621,  724,
 /*  4370 */   621,  724,  621,  621,  621,  724,  621,  724,  621,  724,
 /*  4380 */   621,  621,  724,  621,  621,  724,  724,  621,  621,  621,
 /*  4390 */   621,  621,  621,  621,  621,  621,  621,  621,  621,  724,
 /*  4400 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  621,
 /*  4410 */   621,  621,  621,  724,  724,  621,  621,  621,  621,  621,
 /*  4420 */   621,  621,  621,  621,  622,  622,  622,  622,  622,  622,
 /*  4430 */   622,  622,  622,  622,  622,  622,  104,  103,  105,  107,
 /*  4440 */   106,  112,  111,  109,  110,  108,  724,  622,   30,  117,
 /*  4450 */   462,  622,  724,  622,  724,  622,  622,  622,  724,  622,
 /*  4460 */   724,  622,  724,  622,  622,  724,  622,  622,  724,  724,
 /*  4470 */   622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
 /*  4480 */   622,  622,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  4490 */   724,  724,  622,  622,  622,  622,  724,  724,  622,  622,
 /*  4500 */   622,  622,  622,  622,  622,  622,  622,  611,  611,  611,
 /*  4510 */   611,  611,  611,  611,  611,  611,  611,  611,  611,  104,
 /*  4520 */   103,  105,  107,  106,  112,  111,  109,  110,  108,  724,
 /*  4530 */   611,   30,  117,  462,  611,  724,  611,  724,  611,  611,
 /*  4540 */   611,  724,  611,  724,  611,  724,  611,  611,  724,  611,
 /*  4550 */   611,  724,  724,  611,  611,  611,  611,  611,  611,  611,
 /*  4560 */   611,  611,  611,  611,  611,  724,  724,  724,  724,  724,
 /*  4570 */   724,  724,  724,  724,  724,  611,  611,  611,  611,  724,
 /*  4580 */   724,  611,  611,  611,  611,  611,  611,  611,  611,  611,
 /*  4590 */   584,  584,  584,  584,  584,  584,  584,  584,  584,  584,
 /*  4600 */   584,  584,  584,  584,  584,  584,  584,  584,  584,  584,
 /*  4610 */   584,  584,  724,  584,  584,  466,  584,  584,  724,  584,
 /*  4620 */   724,  584,  584,  584,  724,  584,  724,  584,  724,  584,
 /*  4630 */   584,  724,  584,  584,  724,  724,  584,  584,  584,  584,
 /*  4640 */   584,  584,  584,  584,  584,  584,  584,  584,  724,  724,
 /*  4650 */   724,  724,  724,  724,  724,  724,  724,  724,  584,  584,
 /*  4660 */   584,  584,  724,  724,  584,  584,  584,  584,  584,  584,
 /*  4670 */   584,  584,  584,  559,  559,  559,  559,  559,  559,  559,
 /*  4680 */   559,  559,  559,  559,  559,  559,  559,  559,  559,  559,
 /*  4690 */   559,  559,  559,  559,  559,  724,  559,  559,  559,  559,
 /*  4700 */   559,  724,  559,  724,  559,  559,  559,  724,  559,  724,
 /*  4710 */   559,  724,  559,  559,  724,  559,  559,  724,  724,  559,
 /*  4720 */   559,  559,  559,  559,  559,  559,  559,  559,  559,  559,
 /*  4730 */   559,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  4740 */   724,  559,  559,  559,  559,  724,  724,  559,  559,  559,
 /*  4750 */   559,  559,  559,  559,  559,  559,  568,  568,  568,  568,
 /*  4760 */   568,  568,  119,   82,   80,   81,   79,   94,  568,  568,
 /*  4770 */   568,  568,  568,  568,  568,  568,  568,  568,  724,  568,
 /*  4780 */   568,  568,  568,  568,  724,  568,  724,  568,  568,  568,
 /*  4790 */   724,  568,  724,  568,  724,  568,  568,  724,  568,  568,
 /*  4800 */   724,  724,  568,  568,  568,  568,  568,  568,  568,  568,
 /*  4810 */   568,  568,  568,  568,  724,  724,  724,  724,  724,  724,
 /*  4820 */   724,  724,  724,  724,  568,  568,  568,  568,  724,  724,
 /*  4830 */   568,  568,  568,  568,  568,  568,  568,  568,  568,  564,
 /*  4840 */   564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
 /*  4850 */   564,  564,  564,  564,  564,  564,  564,  564,  564,  564,
 /*  4860 */   564,  724,  564,  564,  564,  564,  564,  724,  564,  724,
 /*  4870 */   564,  564,  564,  724,  564,  724,  564,  724,  564,  564,
 /*  4880 */   724,  564,  564,  724,  724,  564,  564,  564,  564,  564,
 /*  4890 */   564,  564,  564,  564,  564,  564,  564,  724,  724,  724,
 /*  4900 */   724,  724,  724,  724,  724,  724,  724,  564,  564,  564,
 /*  4910 */   564,  724,  724,  564,  564,  564,  564,  564,  564,  564,
 /*  4920 */   564,  564,  565,  565,  565,  565,  565,  565,  565,  565,
 /*  4930 */   565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
 /*  4940 */   565,  565,  565,  565,  724,  565,  565,  565,  565,  565,
 /*  4950 */   724,  565,  724,  565,  565,  565,  724,  565,  724,  565,
 /*  4960 */   724,  565,  565,  724,  565,  565,  724,  724,  565,  565,
 /*  4970 */   565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
 /*  4980 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  4990 */   565,  565,  565,  565,  724,  724,  565,  565,  565,  565,
 /*  5000 */   565,  565,  565,  565,  565,  566,  566,  566,  566,  566,
 /*  5010 */   566,  566,  566,  566,  566,  566,  566,  566,  566,  566,
 /*  5020 */   566,  566,  566,  566,  566,  566,  566,  724,  566,   32,
 /*  5030 */   566,  566,  566,  724,  566,  724,  566,  566,  566,  724,
 /*  5040 */   566,  724,  566,  724,  566,  566,  724,  566,  566,  724,
 /*  5050 */   724,  566,  566,  566,  566,  566,  566,  566,  566,  566,
 /*  5060 */   566,  566,  566,  724,  724,  724,  724,  724,  724,  724,
 /*  5070 */   724,  724,  724,  566,  566,  566,  566,  724,  724,  566,
 /*  5080 */   566,  566,  566,  566,  566,  566,  566,  566,  567,  567,
 /*  5090 */   567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
 /*  5100 */   567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
 /*  5110 */   724,  567,   31,  567,  567,  567,  724,  567,  724,  567,
 /*  5120 */   567,  567,  724,  567,  724,  567,  724,  567,  567,  724,
 /*  5130 */   567,  567,  724,  724,  567,  567,  567,  567,  567,  567,
 /*  5140 */   567,  567,  567,  567,  567,  567,  724,  724,  724,  724,
 /*  5150 */   724,  724,  724,  724,  724,  724,  567,  567,  567,  567,
 /*  5160 */   724,  724,  567,  567,  567,  567,  567,  567,  567,  567,
 /*  5170 */   567,  569,  569,  569,  569,  569,  569,  116,   76,   74,
 /*  5180 */    75,   73,   77,  569,  569,  569,  569,  569,  569,  569,
 /*  5190 */   569,  569,  569,  724,  569,  569,  569,  569,  569,  724,
 /*  5200 */   569,  724,  569,  569,  569,  724,  569,  724,  569,  724,
 /*  5210 */   569,  569,  724,  569,  569,  724,  724,  569,  569,  569,
 /*  5220 */   569,  569,  569,  569,  569,  569,  569,  569,  569,  724,
 /*  5230 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  569,
 /*  5240 */   569,  569,  569,  724,  724,  569,  569,  569,  569,  569,
 /*  5250 */   569,  569,  569,  569,  597,  114,  597,   95,   96,  597,
 /*  5260 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /*  5270 */   106,  112,  111,  109,  110,  108,  724,  597,   30,  117,
 /*  5280 */   462,  597,  724,  597,  724,  597,  597,  597,  724,  597,
 /*  5290 */   724,  597,  724,  597,  597,  724,  597,  597,  724,  724,
 /*  5300 */   597,  597,  597,  597,  597,  597,  597,  597,  597,  597,
 /*  5310 */   597,  597,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  5320 */   724,  724,  597,  597,  597,  597,  724,  724,  597,  597,
 /*  5330 */   597,  597,  597,  597,  597,  597,  597,  598,  598,  598,
 /*  5340 */   598,  598,  598,  598,  598,  598,  598,  598,  598,  598,
 /*  5350 */   598,  598,  598,  598,  598,  598,  109,  110,  108,  724,
 /*  5360 */   598,   30,  117,  462,  598,  724,  598,  724,  598,  598,
 /*  5370 */   598,  724,  598,  724,  598,  724,  598,  598,  724,  598,
 /*  5380 */   598,  724,  724,  598,  598,  598,  598,  598,  598,  598,
 /*  5390 */   598,  598,  598,  598,  598,  724,  724,  724,  724,  724,
 /*  5400 */   724,  724,  724,  724,  724,  598,  598,  598,  598,  724,
 /*  5410 */   724,  598,  598,  598,  598,  598,  598,  598,  598,  598,
 /*  5420 */   599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
 /*  5430 */   599,  599,  599,  599,  599,  599,  599,  599,  599,  109,
 /*  5440 */   110,  108,  724,  599,   30,  117,  462,  599,  724,  599,
 /*  5450 */   724,  599,  599,  599,  724,  599,  724,  599,  724,  599,
 /*  5460 */   599,  724,  599,  599,  724,  724,  599,  599,  599,  599,
 /*  5470 */   599,  599,  599,  599,  599,  599,  599,  599,  724,  724,
 /*  5480 */   724,  724,  724,  724,  724,  724,  724,  724,  599,  599,
 /*  5490 */   599,  599,  724,  724,  599,  599,  599,  599,  599,  599,
 /*  5500 */   599,  599,  599,  600,  600,  600,  600,  600,  600,  600,
 /*  5510 */   600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
 /*  5520 */   600,  600,  600,  600,  600,  724,  600,   30,  117,  462,
 /*  5530 */   600,  724,  600,  724,  600,  600,  600,  724,  600,  724,
 /*  5540 */   600,  724,  600,  600,  724,  600,  600,  724,  724,  600,
 /*  5550 */   600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
 /*  5560 */   600,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  5570 */   724,  600,  600,  600,  600,  724,  724,  600,  600,  600,
 /*  5580 */   600,  600,  600,  600,  600,  600,  601,  601,  601,  601,
 /*  5590 */   601,  601,  601,  601,  601,  601,  601,  601,  601,  601,
 /*  5600 */   601,  601,  601,  601,  601,  601,  601,  601,  724,  601,
 /*  5610 */    30,  117,  462,  601,  724,  601,  724,  601,  601,  601,
 /*  5620 */   724,  601,  724,  601,  724,  601,  601,  724,  601,  601,
 /*  5630 */   724,  724,  601,  601,  601,  601,  601,  601,  601,  601,
 /*  5640 */   601,  601,  601,  601,  724,  724,  724,  724,  724,  724,
 /*  5650 */   724,  724,  724,  724,  601,  601,  601,  601,  724,  724,
 /*  5660 */   601,  601,  601,  601,  601,  601,  601,  601,  601,  602,
 /*  5670 */   602,  602,  602,  602,  602,  602,  602,  602,  602,  602,
 /*  5680 */   602,  602,  602,  602,  602,  602,  602,  602,  602,  602,
 /*  5690 */   602,  724,  602,   30,  117,  462,  602,  724,  602,  724,
 /*  5700 */   602,  602,  602,  724,  602,  724,  602,  724,  602,  602,
 /*  5710 */   724,  602,  602,  724,  724,  602,  602,  602,  602,  602,
 /*  5720 */   602,  602,  602,  602,  602,  602,  602,  724,  724,  724,
 /*  5730 */   724,  724,  724,  724,  724,  724,  724,  602,  602,  602,
 /*  5740 */   602,  724,  724,  602,  602,  602,  602,  602,  602,  602,
 /*  5750 */   602,  602,  603,  603,  603,  603,  603,  603,  603,  603,
 /*  5760 */   603,  603,  603,  603,  603,  603,  603,  603,  603,  112,
 /*  5770 */   111,  109,  110,  108,  724,  603,   30,  117,  462,  603,
 /*  5780 */   724,  603,  724,  603,  603,  603,  724,  603,  724,  603,
 /*  5790 */   724,  603,  603,  724,  603,  603,  724,  724,  603,  603,
 /*  5800 */   603,  603,  603,  603,  603,  603,  603,  603,  603,  603,
 /*  5810 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  5820 */   603,  603,  603,  603,  724,  724,  603,  603,  603,  603,
 /*  5830 */   603,  603,  603,  603,  603,  604,  604,  604,  604,  604,
 /*  5840 */   604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
 /*  5850 */   604,  604,  112,  111,  109,  110,  108,  724,  604,   30,
 /*  5860 */   117,  462,  604,  724,  604,  724,  604,  604,  604,  724,
 /*  5870 */   604,  724,  604,  724,  604,  604,  724,  604,  604,  724,
 /*  5880 */   724,  604,  604,  604,  604,  604,  604,  604,  604,  604,
 /*  5890 */   604,  604,  604,  724,  724,  724,  724,  724,  724,  724,
 /*  5900 */   724,  724,  724,  604,  604,  604,  604,  724,  724,  604,
 /*  5910 */   604,  604,  604,  604,  604,  604,  604,  604,  605,  605,
 /*  5920 */   605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
 /*  5930 */   605,  605,  605,  107,  106,  112,  111,  109,  110,  108,
 /*  5940 */   724,  605,   30,  117,  462,  605,  724,  605,  724,  605,
 /*  5950 */   605,  605,  724,  605,  724,  605,  724,  605,  605,  724,
 /*  5960 */   605,  605,  724,  724,  605,  605,  605,  605,  605,  605,
 /*  5970 */   605,  605,  605,  605,  605,  605,  724,  724,  724,  724,
 /*  5980 */   724,  724,  724,  724,  724,  724,  605,  605,  605,  605,
 /*  5990 */   724,  724,  605,  605,  605,  605,  605,  605,  605,  605,
 /*  6000 */   605,  606,  606,  606,  606,  606,  606,  606,  606,  606,
 /*  6010 */   606,  606,  606,  606,  103,  105,  107,  106,  112,  111,
 /*  6020 */   109,  110,  108,  724,  606,   30,  117,  462,  606,  724,
 /*  6030 */   606,  724,  606,  606,  606,  724,  606,  724,  606,  724,
 /*  6040 */   606,  606,  724,  606,  606,  724,  724,  606,  606,  606,
 /*  6050 */   606,  606,  606,  606,  606,  606,  606,  606,  606,  724,
 /*  6060 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  606,
 /*  6070 */   606,  606,  606,  724,  724,  606,  606,  606,  606,  606,
 /*  6080 */   606,  606,  606,  606,  607,  607,  607,  607,  607,  607,
 /*  6090 */   607,  607,  607,  607,  607,  607,  607,  607,  105,  107,
 /*  6100 */   106,  112,  111,  109,  110,  108,  724,  607,   30,  117,
 /*  6110 */   462,  607,  724,  607,  724,  607,  607,  607,  724,  607,
 /*  6120 */   724,  607,  724,  607,  607,  724,  607,  607,  724,  724,
 /*  6130 */   607,  607,  607,  607,  607,  607,  607,  607,  607,  607,
 /*  6140 */   607,  607,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  6150 */   724,  724,  607,  607,  607,  607,  724,  724,  607,  607,
 /*  6160 */   607,  607,  607,  607,  607,  607,  607,  629,  629,  629,
 /*  6170 */   629,  629,  629,  102,  100,   98,   99,   97,  101,  104,
 /*  6180 */   103,  105,  107,  106,  112,  111,  109,  110,  108,  724,
 /*  6190 */   629,   30,  117,  462,  629,  724,  629,  724,  629,  629,
 /*  6200 */   629,  724,  629,  724,  629,  724,  629,  629,  724,  629,
 /*  6210 */   629,  724,  724,  629,  629,  629,  629,  629,  629,  629,
 /*  6220 */   629,  629,  629,  629,  629,  724,  724,  724,  724,  724,
 /*  6230 */   724,  724,  724,  724,  724,  629,  629,  629,  629,  724,
 /*  6240 */   724,  629,  629,  629,  629,  629,  629,  629,  629,  629,
 /*  6250 */   630,  630,  630,  630,   96,  630,  102,  100,   98,   99,
 /*  6260 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /*  6270 */   110,  108,  724,  630,   30,  117,  462,  630,  724,  630,
 /*  6280 */   724,  630,  630,  630,  724,  630,  724,  630,  724,  630,
 /*  6290 */   630,  724,  630,  630,  724,  724,  630,  630,  630,  630,
 /*  6300 */   630,  630,  630,  630,  630,  630,  630,  630,  724,  724,
 /*  6310 */   724,  724,  724,  724,  724,  724,  724,  724,  630,  630,
 /*  6320 */   630,  630,  724,  724,  630,  630,  630,  630,  630,  630,
 /*  6330 */   630,  630,  630,  585,  585,  585,  585,  585,  585,  585,
 /*  6340 */   585,  585,  585,  585,  585,  585,  585,  585,  585,  585,
 /*  6350 */   585,  585,  585,  585,  585,  724,  585,  585,  585,  585,
 /*  6360 */   585,  724,  585,  724,  585,  585,  585,  724,  585,  724,
 /*  6370 */   585,  724,  585,  585,  724,  585,  585,  724,  724,  585,
 /*  6380 */   585,  585,  585,  585,  585,  585,  585,  585,  585,  585,
 /*  6390 */   585,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  6400 */   724,  585,  585,  585,  585,  724,  724,  585,  585,  585,
 /*  6410 */   585,  585,  585,  585,  585,  585,  589,  589,  589,  589,
 /*  6420 */   589,  589,  589,  589,  589,  589,  589,  589,  589,  589,
 /*  6430 */   589,  589,  589,  589,  589,  589,  589,  589,  724,  589,
 /*  6440 */   589,  589,  589,  589,  724,  589,  724,  589,  589,  589,
 /*  6450 */   724,  589,  724,  589,  724,  589,  589,  724,  589,  589,
 /*  6460 */   724,  724,  589,  589,  589,  589,  589,  589,  589,  589,
 /*  6470 */   589,  589,  589,  589,  724,  724,  724,  724,  724,  724,
 /*  6480 */   724,  724,  724,  724,  589,  589,  589,  589,  724,  724,
 /*  6490 */   589,  589,  589,  589,  589,  589,  589,  589,  589,  590,
 /*  6500 */   590,  590,  590,  590,  590,  590,  590,  590,  590,  590,
 /*  6510 */   590,  590,  590,  590,  590,  590,  590,  590,  590,  590,
 /*  6520 */   590,  724,  590,  590,  590,  590,  590,  724,  590,  724,
 /*  6530 */   590,  590,  590,  724,  590,  724,  590,  724,  590,  590,
 /*  6540 */   724,  590,  590,  724,  724,  590,  590,  590,  590,  590,
 /*  6550 */   590,  590,  590,  590,  590,  590,  590,  724,  724,  724,
 /*  6560 */   724,  724,  724,  724,  724,  724,  724,  590,  590,  590,
 /*  6570 */   590,  724,  724,  590,  590,  590,  590,  590,  590,  590,
 /*  6580 */   590,  590,  591,  591,  591,  591,  591,  591,  591,  591,
 /*  6590 */   591,  591,  591,  591,  591,  591,  591,  591,  591,  591,
 /*  6600 */   591,  591,  591,  591,  724,  591,  591,  591,  591,  591,
 /*  6610 */   724,  591,  724,  591,  591,  591,  724,  591,  724,  591,
 /*  6620 */   724,  591,  591,  724,  591,  591,  724,  724,  591,  591,
 /*  6630 */   591,  591,  591,  591,  591,  591,  591,  591,  591,  591,
 /*  6640 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  6650 */   591,  591,  591,  591,  724,  724,  591,  591,  591,  591,
 /*  6660 */   591,  591,  591,  591,  591,  592,  592,  592,  592,  592,
 /*  6670 */   592,  592,  592,  592,  592,  592,  592,  592,  592,  592,
 /*  6680 */   592,  592,  592,  592,  592,  592,  592,  724,  592,  592,
 /*  6690 */   592,  592,  592,  724,  592,  724,  592,  592,  592,  724,
 /*  6700 */   592,  724,  592,  724,  592,  592,  724,  592,  592,  724,
 /*  6710 */   724,  592,  592,  592,  592,  592,  592,  592,  592,  592,
 /*  6720 */   592,  592,  592,  724,  724,  724,  724,  724,  724,  724,
 /*  6730 */   724,  724,  724,  592,  592,  592,  592,  724,  724,  592,
 /*  6740 */   592,  592,  592,  592,  592,  592,  592,  592,  593,  593,
 /*  6750 */   593,  593,  593,  593,  593,  593,  593,  593,  593,  593,
 /*  6760 */   593,  593,  593,  593,  593,  593,  593,  593,  593,  593,
 /*  6770 */   724,  593,  593,  593,  593,  593,  724,  593,  724,  593,
 /*  6780 */   593,  593,  724,  593,  724,  593,  724,  593,  593,  724,
 /*  6790 */   593,  593,  724,  724,  593,  593,  593,  593,  593,  593,
 /*  6800 */   593,  593,  593,  593,  593,  593,  724,  724,  724,  724,
 /*  6810 */   724,  724,  724,  724,  724,  724,  593,  593,  593,  593,
 /*  6820 */   724,  724,  593,  593,  593,  593,  593,  593,  593,  593,
 /*  6830 */   593,  594,  594,  594,  594,  594,  594,  594,  594,  594,
 /*  6840 */   594,  594,  594,  594,  594,  594,  594,  594,  594,  594,
 /*  6850 */   594,  594,  594,  724,  594,  594,  594,  594,  594,  724,
 /*  6860 */   594,  724,  594,  594,  594,  724,  594,  724,  594,  724,
 /*  6870 */   594,  594,  724,  594,  594,  724,  724,  594,  594,  594,
 /*  6880 */   594,  594,  594,  594,  594,  594,  594,  594,  594,  724,
 /*  6890 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  594,
 /*  6900 */   594,  594,  594,  724,  724,  594,  594,  594,  594,  594,
 /*  6910 */   594,  594,  594,  594,  595,  595,  595,  595,  595,  595,
 /*  6920 */   595,  595,  595,  595,  595,  595,  595,  595,  595,  595,
 /*  6930 */   595,  595,  595,  595,  595,  595,  724,  595,  595,  595,
 /*  6940 */   595,  595,  724,  595,  724,  595,  595,  595,  724,  595,
 /*  6950 */   724,  595,  724,  595,  595,  724,  595,  595,  724,  724,
 /*  6960 */   595,  595,  595,  595,  595,  595,  595,  595,  595,  595,
 /*  6970 */   595,  595,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  6980 */   724,  724,  595,  595,  595,  595,  724,  724,  595,  595,
 /*  6990 */   595,  595,  595,  595,  595,  595,  595,  596,  596,  596,
 /*  7000 */   596,  596,  596,  596,  596,  596,  596,  596,  596,  596,
 /*  7010 */   596,  596,  596,  596,  596,  596,  596,  596,  596,  724,
 /*  7020 */   596,  596,  596,  596,  596,  724,  596,  724,  596,  596,
 /*  7030 */   596,  724,  596,  724,  596,  724,  596,  596,  724,  596,
 /*  7040 */   596,  724,  724,  596,  596,  596,  596,  596,  596,  596,
 /*  7050 */   596,  596,  596,  596,  596,  724,  724,  724,  724,  724,
 /*  7060 */   724,  724,  724,  724,  724,  596,  596,  596,  596,  724,
 /*  7070 */   724,  596,  596,  596,  596,  596,  596,  596,  596,  596,
 /*  7080 */   608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
 /*  7090 */   608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
 /*  7100 */   608,  608,  724,  608,   30,  117,  462,  608,  724,  608,
 /*  7110 */   724,  608,  608,  608,  724,  608,  724,  608,  724,  608,
 /*  7120 */   608,  724,  608,  608,  724,  724,  608,  608,  608,  608,
 /*  7130 */   608,  608,  608,  608,  608,  608,  608,  608,  724,  724,
 /*  7140 */   724,  724,  724,  724,  724,  724,  724,  724,  608,  608,
 /*  7150 */   608,  608,  724,  724,  608,  608,  608,  608,  608,  608,
 /*  7160 */   608,  608,  608,  609,  609,  609,  609,  609,  609,  609,
 /*  7170 */   609,  609,  609,  609,  609,  609,  609,  609,  609,  609,
 /*  7180 */   609,  609,  609,  609,  609,  724,  609,   30,  117,  462,
 /*  7190 */   609,  724,  609,  724,  609,  609,  609,  724,  609,  724,
 /*  7200 */   609,  724,  609,  609,  724,  609,  609,  724,  724,  609,
 /*  7210 */   609,  609,  609,  609,  609,  609,  609,  609,  609,  609,
 /*  7220 */   609,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  7230 */   724,  609,  609,  609,  609,  724,  724,  609,  609,  609,
 /*  7240 */   609,  609,  609,  609,  609,  609,  610,  610,  610,  610,
 /*  7250 */   610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
 /*  7260 */   610,  610,  610,  610,  610,  610,  610,  610,  724,  610,
 /*  7270 */    30,  117,  462,  610,  724,  610,  724,  610,  610,  610,
 /*  7280 */   724,  610,  724,  610,  724,  610,  610,  724,  610,  610,
 /*  7290 */   724,  724,  610,  610,  610,  610,  610,  610,  610,  610,
 /*  7300 */   610,  610,  610,  610,  724,  724,  724,  724,  724,  724,
 /*  7310 */   724,  724,  724,  724,  610,  610,  610,  610,  724,  724,
 /*  7320 */   610,  610,  610,  610,  610,  610,  610,  610,  610,  631,
 /*  7330 */   631,  631,  631,  631,  631,  102,  100,   98,   99,   97,
 /*  7340 */   101,  104,  103,  105,  107,  106,  112,  111,  109,  110,
 /*  7350 */   108,  724,  631,   30,  117,  462,  631,  724,  631,  724,
 /*  7360 */   631,  631,  631,  724,  631,  724,  631,  724,  631,  631,
 /*  7370 */   724,  631,  631,  724,  724,  631,  631,  631,  631,  631,
 /*  7380 */   631,  631,  631,  631,  631,  631,  631,  724,  724,  724,
 /*  7390 */   724,  724,  724,  724,  724,  724,  724,  631,  631,  631,
 /*  7400 */   631,  724,  724,  631,  631,  631,  631,  631,  631,  631,
 /*  7410 */   631,  631,  720,  720,  720,  720,  720,  720,  720,  720,
 /*  7420 */   720,  720,  720,  720,  720,  720,  720,  720,  720,  720,
 /*  7430 */   720,  720,  720,  720,  724,  720,  720,  720,  720,  720,
 /*  7440 */   724,  720,  724,  720,  720,  720,  724,  720,  724,  720,
 /*  7450 */   724,  720,  720,  724,  720,  720,  724,  724,  720,  720,
 /*  7460 */   720,  720,  720,  720,  720,  720,  720,  720,  720,  720,
 /*  7470 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  7480 */   720,  720,  720,  720,  724,  724,  720,  720,  720,  720,
 /*  7490 */   720,  720,  720,  720,  720,  721,  721,  721,  721,  721,
 /*  7500 */   721,  721,  721,  721,  721,  721,  721,  721,  721,  721,
 /*  7510 */   721,  721,  721,  721,  721,  721,  721,  724,  721,  721,
 /*  7520 */   721,  721,  721,  724,  721,  724,  721,  721,  721,  724,
 /*  7530 */   721,  724,  721,  724,  721,  721,  724,  721,  721,  724,
 /*  7540 */   724,  721,  721,  721,  721,  721,  721,  721,  721,  721,
 /*  7550 */   721,  721,  721,  724,  724,  724,  724,  724,  724,  724,
 /*  7560 */   724,  724,  724,  721,  721,  721,  721,  724,  724,  721,
 /*  7570 */   721,  721,  721,  721,  721,  721,  721,  721,  716,  716,
 /*  7580 */   716,  716,  716,  716,  716,  716,  716,  716,  716,  716,
 /*  7590 */   716,  716,  716,  716,  716,  716,  716,  716,  716,  716,
 /*  7600 */   724,  716,  716,  716,  716,  716,  724,  716,  724,  716,
 /*  7610 */   716,  716,  724,  716,  724,  716,  724,  716,  716,  724,
 /*  7620 */   716,  716,  724,  724,  716,  716,  716,  716,  716,  716,
 /*  7630 */   716,  716,  716,  716,  716,  716,  724,  724,  724,  724,
 /*  7640 */   724,  724,  724,  724,  724,  724,  716,  716,  716,  716,
 /*  7650 */   724,  724,  716,  716,  716,  716,  716,  716,  716,  716,
 /*  7660 */   716,  588,  588,  588,  588,  588,  588,  588,  588,  588,
 /*  7670 */   588,  588,  588,  588,  588,  588,  588,  588,  588,  588,
 /*  7680 */   588,  588,  588,  724,  588,  588,  588,  588,  588,  724,
 /*  7690 */   588,  724,  588,  588,  588,  724,  588,  724,  588,  724,
 /*  7700 */   588,  588,  724,  588,  588,  724,  724,  588,  588,  588,
 /*  7710 */   588,  588,  588,  588,  588,  588,  588,  588,  588,  724,
 /*  7720 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  588,
 /*  7730 */   588,  588,  588,  724,  724,  588,  588,  588,  588,  588,
 /*  7740 */   588,  588,  588,  588,  571,  571,  571,  571,  571,  571,
 /*  7750 */   571,  571,  571,  571,  571,  571,  571,  571,  571,  571,
 /*  7760 */   571,  571,  571,  571,  571,  571,  724,  571,  571,  571,
 /*  7770 */   571,  571,  724,  571,  724,  571,  571,  571,  724,  571,
 /*  7780 */   724,  571,  724,  571,  571,  724,  571,  571,  724,  724,
 /*  7790 */   571,  571,  571,  571,  571,  571,  571,  571,  571,  571,
 /*  7800 */   571,  571,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  7810 */   724,  724,  571,  571,  571,  571,  724,  724,  571,  571,
 /*  7820 */   571,  571,  571,  571,  571,  571,  571,  581,  581,  581,
 /*  7830 */   581,  581,  581,  581,  581,  581,  581,  581,  581,  581,
 /*  7840 */   581,  581,  581,  581,  581,  581,  581,  581,  581,  724,
 /*  7850 */   581,  581,  581,  581,  581,  724,  581,  724,  581,  581,
 /*  7860 */   581,  724,  581,  724,  581,  724,  581,  581,  724,  581,
 /*  7870 */   581,  724,  724,  581,  581,  581,  581,  581,  581,  581,
 /*  7880 */   581,  581,  581,  581,  581,  724,  724,  724,  724,  724,
 /*  7890 */   724,  724,  724,  724,  724,  581,  581,  581,  581,  724,
 /*  7900 */   724,  581,  581,  581,  581,  581,  581,  581,  581,  581,
 /*  7910 */   580,  580,  580,  580,  580,  580,  580,  580,  580,  580,
 /*  7920 */   580,  580,  580,  580,  580,  580,  580,  580,  580,  580,
 /*  7930 */   580,  580,  724,  580,  580,  580,  580,  580,  724,  580,
 /*  7940 */   724,  580,  580,  580,  724,  580,  724,  580,  724,  580,
 /*  7950 */   580,  724,  580,  580,  724,  724,  580,  580,  580,  580,
 /*  7960 */   580,  580,  580,  580,  580,  580,  580,  580,  724,  724,
 /*  7970 */   724,  724,  724,  724,  724,  724,  724,  724,  580,  580,
 /*  7980 */   580,  580,  724,  724,  580,  580,  580,  580,  580,  580,
 /*  7990 */   580,  580,  580,  717,  717,  717,  717,  717,  717,  717,
 /*  8000 */   717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
 /*  8010 */   717,  717,  717,  717,  717,  724,  717,  717,  717,  717,
 /*  8020 */   717,  724,  717,  724,  717,  717,  717,  724,  717,  724,
 /*  8030 */   717,  724,  717,  717,  724,  717,  717,  724,  724,  717,
 /*  8040 */   717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
 /*  8050 */   717,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  8060 */   724,  717,  717,  717,  717,  724,  724,  717,  717,  717,
 /*  8070 */   717,  717,  717,  717,  717,  717,  114,  561,   95,   96,
 /*  8080 */   561,  102,  100,   98,   99,   97,  101,  104,  103,  105,
 /*  8090 */   107,  106,  112,  111,  109,  110,  108,  724,  561,   30,
 /*  8100 */   117,  462,  561,  724,  561,  724,  561,  561,  561,  724,
 /*  8110 */   561,  724,  561,  724,  561,  561,  724,  561,  561,  724,
 /*  8120 */   724,  561,  561,  561,  561,  561,  561,  561,  561,  561,
 /*  8130 */   561,  561,  561,  724,  724,  724,  724,  724,  724,  724,
 /*  8140 */   724,  724,  724,  561,  561,  561,  561,  724,  724,  561,
 /*  8150 */   561,  561,  561,  561,  561,  561,  561,  561,  584,  584,
 /*  8160 */   584,  584,  584,  584,  584,  584,  584,  584,  584,  584,
 /*  8170 */   584,  584,  584,  584,  584,  584,  584,  584,  584,  724,
 /*  8180 */   584,  584,  448,  584,  584,  724,  584,  724,  584,  584,
 /*  8190 */   584,  724,  584,  724,  584,  724,  584,  584,  724,  584,
 /*  8200 */   584,  724,  724,  584,  584,  584,  584,  584,  584,  584,
 /*  8210 */   584,  584,  584,  584,  584,  724,  724,  724,  724,  724,
 /*  8220 */   724,  724,  724,  724,  724,  584,  584,  584,  584,  724,
 /*  8230 */   724,  584,  584,  584,  584,  584,  584,  584,  584,  584,
 /*  8240 */   114,  560,   95,   96,  560,  102,  100,   98,   99,   97,
 /*  8250 */   101,  104,  103,  105,  107,  106,  112,  111,  109,  110,
 /*  8260 */   108,  724,  560,   30,  117,  462,  560,  724,  560,  724,
 /*  8270 */   560,  560,  560,  724,  560,  724,  560,  724,  560,  560,
 /*  8280 */   724,  560,  560,  724,  724,  560,  560,  560,  560,  560,
 /*  8290 */   560,  560,  560,  560,  560,  560,  560,  550,  350,  550,
 /*  8300 */   724,  724,  552,  237,  128,  724,  724,  560,  560,  560,
 /*  8310 */   560,  724,  460,  560,  560,  560,  560,  560,  560,  560,
 /*  8320 */   560,  560,  724,  724,  550,  724,  171,  724,  115,  552,
 /*  8330 */   550,  238,  401,   12,  198,  552,  319,  724,  724,  724,
 /*  8340 */   175,    1,  724,  141,  724,  458,  457,  456,  455,  454,
 /*  8350 */   453,  163,  162,  161,  160,  159,  158,  157,  452,  451,
 /*  8360 */   450,  553,  724,  553,  291,  724,   12,  724,  724,  724,
 /*  8370 */   724,  320,  367,  252,  425,  151,   10,  423,  422,   54,
 /*  8380 */   724,  460,  724,  416,  724,  724,  724,  724,  553,  724,
 /*  8390 */   414,  412,  411,   19,  553,  171,  724,  724,   57,   21,
 /*  8400 */   407,  138,  404,  153,  724,  319,  724,  724,  724,  175,
 /*  8410 */     1,  724,  141,  724,  458,  457,  456,  455,  454,  453,
 /*  8420 */   163,  162,  161,  160,  159,  158,  157,  452,  451,  450,
 /*  8430 */   724,  724,  724,  291,  724,   12,  724,  724,  724,  724,
 /*  8440 */   320,  367,  252,  425,  151,   10,  423,  422,   54,  724,
 /*  8450 */   724,  460,  416,  724,  724,  724,  724,  724,  724,  414,
 /*  8460 */   412,  411,   19,  724,  724,  171,  724,   57,   21,  407,
 /*  8470 */   138,  404,  724,  152,  724,  319,  724,  724,  724,  175,
 /*  8480 */     1,  724,  141,  724,  458,  457,  456,  455,  454,  453,
 /*  8490 */   163,  162,  161,  160,  159,  158,  157,  452,  451,  450,
 /*  8500 */   724,  724,  724,  291,  724,   12,  724,  724,  724,  724,
 /*  8510 */   320,  367,  252,  425,  151,   10,  423,  422,   54,  724,
 /*  8520 */   460,  724,  416,  724,  724,  724,  724,  724,  724,  414,
 /*  8530 */   412,  411,   19,  724,  171,  724,  724,   57,   21,  407,
 /*  8540 */   138,  404,  150,  724,  319,  724,  724,  724,  175,    1,
 /*  8550 */   724,  141,  724,  458,  457,  456,  455,  454,  453,  163,
 /*  8560 */   162,  161,  160,  159,  158,  157,  452,  451,  450,  724,
 /*  8570 */   724,  724,  291,  724,   12,  724,  724,  724,  724,  320,
 /*  8580 */   367,  252,  425,  151,   10,  423,  422,   54,  724,  724,
 /*  8590 */   460,  416,  724,  724,  724,  724,  724,  724,  414,  412,
 /*  8600 */   411,   19,  724,  724,  171,  724,   57,   21,  407,  138,
 /*  8610 */   404,  724,  149,  724,  319,  724,  724,  724,  175,    1,
 /*  8620 */   724,  141,  724,  458,  457,  456,  455,  454,  453,  163,
 /*  8630 */   162,  161,  160,  159,  158,  157,  452,  451,  450,  724,
 /*  8640 */   724,  724,  291,  724,   12,  724,  724,  724,  724,  320,
 /*  8650 */   367,  252,  425,  151,   10,  423,  422,   54,  724,  460,
 /*  8660 */   724,  416,  724,  724,  724,  724,  724,  724,  414,  412,
 /*  8670 */   411,   19,  724,  171,  724,  724,   57,   21,  407,  138,
 /*  8680 */   404,  147,  724,  319,  724,  724,  724,  175,    1,  724,
 /*  8690 */   141,  724,  458,  457,  456,  455,  454,  453,  163,  162,
 /*  8700 */   161,  160,  159,  158,  157,  452,  451,  450,  724,  724,
 /*  8710 */   724,  291,  724,   12,  724,  724,  724,  724,  320,  367,
 /*  8720 */   252,  425,  151,   10,  423,  422,   54,  724,  724,  460,
 /*  8730 */   416,  724,  724,  724,  724,  724,  724,  414,  412,  411,
 /*  8740 */    19,  724,  724,  171,  724,   57,   21,  407,  138,  404,
 /*  8750 */   724,  146,  724,  319,  724,  724,  724,  175,    1,  724,
 /*  8760 */   141,  724,  458,  457,  456,  455,  454,  453,  163,  162,
 /*  8770 */   161,  160,  159,  158,  157,  452,  451,  450,  724,  724,
 /*  8780 */   724,  291,  724,   12,  724,  724,  724,  724,  320,  367,
 /*  8790 */   252,  425,  151,   10,  423,  422,   54,  724,  460,  724,
 /*  8800 */   416,  724,  724,  724,  724,  724,  724,  414,  412,  411,
 /*  8810 */    19,  724,  171,  724,  724,   57,   21,  407,  138,  404,
 /*  8820 */   145,  724,  319,  724,  724,  724,  175,    1,  724,  141,
 /*  8830 */   724,  458,  457,  456,  455,  454,  453,  163,  162,  161,
 /*  8840 */   160,  159,  158,  157,  452,  451,  450,  724,  724,  724,
 /*  8850 */   291,  724,   12,  724,  724,  724,  724,  320,  367,  252,
 /*  8860 */   425,  151,   10,  423,  422,   54,  724,  724,  460,  416,
 /*  8870 */   724,  724,  724,  724,  724,  724,  414,  412,  411,   19,
 /*  8880 */   724,  724,  171,  724,   57,   21,  407,  138,  404,  724,
 /*  8890 */   142,  724,  319,  724,  724,  724,  175,    1,  724,  141,
 /*  8900 */   724,  458,  457,  456,  455,  454,  453,  163,  162,  161,
 /*  8910 */   160,  159,  158,  157,  452,  451,  450,  724,  724,  724,
 /*  8920 */   291,  724,   12,  724,  724,  724,  724,  320,  367,  252,
 /*  8930 */   425,  151,   10,  423,  422,   54,  724,  460,  724,  416,
 /*  8940 */   724,  724,  724,  724,  724,  724,  414,  412,  411,   19,
 /*  8950 */   724,  171,  724,  724,   57,   21,  407,  138,  404,  260,
 /*  8960 */   724,  319,  724,  724,  724,  175,    1,  724,  141,  724,
 /*  8970 */   458,  457,  456,  455,  454,  453,  163,  162,  161,  160,
 /*  8980 */   159,  158,  157,  452,  451,  450,  724,  724,  724,  291,
 /*  8990 */   724,   12,  724,  724,  724,  724,  320,  367,  252,  425,
 /*  9000 */   151,   10,  423,  422,   54,  724,  724,  460,  416,  724,
 /*  9010 */   724,  724,  724,  724,  724,  414,  412,  411,   19,  724,
 /*  9020 */   724,  171,  724,   57,   21,  407,  138,  404,  724,  325,
 /*  9030 */   724,  319,  724,  724,  724,  175,    1,  724,  141,  724,
 /*  9040 */   458,  457,  456,  455,  454,  453,  163,  162,  161,  160,
 /*  9050 */   159,  158,  157,  452,  451,  450,  724,  724,  724,  291,
 /*  9060 */   724,   12,  724,  724,  724,  724,  320,  367,  252,  425,
 /*  9070 */   151,   10,  423,  422,   54,  724,  459,  724,  416,  724,
 /*  9080 */   724,  724,  724,  724,  724,  414,  412,  411,   19,  724,
 /*  9090 */   171,  724,  724,   57,   21,  407,  138,  404,  724,  724,
 /*  9100 */   319,  724,  724,  724,  241,    1,  724,  141,   17,  458,
 /*  9110 */   457,  456,  455,  454,  453,  163,  162,  161,  160,  159,
 /*  9120 */   158,  157,  452,  451,  450,  724,  724,  724,  291,  724,
 /*  9130 */    12,  724,  724,  724,  724,  320,  367,  252,  425,  151,
 /*  9140 */    10,  423,  422,   54,  247,  724,  724,  416,  724,  237,
 /*  9150 */   724,  724,  724,  135,  414,  412,  411,   19,  237,  724,
 /*  9160 */   724,  724,   57,   21,  407,  138,  404,  134,  558,  724,
 /*  9170 */   724,  558,  237,  724,  724,  724,  724,  238,  724,   12,
 /*  9180 */   724,  724,  724,  558,  558,  724,  238,  724,   12,  558,
 /*  9190 */   558,  558,  724,  558,  724,  558,  724,  558,  558,  558,
 /*  9200 */   238,  558,   12,  558,  724,  558,  558,  724,  558,  558,
 /*  9210 */   724,  724,  558,  558,  558,  558,  558,  558,  558,  558,
 /*  9220 */   558,  558,  558,  558,  724,  243,  724,  724,  724,  724,
 /*  9230 */   724,  724,  724,  724,  558,  558,  558,  558,  724,  171,
 /*  9240 */   558,  558,  558,  558,  558,  558,  558,  558,  558,  319,
 /*  9250 */   724,  724,  724,  244,    1,  724,  141,  724,  458,  457,
 /*  9260 */   456,  455,  454,  453,  163,  162,  161,  160,  159,  158,
 /*  9270 */   157,  452,  451,  450,  724,  724,  724,  291,  724,   12,
 /*  9280 */   724,  724,  724,  724,  320,  367,  252,  425,  151,   10,
 /*  9290 */   423,  422,   54,  724,  724,  724,  416,  724,  724,  724,
 /*  9300 */   724,  724,  724,  414,  412,  411,   19,  171,  724,  724,
 /*  9310 */   724,   57,   21,  407,  138,  404,  724,  319,  724,  724,
 /*  9320 */   724,  241,    1,  724,  141,   15,  458,  457,  456,  455,
 /*  9330 */   454,  453,  163,  162,  161,  160,  159,  158,  157,  452,
 /*  9340 */   451,  450,  724,  724,  724,  291,  724,   12,  724,  724,
 /*  9350 */   724,  724,  320,  367,  252,  425,  151,   10,  423,  422,
 /*  9360 */    54,  724,  724,  724,  416,  724,  724,  724,  724,  724,
 /*  9370 */   724,  414,  412,  411,   19,  724,  724,  724,  171,   57,
 /*  9380 */    21,  407,  138,  404,  724,  724,  724,  724,  319,  724,
 /*  9390 */   724,  724,  241,    1,  724,  141,   13,  458,  457,  456,
 /*  9400 */   455,  454,  453,  163,  162,  161,  160,  159,  158,  157,
 /*  9410 */   452,  451,  450,  724,  724,  724,  291,  724,   12,  724,
 /*  9420 */   724,  724,  724,  320,  367,  252,  425,  151,   10,  423,
 /*  9430 */   422,   54,  133,  371,  724,  416,  724,  237,  237,  724,
 /*  9440 */   724,  370,  414,  412,  411,   19,  237,  724,  724,  724,
 /*  9450 */    57,   21,  407,  138,  404,  724,  724,  724,  724,  546,
 /*  9460 */   724,  724,  724,  724,  724,  238,  238,   12,   12,  724,
 /*  9470 */   724,  546,  546,  724,  238,  724,   12,  546,  546,  546,
 /*  9480 */   724,  546,  724,  546,  724,  319,  546,  724,  724,  546,
 /*  9490 */   724,  546,  546,  546,  724,  724,  546,  546,  355,  356,
 /*  9500 */   546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
 /*  9510 */   546,  546,  724,  291,  724,   12,  724,  724,  724,  724,
 /*  9520 */   320,  367,  546,  546,  546,  546,  546,  546,  546,  546,
 /*  9530 */   546,  546,  546,  546,  546,  546,  546,  547,  724,  724,
 /*  9540 */   724,  724,  724,  724,  724,  354,  408,  724,  724,  547,
 /*  9550 */   547,  724,  724,  724,  724,  547,  547,  547,  724,  547,
 /*  9560 */   724,  547,  724,  319,  547,  724,  724,  547,  724,  547,
 /*  9570 */   547,  547,  724,  724,  547,  547,  355,  356,  547,  547,
 /*  9580 */   547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
 /*  9590 */   724,  291,  724,   12,  724,  724,  724,  724,  320,  367,
 /*  9600 */   547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
 /*  9610 */   547,  547,  547,  547,  547,  678,  724,  724,  724,  724,
 /*  9620 */   724,  724,  724,  353,  724,  724,  724,  678,  678,  724,
 /*  9630 */   724,  724,  724,  678,  678,  678,  368,  678,  724,  678,
 /*  9640 */   724,  237,  678,  724,  724,  678,  724,  678,  678,  678,
 /*  9650 */   724,  724,  678,  678,  724,  724,  678,  678,  678,  678,
 /*  9660 */   678,  678,  678,  678,  678,  678,  678,  678,  724,  238,
 /*  9670 */   724,   12,  724,  724,  724,  724,  724,  724,  678,  678,
 /*  9680 */   678,  678,  678,  678,  678,  678,  678,  678,  678,  678,
 /*  9690 */   678,  678,  678,  545,  724,  724,  724,  724,  724,  724,
 /*  9700 */   724,  724,  724,  724,  724,  545,  545,  724,  724,  724,
 /*  9710 */   724,  545,  545,  545,  334,  545,  724,  545,  724,  237,
 /*  9720 */   545,  724,  724,  545,  724,  545,  545,  545,  724,  724,
 /*  9730 */   545,  545,  724,  724,  545,  545,  545,  545,  545,  545,
 /*  9740 */   545,  545,  545,  545,  545,  545,  724,  238,  724,   12,
 /*  9750 */   724,  724,  724,  724,  724,  724,  545,  545,  545,  545,
 /*  9760 */   545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
 /*  9770 */   545,   83,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  9780 */   724,  724,  724,   86,   85,  724,  724,  724,  724,   84,
 /*  9790 */    93,   51,  365,  170,  724,  256,  724,  237,  461,  724,
 /*  9800 */   724,  246,  724,  129,  679,  233,  724,  724,  232,  231,
 /*  9810 */   724,  724,  445,  444,  443,  442,  441,  440,  439,  437,
 /*  9820 */   428,  139,   43,   42,  724,  238,  724,   12,  724,  724,
 /*  9830 */   724,  724,  724,  724,  253,  424,  418,  417,  679,  679,
 /*  9840 */   413,  410,  406,  403,  402,   33,  435,  400,  398,   83,
 /*  9850 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /*  9860 */   724,   86,   85,  724,  724,  724,  724,   84,   93,   51,
 /*  9870 */   364,  170,  724,  256,  724,  237,  461,  724,  724,  246,
 /*  9880 */   724,  129,  680,  233,  724,  724,  232,  231,  724,  724,
 /*  9890 */   445,  444,  443,  442,  441,  440,  439,  437,  428,  139,
 /*  9900 */    43,   42,  724,  238,  363,   12,  724,  724,  724,  237,
 /*  9910 */   724,  724,  253,  424,  418,  417,  680,  680,  413,  410,
 /*  9920 */   406,  403,  402,   33,  435,  400,  398,  120,  351,  724,
 /*  9930 */   506,  724,  724,  237,  724,  724,  724,  238,  724,   12,
 /*  9940 */   724,  724,  506,  506,  724,  724,  724,  724,  506,  506,
 /*  9950 */   506,  348,  506,  724,  506,  724,  237,  506,  724,  724,
 /*  9960 */   506,  238,  506,   12,  506,  724,  724,  506,  506,  724,
 /*  9970 */   724,  506,  506,  506,  506,  506,  506,  506,  506,  506,
 /*  9980 */   506,  506,  506,  724,  238,  724,   12,  724,  724,  724,
 /*  9990 */   724,  724,  724,  506,  506,  506,  506,  724,  724,  506,
 /* 10000 */   506,  506,  506,  506,  506,  506,  506,  506,  521,  724,
 /* 10010 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10020 */   521,  521,  724,  724,  724,  724,  521,  521,  521,  346,
 /* 10030 */   521,  724,  521,  724,  237,  521,  724,  724,  521,  724,
 /* 10040 */   521,  521,  521,  724,  724,  521,  521,  724,  724,  521,
 /* 10050 */   521,  521,  521,  521,  521,  521,  521,  521,  521,  521,
 /* 10060 */   521,  724,  238,  724,   12,  724,  724,  724,  724,  724,
 /* 10070 */   724,  521,  521,  521,  521,  724,  724,  521,  521,  521,
 /* 10080 */   521,  521,  521,  521,  521,  521,  683,  724,  724,  724,
 /* 10090 */   724,  724,  724,  724,  724,  724,  724,  724,  683,  683,
 /* 10100 */   724,  724,  724,  724,  683,  683,  683,  724,  683,  724,
 /* 10110 */   683,  724,  724,  683,  724,  724,  683,  724,  683,  683,
 /* 10120 */   683,  724,  724,  683,  683,  724,  724,  683,  683,  683,
 /* 10130 */   683,  683,  683,  683,  683,  683,  683,  683,  683,  724,
 /* 10140 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  683,
 /* 10150 */   683,  683,  683,  724,  724,  683,  683,  683,  683,  683,
 /* 10160 */   683,  683,  683,  683,  505,  724,  724,  724,  724,  724,
 /* 10170 */   724,  724,  724,  724,  724,  724,  505,  505,  724,  724,
 /* 10180 */   724,  724,  505,  505,  505,  724,  505,  724,  505,  724,
 /* 10190 */    52,  505,  724,  724,  505,  724,  505,  724,  505,  724,
 /* 10200 */   724,  505,  505,  724,  724,  505,  505,  505,  505,  505,
 /* 10210 */   505,  505,  505,  505,  505,  505,  505,  724,  724,  724,
 /* 10220 */   724,  724,  724,  724,  724,  724,  724,  505,  505,  505,
 /* 10230 */   505,  724,  724,  505,  505,  505,  505,  505,  505,  505,
 /* 10240 */   505,  505,   83,  724,  724,  724,  724,  724,  724,  724,
 /* 10250 */   724,  724,  724,  724,   86,   85,  724,  724,  724,  724,
 /* 10260 */    84,   93,   51,  724,  170,  724,  256,  724,  724,  461,
 /* 10270 */   724,  724,  246,  724,  129,  526,  233,  724,  724,  232,
 /* 10280 */   231,  724,  724,  445,  444,  443,  442,  441,  440,  439,
 /* 10290 */   437,  428,  139,   43,   42,  724,  724,  724,  724,  724,
 /* 10300 */   724,  724,  724,  724,  724,  253,  424,  418,  417,  724,
 /* 10310 */   724,  413,  410,  406,  403,  402,   33,  435,  400,  398,
 /* 10320 */    83,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10330 */   724,  724,   86,   85,  724,  724,  724,  724,   84,   93,
 /* 10340 */    51,  724,  170,  724,  256,  724,  724,  461,  724,  724,
 /* 10350 */   246,  724,  129,  684,  233,  724,  724,  232,  231,  724,
 /* 10360 */   724,  445,  444,  443,  442,  441,  440,  439,  437,  428,
 /* 10370 */   139,   43,   42,  724,  724,  724,  724,  724,  724,  724,
 /* 10380 */   724,  724,  724,  253,  424,  418,  417,  724,  724,  413,
 /* 10390 */   410,  406,  403,  402,   33,  435,  400,  398,   83,  724,
 /* 10400 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10410 */    86,   85,  724,  724,  724,  724,   84,   93,   51,  724,
 /* 10420 */   170,  724,  256,  724,  724,  461,  724,  724,  246,  724,
 /* 10430 */   129,  685,  233,  724,  724,  232,  231,  724,  724,  445,
 /* 10440 */   444,  443,  442,  441,  440,  439,  437,  428,  139,   43,
 /* 10450 */    42,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10460 */   724,  253,  424,  418,  417,  724,  724,  413,  410,  406,
 /* 10470 */   403,  402,   33,  435,  400,  398,   83,  724,  724,  724,
 /* 10480 */   724,  724,  724,  724,  724,  724,  724,  724,   86,   85,
 /* 10490 */   724,  724,  724,  724,   84,   93,   51,  724,  170,  724,
 /* 10500 */   256,  724,  724,  461,  724,  724,  246,  724,  129,  525,
 /* 10510 */   233,  724,  724,  232,  231,  724,  724,  445,  444,  443,
 /* 10520 */   442,  441,  440,  439,  437,  428,  139,   43,   42,  724,
 /* 10530 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  253,
 /* 10540 */   424,  418,  417,  724,  724,  413,  410,  406,  403,  402,
 /* 10550 */    33,  435,  400,  398,  660,  724,  724,  724,  724,  724,
 /* 10560 */   724,  724,  724,  724,  724,  724,  660,  660,  724,  724,
 /* 10570 */   724,  724,  660,  660,  660,  724,  660,  724,  660,  724,
 /* 10580 */   724,  660,  724,  724,  660,  724,  660,  724,  660,  724,
 /* 10590 */   724,  660,  660,  724,  724,  660,  660,  660,  660,  660,
 /* 10600 */   660,  660,  660,  660,  660,  660,  660,  724,  724,  724,
 /* 10610 */   724,  724,  724,  724,  724,  724,  724,  660,  660,  660,
 /* 10620 */   660,  724,  724,  660,  660,  660,  660,  660,  660,  660,
 /* 10630 */   660,  660,  663,  724,  724,  724,  724,  724,  724,  724,
 /* 10640 */   724,  724,  724,  724,  663,  663,  724,  724,  724,  724,
 /* 10650 */   663,   61,  663,  724,  663,  724,  663,  724,  724,  663,
 /* 10660 */   724,  724,  663,  724,  663,  724,  663,  724,  724,  663,
 /* 10670 */   663,  724,  724,  663,  663,  663,  663,  663,  663,  663,
 /* 10680 */   663,  663,  663,  663,  663,  724,  724,  724,  724,  724,
 /* 10690 */   724,  724,  724,  724,  724,  663,  663,  663,  663,  724,
 /* 10700 */   724,  663,  663,  663,  663,  663,  663,  663,  663,  663,
 /* 10710 */   672,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10720 */   724,  724,  672,  672,  724,  724,  724,  724,  672,  672,
 /* 10730 */   672,  724,  672,  724,  672,  724,  724,  672,  724,  724,
 /* 10740 */   672,  724,  672,  724,  672,  724,  724,  672,  672,  724,
 /* 10750 */   724,  672,  672,  672,  672,  672,  672,  672,  672,  672,
 /* 10760 */   672,  672,  672,  724,  724,  724,  724,  724,  724,  724,
 /* 10770 */   724,  724,  724,  672,  421,  672,  672,  724,  724,  672,
 /* 10780 */   672,  672,  672,  672,  672,  672,  672,  672,  570,  724,
 /* 10790 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10800 */   570,  570,  724,  724,  724,  724,  570,  570,  570,  724,
 /* 10810 */   570,  724,  570,  724,  724,  570,  724,  724,  570,  724,
 /* 10820 */   570,  724,  570,  724,  724,  570,  570,  724,  724,  570,
 /* 10830 */   570,  570,  570,  570,  570,  570,  570,  570,  570,  570,
 /* 10840 */   570,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 10850 */   724,  570,  570,  570,  570,  724,  724,  570,  570,  570,
 /* 10860 */   570,  570,  570,  570,  570,  570,  507,  724,  724,  724,
 /* 10870 */   724,  724,  724,  724,  724,  724,  724,  724,  507,  507,
 /* 10880 */   724,  724,  724,  724,  507,  507,  507,  724,  261,  724,
 /* 10890 */   507,  724,  724,  507,  724,  724,  507,  724,  507,  724,
 /* 10900 */   507,  724,  724,  507,  507,  724,  724,  507,  507,  507,
 /* 10910 */   507,  507,  507,  507,  507,  507,  507,  507,  507,  724,
 /* 10920 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  507,
 /* 10930 */   507,  507,  507,  724,  724,  507,  507,  507,  507,  507,
 /* 10940 */   507,  507,  507,  507,  513,  724,  724,  724,  724,  724,
 /* 10950 */   724,  724,  724,  724,  724,  724,  513,  513,  724,  724,
 /* 10960 */   724,  724,  513,  513,  513,  724,  513,  724,  513,  724,
 /* 10970 */   724,  513,  724,  724,  513,  724,  513,  724,  513,  724,
 /* 10980 */   724,  513,  513,  724,  724,  513,  513,  513,  513,  513,
 /* 10990 */   513,  513,  513,  513,  513,  513,  513,  724,  724,  724,
 /* 11000 */   724,  724,  724,  724,  724,  724,  724,  513,  513,  513,
 /* 11010 */   513,  724,  724,  513,  513,  513,  513,  513,  513,  513,
 /* 11020 */   513,  513,   83,  724,  724,  724,  724,  724,  724,  724,
 /* 11030 */   724,  724,  724,  724,   86,   85,  724,  724,  724,  724,
 /* 11040 */    84,   93,   51,  724,  170,  724,  256,  724,  724,  461,
 /* 11050 */   724,  724,  246,  724,  129,  724,  233,  724,  724,  232,
 /* 11060 */   231,  724,  724,  445,  444,  443,  442,  441,  440,  439,
 /* 11070 */   437,  428,  139,   43,   42,  724,  724,  724,  724,  724,
 /* 11080 */   724,  724,  724,  724,  724,  253,  424,  418,  417,  724,
 /* 11090 */   724,  413,  410,  406,  403,  402,   33,  435,  400,  398,
 /* 11100 */   639,  567,  639,  567,  567,  724,  567,  567,  567,  567,
 /* 11110 */   567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
 /* 11120 */   567,  567,  724,  724,   31,  567,  567,  639,  724,  114,
 /* 11130 */   724,   95,   96,  639,  102,  100,   98,   99,   97,  101,
 /* 11140 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 11150 */   724,  724,   30,  117,  462,  279,  639,  639,  639,  639,
 /* 11160 */   639,  639,  639,  639,  639,  639,  639,  639,  641,  568,
 /* 11170 */   641,  568,  568,  724,  119,   82,   80,   81,   79,   94,
 /* 11180 */   568,  568,  568,  568,  568,  568,  568,  568,  568,  568,
 /* 11190 */   724,  724,  568,  568,  568,  641,  724,  720,  724,  720,
 /* 11200 */   720,  641,  720,  720,  720,  720,  720,  720,  720,  720,
 /* 11210 */   720,  720,  720,  720,  720,  720,  720,  720,  724,  724,
 /* 11220 */   720,  720,  720,  144,  641,  641,  641,  641,  641,  641,
 /* 11230 */   641,  641,  641,  641,  641,  641,  640,  569,  640,  569,
 /* 11240 */   569,  724,  116,   76,   74,   75,   73,   77,  569,  569,
 /* 11250 */   569,  569,  569,  569,  569,  569,  569,  569,  724,  724,
 /* 11260 */   569,  569,  569,  640,  724,  721,  724,  721,  721,  640,
 /* 11270 */   721,  721,  721,  721,  721,  721,  721,  721,  721,  721,
 /* 11280 */   721,  721,  721,  721,  721,  721,  724,  724,  721,  721,
 /* 11290 */   721,  143,  640,  640,  640,  640,  640,  640,  640,  640,
 /* 11300 */   640,  640,  640,  640,  482,  724,  724,  724,  724,  724,
 /* 11310 */   724,  724,  482,  724,  724,  724,  724,  724,  724,  724,
 /* 11320 */   724,  724,  724,  724,  482,  482,  724,  724,  724,  724,
 /* 11330 */   482,  482,  482,  724,  724,  482,  482,  724,  724,  482,
 /* 11340 */   724,  482,  482,  724,  482,  724,  482,  724,  724,  482,
 /* 11350 */   482,  724,  724,  482,  482,  482,  482,  482,  482,  482,
 /* 11360 */   482,  114,  482,   95,   96,  724,  102,  100,   98,   99,
 /* 11370 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /* 11380 */   110,  108,  724,  724,   30,  117,  462,  482,  482,  482,
 /* 11390 */   483,  724,  724,  724,  724,  724,  724,  724,  483,  724,
 /* 11400 */   229,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 11410 */   483,  483,  724,  724,  724,  724,  483,  483,  483,  724,
 /* 11420 */   724,  483,  483,  724,  724,  483,  724,  483,  483,  724,
 /* 11430 */   483,  724,  483,  724,  724,  483,  483,  724,  724,  483,
 /* 11440 */   483,  483,  483,  483,  483,  483,  483,  114,  483,   95,
 /* 11450 */    96,  724,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 11460 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 11470 */    30,  117,  462,  483,  483,  483,  484,  113,  724,  724,
 /* 11480 */   724,  724,  724,  724,  484,  724,  724,  724,  724,  724,
 /* 11490 */   724,  724,  724,  724,  724,  724,  484,  484,  724,  724,
 /* 11500 */   724,  724,  484,  484,  484,  724,  724,  484,  484,  724,
 /* 11510 */   724,  484,  724,  484,  484,  724,  484,  724,  484,  724,
 /* 11520 */   724,  484,  484,  724,  724,  484,  484,  484,  484,  484,
 /* 11530 */   484,  484,  484,  114,  484,   95,   96,  724,  102,  100,
 /* 11540 */    98,   99,   97,  101,  104,  103,  105,  107,  106,  112,
 /* 11550 */   111,  109,  110,  108,  724,  724,   30,  117,  462,  484,
 /* 11560 */   484,  484,  485,  724,  724,  215,  724,  724,  724,  724,
 /* 11570 */   485,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 11580 */   724,  724,  485,  485,  724,  724,  724,  724,  485,  485,
 /* 11590 */   485,  724,  724,  485,  485,  724,  724,  485,  724,  485,
 /* 11600 */   485,  724,  485,  724,  485,  724,  724,  485,  485,  724,
 /* 11610 */   724,  485,  485,  485,  485,  485,  485,  485,  485,  114,
 /* 11620 */   485,   95,   96,  724,  102,  100,   98,   99,   97,  101,
 /* 11630 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 11640 */   724,  724,   30,  117,  462,  485,  485,  485,  486,  724,
 /* 11650 */   724,  214,  724,  724,  724,  724,  486,  724,  724,  724,
 /* 11660 */   724,  724,  724,  724,  724,  724,  724,  724,  486,  486,
 /* 11670 */   724,  724,  724,  724,  486,  486,  486,  724,  724,  486,
 /* 11680 */   486,  724,  724,  486,  724,  486,  486,  724,  486,  724,
 /* 11690 */   486,  724,  724,  486,  486,  724,  724,  486,  486,  486,
 /* 11700 */   486,  486,  486,  486,  486,  114,  486,   95,   96,  724,
 /* 11710 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /* 11720 */   106,  112,  111,  109,  110,  108,  724,  724,   30,  117,
 /* 11730 */   462,  486,  486,  486,  487,  724,  724,  213,  724,  724,
 /* 11740 */   724,  724,  487,  724,  724,  724,  724,  724,  724,  724,
 /* 11750 */   724,  724,  724,  724,  487,  487,  724,  724,  724,  724,
 /* 11760 */   487,  487,  487,  724,  724,  487,  487,  724,  724,  487,
 /* 11770 */   724,  487,  487,  724,  487,  724,  487,  724,  724,  487,
 /* 11780 */   487,  724,  724,  487,  487,  487,  487,  487,  487,  487,
 /* 11790 */   487,  114,  487,   95,   96,  724,  102,  100,   98,   99,
 /* 11800 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /* 11810 */   110,  108,  724,  724,   30,  117,  462,  487,  487,  487,
 /* 11820 */   488,  724,  724,  212,  724,  724,  724,  724,  488,  724,
 /* 11830 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 11840 */   488,  488,  724,  724,  724,  724,  488,  488,  488,  724,
 /* 11850 */   724,  488,  488,  724,  724,  488,  724,  488,  488,  724,
 /* 11860 */   488,  724,  488,  724,  724,  488,  488,  724,  724,  488,
 /* 11870 */   488,  488,  488,  488,  488,  488,  488,  114,  488,   95,
 /* 11880 */    96,  724,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 11890 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 11900 */    30,  117,  462,  488,  488,  488,  489,  724,  724,  211,
 /* 11910 */   724,  724,  724,  724,  489,  724,  724,  724,  724,  724,
 /* 11920 */   724,  724,  724,  724,  724,  724,  489,  489,  724,  724,
 /* 11930 */   724,  724,  489,  489,  489,  724,  724,  489,  489,  724,
 /* 11940 */   724,  489,  724,  489,  489,  724,  489,  724,  489,  724,
 /* 11950 */   724,  489,  489,  724,  724,  489,  489,  489,  489,  489,
 /* 11960 */   489,  489,  489,  114,  489,   95,   96,  724,  102,  100,
 /* 11970 */    98,   99,   97,  101,  104,  103,  105,  107,  106,  112,
 /* 11980 */   111,  109,  110,  108,  724,  724,   30,  117,  462,  489,
 /* 11990 */   489,  489,  490,  724,  724,  210,  724,  724,  724,  724,
 /* 12000 */   490,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 12010 */   724,  724,  490,  490,  724,  724,  724,  724,  490,  490,
 /* 12020 */   490,  724,  724,  490,  490,  724,  724,  490,  724,  490,
 /* 12030 */   490,  724,  490,  724,  490,  724,  724,  490,  490,  724,
 /* 12040 */   724,  490,  490,  490,  490,  490,  490,  490,  490,  114,
 /* 12050 */   490,   95,   96,  724,  102,  100,   98,   99,   97,  101,
 /* 12060 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 12070 */   724,  724,   30,  117,  462,  490,  490,  490,  491,  724,
 /* 12080 */   724,  209,  724,  724,  724,  724,  491,  724,  724,  724,
 /* 12090 */   724,  724,  724,  724,  724,  724,  724,  724,  491,  491,
 /* 12100 */   724,  724,  724,  724,  491,  491,  491,  724,  724,  491,
 /* 12110 */   491,  724,  724,  491,  724,  491,  491,  724,  491,  724,
 /* 12120 */   491,  724,  724,  491,  491,  724,  724,  491,  491,  491,
 /* 12130 */   491,  491,  491,  491,  491,  114,  491,   95,   96,  724,
 /* 12140 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /* 12150 */   106,  112,  111,  109,  110,  108,  724,  724,   30,  117,
 /* 12160 */   462,  491,  491,  491,  492,  724,  724,  724,  724,  724,
 /* 12170 */   724,  724,  492,  724,  254,  724,  724,  724,  724,  724,
 /* 12180 */   724,  724,  724,  724,  492,  492,  724,  724,  724,  724,
 /* 12190 */   492,  492,  492,  724,  724,  492,  492,  724,  724,  492,
 /* 12200 */   724,  492,  492,  724,  492,  724,  492,  724,  724,  492,
 /* 12210 */   492,  724,  724,  492,  492,  492,  492,  492,  492,  492,
 /* 12220 */   492,  114,  492,   95,   96,  724,  102,  100,   98,   99,
 /* 12230 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /* 12240 */   110,  108,  724,  724,   30,  117,  462,  492,  492,  492,
 /* 12250 */   493,  724,  724,  661,  724,  724,  724,  724,  493,  724,
 /* 12260 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 12270 */   493,  493,  724,  724,  724,  724,  493,  493,  493,  724,
 /* 12280 */   724,  493,  493,  724,  724,  493,  724,  493,  493,  724,
 /* 12290 */   493,  724,  493,  724,  724,  493,  493,  724,  724,  493,
 /* 12300 */   493,  493,  493,  493,  493,  493,  493,  114,  493,   95,
 /* 12310 */    96,  724,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 12320 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 12330 */    30,  117,  462,  493,  493,  493,  494,  724,  724,  667,
 /* 12340 */   724,  724,  724,  724,  494,  724,  724,  724,  724,  724,
 /* 12350 */   724,  724,  724,  724,  724,  724,  494,  494,  724,  724,
 /* 12360 */   724,  724,  494,  494,  494,  724,  724,  494,  494,  724,
 /* 12370 */   724,  494,  724,  494,  494,  724,  494,  724,  494,  724,
 /* 12380 */   724,  494,  494,  724,  724,  494,  494,  494,  494,  494,
 /* 12390 */   494,  494,  494,  114,  494,   95,   96,  724,  102,  100,
 /* 12400 */    98,   99,   97,  101,  104,  103,  105,  107,  106,  112,
 /* 12410 */   111,  109,  110,  108,  724,  724,   30,  117,  462,  494,
 /* 12420 */   494,  494,  499,  724,  724,  670,  724,  724,  724,  724,
 /* 12430 */   499,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 12440 */   724,  724,  499,  499,  724,  724,  724,  724,  499,  499,
 /* 12450 */   499,  724,  724,  499,  499,  724,  724,  499,  724,  499,
 /* 12460 */   499,  724,  499,  724,  499,  724,  724,  499,  499,  724,
 /* 12470 */   724,  499,  499,  499,  499,  499,  499,  499,  499,  114,
 /* 12480 */   499,   95,   96,  724,  102,  100,   98,   99,   97,  101,
 /* 12490 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 12500 */   724,  724,   30,  117,  462,  499,  499,  499,  500,  724,
 /* 12510 */   724,  691,  724,  724,  724,  724,  500,  724,  724,  724,
 /* 12520 */   724,  724,  724,  724,  724,  724,  724,  724,  500,  500,
 /* 12530 */   724,  724,  724,  724,  500,  500,  500,  724,  724,  500,
 /* 12540 */   500,  724,  724,  500,  724,  500,  500,  724,  500,  724,
 /* 12550 */   500,  724,  724,  500,  500,  724,  724,  500,  500,  500,
 /* 12560 */   500,  500,  500,  500,  500,  114,  500,   95,   96,  724,
 /* 12570 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /* 12580 */   106,  112,  111,  109,  110,  108,  724,  724,   30,   78,
 /* 12590 */   449,  500,  500,  500,  509,  724,  724,  724,  724,  724,
 /* 12600 */   724,  724,  509,  724,  724,  724,  724,  724,  724,  724,
 /* 12610 */   724,  724,  724,  724,  509,  509,  724,  724,  724,  724,
 /* 12620 */   509,  509,  509,  724,  724,  509,  509,  724,  724,  509,
 /* 12630 */   724,  509,  509,  724,  509,  724,  509,  724,  724,  509,
 /* 12640 */   509,  724,  724,  509,  509,  509,  509,  509,  509,  509,
 /* 12650 */   509,  567,  509,  567,  567,  724,  567,  567,  567,  567,
 /* 12660 */   567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
 /* 12670 */   567,  567,  724,  724,   24,  567,  567,  509,  509,  509,
 /* 12680 */   508,  724,  724,  724,  724,  724,  724,  724,  508,  724,
 /* 12690 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 12700 */   508,  508,  724,  724,  724,  724,  508,  508,  508,  724,
 /* 12710 */   724,  508,  508,  724,  724,  508,  724,  508,  508,  724,
 /* 12720 */   508,  724,  508,  724,  724,  508,  508,  724,  724,  508,
 /* 12730 */   508,  508,  508,  508,  508,  508,  508,  114,  508,   95,
 /* 12740 */    96,  724,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 12750 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 12760 */    23,  117,  462,  508,  508,  508,  518,  724,  724,  724,
 /* 12770 */    72,  724,  642,  724,  518,  724,  724,  724,  724,  724,
 /* 12780 */   724,  724,  724,  724,  724,  724,  518,  518,  724,  724,
 /* 12790 */   724,  724,  518,  518,  518,  724,  724,  518,  518,  724,
 /* 12800 */   724,  518,  724,  518,  518,  724,  518,  724,  518,  724,
 /* 12810 */   724,  518,  518,  724,  724,  518,  518,  518,  518,  518,
 /* 12820 */   518,  518,  518,  724,  518,  724,  336,  335,   71,   70,
 /* 12830 */    69,   68,   67,   66,   65,   64,   63,   62,  724,  724,
 /* 12840 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  518,
 /* 12850 */   518,  518,  517,  724,  724,  724,  724,  724,  724,  724,
 /* 12860 */   517,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 12870 */   724,  724,  517,  517,  724,  724,  724,  724,  517,  517,
 /* 12880 */   517,  724,  724,  517,  517,  724,  724,  517,  724,  517,
 /* 12890 */   517,  724,  517,  724,  517,  724,  724,  517,  517,  724,
 /* 12900 */   724,  517,  517,  517,  517,  517,  517,  517,  517,  724,
 /* 12910 */   517,  724,  724,  724,  319,  724,  724,  724,  724,  724,
 /* 12920 */   724,  724,  724,  362,  724,  361,  360,  359,  724,  724,
 /* 12930 */   724,  724,  724,  724,  724,  517,  517,  517,  516,  724,
 /* 12940 */   724,  724,  236,  724,   12,  724,  516,  724,  724,  320,
 /* 12950 */   367,  724,  724,  724,  724,  724,  724,  724,  516,  516,
 /* 12960 */   724,  724,  724,  724,  516,  516,  516,  724,  724,  516,
 /* 12970 */   516,  724,  357,  516,  724,  516,  516,  724,  516,  724,
 /* 12980 */   516,  724,  724,  516,  516,  724,  724,  516,  516,  516,
 /* 12990 */   516,  516,  516,  516,  516,  724,  516,  724,  724,  724,
 /* 13000 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13010 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13020 */   724,  516,  516,  516,  480,  724,  724,  724,  724,  724,
 /* 13030 */   724,  724,   83,  724,  724,  724,  724,  724,  724,  724,
 /* 13040 */   724,  724,  724,  724,   86,   85,  724,  724,  724,  724,
 /* 13050 */    84,   93,   51,  724,  724,  136,  316,  724,  724,  378,
 /* 13060 */   724,  389,  246,  724,  125,  724,  233,  724,  724,  232,
 /* 13070 */   231,  724,  724,  445,  444,  443,  442,  441,  440,  439,
 /* 13080 */   437,  724,  137,  724,  724,  724,  724,  724,  724,  724,
 /* 13090 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13100 */   724,  724,  724,  724,  724,  724,  724,  435,  434,  432,
 /* 13110 */   481,  724,  724,  724,  724,  724,  724,  724,  481,  724,
 /* 13120 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13130 */   481,  481,  724,  724,  724,  724,  481,  481,  481,  724,
 /* 13140 */   724,  481,  481,  724,  724,  481,  724,  481,  481,  724,
 /* 13150 */   481,  724,  481,  724,  724,  481,  481,  724,  724,  481,
 /* 13160 */   481,  481,  481,  481,  481,  481,  481,  724,  481,  724,
 /* 13170 */   724,  724,  724,  319,  724,  724,  724,  724,  724,  724,
 /* 13180 */   724,  724,  362,  724,  361,  360,  359,  724,  724,  724,
 /* 13190 */   724,  724,  724,  481,  481,  481,  724,  724,  724,  724,
 /* 13200 */   724,  236,  693,   12,  724,  724,  724,  724,  320,  367,
 /* 13210 */   724,  724,  724,  724,  693,  693,  724,  724,  724,  724,
 /* 13220 */   693,  693,  693,  724,  693,  724,  693,  724,  724,  693,
 /* 13230 */   724,  358,  409,  724,  693,  724,  693,  724,  724,  693,
 /* 13240 */   693,  724,  724,  693,  693,  693,  693,  693,  693,  693,
 /* 13250 */   693,  724,  693,  693,  693,  724,  724,  724,  724,  724,
 /* 13260 */   724,  724,   83,  724,  724,  724,  724,  724,  724,  724,
 /* 13270 */   724,  724,  724,  724,   86,   85,  724,  693,  693,  693,
 /* 13280 */    84,   93,   51,  724,  700,  724,  256,  724,  724,  461,
 /* 13290 */   724,  724,  724,  724,  129,  724,  233,  724,  724,  232,
 /* 13300 */   231,  724,  724,  445,  444,  443,  442,  441,  440,  439,
 /* 13310 */   437,  724,  139,   43,   42,  724,  724,  724,  724,  724,
 /* 13320 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13330 */   724,  724,  724,  724,  724,  724,  724,  435,  434,  432,
 /* 13340 */   724,  551,  114,  551,   95,   96,  724,  102,  100,   98,
 /* 13350 */    99,   97,  101,  104,  103,  105,  107,  106,  112,  111,
 /* 13360 */   109,  110,  108,   83,  724,   30,  117,  462,  551,  724,
 /* 13370 */   724,  724,  724,  724,  551,   86,   85,  724,  724,  724,
 /* 13380 */   724,   84,   93,   51,  724,  724,  724,  256,  724,  724,
 /* 13390 */   461,  724,  724,  724,  724,  129,  724,  233,  724,  724,
 /* 13400 */   232,  231,  724,  724,  445,  444,  443,  442,  441,  440,
 /* 13410 */   439,  437,  724,  139,   43,   42,  724,  724,  724,  724,
 /* 13420 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13430 */   724,  724,  724,  724,  724,  724,  724,  724,  435,  434,
 /* 13440 */   432,  724,  118,  567,  567,  567,  567,  724,  567,  567,
 /* 13450 */   567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
 /* 13460 */   567,  567,  567,  567,  724,  724,   31,  567,  567,  724,
 /* 13470 */   724,  584,  579,  584,  584,  567,  584,  584,  584,  584,
 /* 13480 */   584,  584,  584,  584,  584,  584,  584,  584,  584,  584,
 /* 13490 */   584,  584,  724,  724,  584,  466,  584,  579,  724,  114,
 /* 13500 */   644,   95,   96,  579,  102,  100,   98,   99,   97,  101,
 /* 13510 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 13520 */   724,  724,   30,  117,  462,  644,  724,  114,  650,   95,
 /* 13530 */    96,  644,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 13540 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 13550 */    30,  117,  462,  650,  724,  114,  651,   95,   96,  650,
 /* 13560 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /* 13570 */   106,  112,  111,  109,  110,  108,  724,  724,   30,  117,
 /* 13580 */   462,  651,  724,  114,  652,   95,   96,  651,  102,  100,
 /* 13590 */    98,   99,   97,  101,  104,  103,  105,  107,  106,  112,
 /* 13600 */   111,  109,  110,  108,  724,  724,   30,  117,  462,  652,
 /* 13610 */   724,  114,  653,   95,   96,  652,  102,  100,   98,   99,
 /* 13620 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /* 13630 */   110,  108,  724,  724,   30,  117,  462,  653,  724,  114,
 /* 13640 */   654,   95,   96,  653,  102,  100,   98,   99,   97,  101,
 /* 13650 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 13660 */   724,  724,   30,  117,  462,  654,  724,  114,  655,   95,
 /* 13670 */    96,  654,  102,  100,   98,   99,   97,  101,  104,  103,
 /* 13680 */   105,  107,  106,  112,  111,  109,  110,  108,  724,  724,
 /* 13690 */    30,  117,  462,  655,  724,  114,  656,   95,   96,  655,
 /* 13700 */   102,  100,   98,   99,   97,  101,  104,  103,  105,  107,
 /* 13710 */   106,  112,  111,  109,  110,  108,  724,  724,   30,  117,
 /* 13720 */   462,  656,  724,  114,  657,   95,   96,  656,  102,  100,
 /* 13730 */    98,   99,   97,  101,  104,  103,  105,  107,  106,  112,
 /* 13740 */   111,  109,  110,  108,  724,  724,   30,  117,  462,  657,
 /* 13750 */   724,  114,  658,   95,   96,  657,  102,  100,   98,   99,
 /* 13760 */    97,  101,  104,  103,  105,  107,  106,  112,  111,  109,
 /* 13770 */   110,  108,  724,  724,   30,  117,  462,  658,  724,  114,
 /* 13780 */   659,   95,   96,  658,  102,  100,   98,   99,   97,  101,
 /* 13790 */   104,  103,  105,  107,  106,  112,  111,  109,  110,  108,
 /* 13800 */   707,  724,   30,  117,  462,  659,  724,  724,  724,  724,
 /* 13810 */   724,  659,  707,  707,  724,  724,  724,  724,  707,  707,
 /* 13820 */   707,  724,  724,  724,  707,  724,  724,  707,  707,  724,
 /* 13830 */   724,  724,  724,  724,  707,  724,  724,  707,  707,  724,
 /* 13840 */   724,  707,  707,  707,  707,  707,  707,  707,  707,  724,
 /* 13850 */   724,  707,  707,  724,   83,  724,  724,  724,  724,  724,
 /* 13860 */   724,  724,  724,  724,  724,  724,   86,   85,  724,  724,
 /* 13870 */   724,  724,   84,   93,   51,  707,  707,  707,  256,  724,
 /* 13880 */   724,  461,  704,  724,  724,  724,  724,  724,  233,  724,
 /* 13890 */   724,  232,  231,  724,  724,  445,  444,  443,  442,  441,
 /* 13900 */   440,  439,  437,  724,  724,   43,   42,  724,  724,  724,
 /* 13910 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 13920 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  435,
 /* 13930 */   434,  432,  724,  724,  114,  572,   95,   96,  724,  102,
 /* 13940 */   100,   98,   99,   97,  101,  104,  103,  105,  107,  106,
 /* 13950 */   112,  111,  109,  110,  108,  724,  724,   30,  117,  462,
 /* 13960 */   724,  724,  114,  573,   95,   96,  572,  102,  100,   98,
 /* 13970 */    99,   97,  101,  104,  103,  105,  107,  106,  112,  111,
 /* 13980 */   109,  110,  108,  724,  724,   30,  117,  462,  724,  724,
 /* 13990 */   114,  724,   95,   96,  573,  102,  100,   98,   99,   97,
 /* 14000 */   101,  104,  103,  105,  107,  106,  112,  111,  109,  110,
 /* 14010 */   108,  724,  724,   30,  117,  462,  259,   83,  724,  724,
 /* 14020 */   724,  724,  724,  724,  327,  724,  724,  724,  724,   86,
 /* 14030 */    85,  724,  724,  724,  724,   84,   93,   51,  724,  724,
 /* 14040 */   724,  230,  724,  724,  461,  586,  724,  724,  724,  724,
 /* 14050 */   724,  233,  586,  724,  232,  231,  724,  724,  445,  444,
 /* 14060 */   443,  442,  441,  440,  439,  437,  724,  724,  724,  724,
 /* 14070 */   724,   83,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 14080 */   724,  724,  724,   86,   85,  724,  724,  724,  724,   84,
 /* 14090 */    93,   51,  435,  434,  432,  256,  724,  724,  461,  724,
 /* 14100 */   724,  724,  724,  724,  724,  233,  724,  724,  232,  231,
 /* 14110 */   724,  724,  445,  444,  443,  442,  441,  440,  439,  437,
 /* 14120 */   724,  724,   43,   42,  724,  724,  724,  724,  724,  724,
 /* 14130 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 14140 */   724,  724,  724,  724,  724,  724,  435,  434,  432,  724,
 /* 14150 */   724,  580,  724,  580,  580,  724,  580,  580,  580,  580,
 /* 14160 */   580,  580,  580,  580,  580,  580,  580,  580,  580,  580,
 /* 14170 */   580,  580,  724,  724,  580,  580,  580,  582,  724,  581,
 /* 14180 */   724,  581,  581,  724,  581,  581,  581,  581,  581,  581,
 /* 14190 */   581,  581,  581,  581,  581,  581,  581,  581,  581,  581,
 /* 14200 */    83,  724,  581,  581,  581,  583,  724,  724,  724,  724,
 /* 14210 */   724,  724,   86,   85,  724,  724,  724,  724,   84,   93,
 /* 14220 */    51,  724,  724,  724,  292,  724,  724,  461,  578,  724,
 /* 14230 */   724,  724,  724,  724,  233,  724,  724,  232,  231,  724,
 /* 14240 */   724,  445,  444,  443,  442,  441,  440,  439,  437,  724,
 /* 14250 */   724,  724,  724,  724,  724,  724,  724,  724,  275,  724,
 /* 14260 */   724,  276,  274,  479,  272,  271,  270,  269,  478,  477,
 /* 14270 */   476,  475,  264,  380,  341,  435,  434,  432,    3,  724,
 /* 14280 */   724,  124,  315,  724,   83,  724,  724,    1,  724,  141,
 /* 14290 */   724,  724,  724,  724,  724,  724,   86,   85,  724,  724,
 /* 14300 */   724,  724,   84,   93,   51,  724,  562,  724,  230,  724,
 /* 14310 */   236,  461,   12,  724,  724,  724,  724,  724,  233,  724,
 /* 14320 */   724,  232,  231,  724,  724,  445,  444,  443,  442,  441,
 /* 14330 */   440,  439,  437,  724,  724,  724,  724,  724,   83,  724,
 /* 14340 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 14350 */    86,   85,  724,  724,  724,  724,   84,   93,   51,  435,
 /* 14360 */   434,  432,  292,  724,  724,  461,  576,  724,  724,  724,
 /* 14370 */   724,  724,  233,  724,  724,  232,  231,  724,  724,  445,
 /* 14380 */   444,  443,  442,  441,  440,  439,  437,  724,  724,  724,
 /* 14390 */   724,  724,  677,  724,  724,  724,  724,  724,  724,  724,
 /* 14400 */   724,  724,  724,  724,  677,  677,  724,  724,  724,  724,
 /* 14410 */   677,  677,  677,  435,  434,  432,  677,  724,  724,  677,
 /* 14420 */   724,  724,  724,  724,  724,  724,  677,  724,  724,  677,
 /* 14430 */   677,  724,  724,  677,  677,  677,  677,  677,  677,  677,
 /* 14440 */   677,  724,  724,  724,  724,  724,  706,  724,  724,  724,
 /* 14450 */   724,  724,  724,  724,  724,  724,  724,  724,  706,  706,
 /* 14460 */   724,  724,  724,  724,  706,  706,  706,  677,  677,  677,
 /* 14470 */   706,  724,  724,  706,  724,  724,  724,  724,  724,  724,
 /* 14480 */   706,  724,  724,  706,  706,  724,  724,  706,  706,  706,
 /* 14490 */   706,  706,  706,  706,  706,  724,  724,  724,  724,  724,
 /* 14500 */    83,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 14510 */   724,  724,   86,   85,  724,  724,  724,  724,   84,   93,
 /* 14520 */    51,  706,  706,  706,  230,  724,  724,  461,  724,  724,
 /* 14530 */   724,  724,  724,  724,  233,  724,  724,  232,  231,  724,
 /* 14540 */   724,  445,  444,  443,  442,  441,  440,  439,  437,  724,
 /* 14550 */   724,  724,  724,  724,   83,  724,  724,  724,  724,  724,
 /* 14560 */   724,  724,  724,  724,  724,  724,   86,   85,  724,  724,
 /* 14570 */   724,  724,   84,   93,   51,  435,  434,  432,  256,  724,
 /* 14580 */   724,  461,  724,  724,  724,  724,  724,  724,  233,  724,
 /* 14590 */   724,  232,  231,  724,  724,  445,  444,  443,  442,  441,
 /* 14600 */   440,  439,  437,  724,  724,  724,  724,  724,  724,  724,
 /* 14610 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  724,
 /* 14620 */   724,  724,  724,  724,  724,  724,  724,  724,  724,  435,
 /* 14630 */   434,  432,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     0,   30,    2,    3,    4,    5,    6,    7,    8,    9,
 /*    10 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*    20 */    20,   21,   22,   23,   24,   30,   26,   27,   28,   29,
 /*    30 */    30,   31,   32,  110,   34,   35,   36,   37,   38,   27,
 /*    40 */    40,   41,   42,   43,   32,   45,   46,  112,  113,   49,
 /*    50 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*    60 */    60,  138,    5,  140,  141,  142,  143,  158,  159,  160,
 /*    70 */   161,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*    80 */    80,   81,   82,   83,   84,   85,    0,   30,    2,    3,
 /*    90 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   100 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   110 */    24,   30,   26,   27,   28,   29,   30,   31,   32,  110,
 /*   120 */    34,   35,   36,   37,   38,  110,   40,   41,   42,   43,
 /*   130 */    29,   45,   46,   32,   30,   49,   50,   51,   52,   53,
 /*   140 */    54,   55,   56,   57,   58,   59,   60,  138,   30,  140,
 /*   150 */   141,  142,  143,  138,   32,  140,  141,   71,   72,   73,
 /*   160 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*   170 */    84,   85,    0,    5,    2,    3,    4,    5,    6,    7,
 /*   180 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   190 */    18,   19,   20,   21,   22,   23,   24,   32,   26,   27,
 /*   200 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*   210 */    38,   43,   40,   41,   42,   43,   29,   45,   46,   32,
 /*   220 */    30,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*   230 */    58,   59,   60,  138,   35,  140,  141,  142,  143,   40,
 /*   240 */    41,   87,   88,   71,   72,   73,   74,   75,   76,   77,
 /*   250 */    78,   79,   80,   81,   82,   83,   84,   85,    0,    5,
 /*   260 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   270 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*   280 */    22,   23,   24,   32,   26,   27,   28,   29,   30,   31,
 /*   290 */    32,  110,   34,   35,   36,   37,   38,   43,   40,   41,
 /*   300 */    42,   43,   29,   45,   46,   32,   32,   49,   50,   51,
 /*   310 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*   320 */    35,  140,  141,  142,  143,   40,   41,   30,   27,   71,
 /*   330 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*   340 */    82,   83,   84,   85,    0,    5,    2,    3,    4,    5,
 /*   350 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   360 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   36,
 /*   370 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*   380 */    36,   37,   38,   43,   40,   41,   42,   43,    5,   45,
 /*   390 */    46,   28,   42,   49,   50,   51,   52,   53,   54,   55,
 /*   400 */    56,   57,   58,   59,   60,  138,   35,  140,  141,  142,
 /*   410 */   143,   40,   41,   30,   32,   71,   72,   73,   74,   75,
 /*   420 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*   430 */     0,   43,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   440 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   450 */    20,   21,   22,   23,   24,   43,   26,   27,   28,   29,
 /*   460 */    30,   31,   32,  110,   34,   35,   36,   37,   38,    5,
 /*   470 */    40,   41,   42,   43,    5,   45,   46,   27,   30,   49,
 /*   480 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*   490 */    60,  138,   35,  140,  141,  142,  143,   40,   41,   30,
 /*   500 */    36,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*   510 */    80,   81,   82,   83,   84,   85,    0,   41,    2,    3,
 /*   520 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   530 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   540 */    24,   30,   26,   27,   28,   29,   30,   31,   32,  110,
 /*   550 */    34,   35,   36,   37,   38,    5,   40,   41,   42,   43,
 /*   560 */     5,   45,   46,   30,   30,   49,   50,   51,   52,   53,
 /*   570 */    54,   55,   56,   57,   58,   59,   60,  138,   35,  140,
 /*   580 */   141,  142,  143,   40,   41,   30,   36,   71,   72,   73,
 /*   590 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*   600 */    84,   85,    0,   30,    2,    3,    4,    5,    6,    7,
 /*   610 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   620 */    18,   19,   20,   21,   22,   23,   24,   30,   26,   27,
 /*   630 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*   640 */    38,    5,   40,   41,   42,   43,    5,   45,   46,   30,
 /*   650 */    30,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*   660 */    58,   59,   60,  138,   35,  140,  141,  142,  143,   40,
 /*   670 */    41,   30,   36,   71,   72,   73,   74,   75,   76,   77,
 /*   680 */    78,   79,   80,   81,   82,   83,   84,   85,    0,   30,
 /*   690 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   700 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*   710 */    22,   23,   24,   30,   26,   27,   28,   29,   30,   31,
 /*   720 */    32,  110,   34,   35,   36,   37,   38,  110,   40,   41,
 /*   730 */    42,   43,   29,   45,   46,   32,   32,   49,   50,   51,
 /*   740 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*   750 */     5,  140,  141,  142,  143,  138,    3,  140,    5,   71,
 /*   760 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*   770 */    82,   83,   84,   85,    0,   30,    2,    3,    4,    5,
 /*   780 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   790 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   28,
 /*   800 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*   810 */    36,   37,   38,   30,   40,   41,   42,   43,   42,   45,
 /*   820 */    46,   38,   39,   49,   50,   51,   52,   53,   54,   55,
 /*   830 */    56,   57,   58,   59,   60,  138,    5,  140,  141,  142,
 /*   840 */   143,  154,  155,  156,   43,   71,   72,   73,   74,   75,
 /*   850 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*   860 */     0,   30,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   870 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*   880 */    20,   21,   22,   23,   24,   27,   26,   27,   28,   29,
 /*   890 */    30,   31,   32,   41,   34,   35,   36,   37,   38,    5,
 /*   900 */    40,   41,   42,   43,    5,   45,   46,   27,   27,   49,
 /*   910 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*   920 */    60,  158,  159,  160,   27,  162,  163,   75,   76,   30,
 /*   930 */    36,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*   940 */    80,   81,   82,   83,   84,   85,    0,   27,    2,    3,
 /*   950 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   960 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   970 */    24,   27,   26,   27,   28,   29,   30,   31,   32,  110,
 /*   980 */    34,   35,   36,   37,   38,    5,   40,   41,   42,   43,
 /*   990 */    32,   45,   46,   27,   36,   49,   50,   51,   52,   53,
 /*  1000 */    54,   55,   56,   57,   58,   59,   60,  138,    5,  140,
 /*  1010 */    30,   29,   30,   36,  145,   33,   36,   71,   72,   73,
 /*  1020 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*  1030 */    84,   85,    0,   30,    2,    3,    4,    5,    6,    7,
 /*  1040 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  1050 */    18,   19,   20,   21,   22,   23,   24,   27,   26,   27,
 /*  1060 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*  1070 */    38,    5,   40,   41,   42,   43,   36,   45,   46,   27,
 /*  1080 */    27,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  1090 */    58,   59,   60,  138,    5,  140,   30,   29,   30,   36,
 /*  1100 */   145,   33,   36,   71,   72,   73,   74,   75,   76,   77,
 /*  1110 */    78,   79,   80,   81,   82,   83,   84,   85,    0,   30,
 /*  1120 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1130 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  1140 */    22,   23,   24,   27,   26,   27,   28,   29,   30,   31,
 /*  1150 */    32,  110,   34,   35,   36,   37,   38,    5,   40,   41,
 /*  1160 */    42,   43,   36,   45,   46,   36,   43,   49,   50,   51,
 /*  1170 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  1180 */     5,  140,   30,   29,   30,   40,  145,   33,   36,   71,
 /*  1190 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*  1200 */    82,   83,   84,   85,    0,   30,    2,    3,    4,    5,
 /*  1210 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  1220 */    16,   17,   18,   19,   20,   21,   22,   23,   24,    5,
 /*  1230 */    26,   27,   28,   29,   30,   31,   32,    5,   34,   35,
 /*  1240 */    36,   37,   38,    5,   40,   41,   42,   43,    5,   45,
 /*  1250 */    46,    3,   32,   49,   50,   51,   52,   53,   54,   55,
 /*  1260 */    56,   57,   58,   59,   60,   29,   30,   43,   36,   33,
 /*  1270 */    29,   30,   34,   30,   33,   71,   72,   73,   74,   75,
 /*  1280 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  1290 */     0,   36,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1300 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  1310 */    20,   21,   22,   23,   24,   27,   26,   27,   28,   29,
 /*  1320 */    30,   31,   32,   41,   34,   35,   36,   37,   38,    5,
 /*  1330 */    40,   41,   42,   43,  111,   45,   46,   27,   36,   49,
 /*  1340 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  1350 */    60,   29,   30,   27,    3,   33,    5,   75,   76,  136,
 /*  1360 */    36,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*  1370 */    80,   81,   82,   83,   84,   85,    0,   27,    2,    3,
 /*  1380 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  1390 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1400 */    24,   36,   26,   27,   28,   29,   30,   31,   32,  110,
 /*  1410 */    34,   35,   36,   37,   38,  110,   40,   41,   42,   43,
 /*  1420 */    27,   45,   46,   27,   36,   49,   50,   51,   52,   53,
 /*  1430 */    54,   55,   56,   57,   58,   59,   60,  138,    3,  140,
 /*  1440 */     5,   38,    3,  138,    5,  140,   41,   71,   72,   73,
 /*  1450 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*  1460 */    84,   85,    0,   27,    2,    3,    4,    5,    6,    7,
 /*  1470 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  1480 */    18,   19,   20,   21,   22,   23,   24,   27,   26,   27,
 /*  1490 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*  1500 */    38,  110,   40,   41,   42,   43,   36,   45,   46,   27,
 /*  1510 */    30,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  1520 */    58,   59,   60,  138,  111,  140,   36,   36,   27,  138,
 /*  1530 */    32,  140,   36,   71,   72,   73,   74,   75,   76,   77,
 /*  1540 */    78,   79,   80,   81,   82,   83,   84,   85,    0,  136,
 /*  1550 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1560 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  1570 */    22,   23,   24,   30,   26,   27,   28,   29,   30,   31,
 /*  1580 */    32,  110,   34,   35,   36,   37,   38,  110,   40,   41,
 /*  1590 */    42,   43,   30,   45,   46,   30,   27,   49,   50,   51,
 /*  1600 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  1610 */   111,  140,   36,   27,   36,  138,   34,  140,   41,   71,
 /*  1620 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*  1630 */    82,   83,   84,   85,    0,  136,    2,    3,    4,    5,
 /*  1640 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  1650 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   36,
 /*  1660 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*  1670 */    36,   37,   38,  110,   40,   41,   42,   43,   36,   45,
 /*  1680 */    46,   36,   36,   49,   50,   51,   52,   53,   54,   55,
 /*  1690 */    56,   57,   58,   59,   60,  138,  111,  140,   36,   32,
 /*  1700 */    30,  138,   27,  140,   32,   71,   72,   73,   74,   75,
 /*  1710 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  1720 */     0,  136,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1730 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  1740 */    20,   21,   22,   23,   24,   36,   26,   27,   28,   29,
 /*  1750 */    30,   31,   32,  110,   34,   35,   36,   37,   38,  110,
 /*  1760 */    40,   41,   42,   43,   30,   45,   46,   36,   36,   49,
 /*  1770 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  1780 */    60,  138,  111,  140,  116,   41,  135,  138,   42,  140,
 /*  1790 */   137,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*  1800 */    80,   81,   82,   83,   84,   85,    0,  136,    2,    3,
 /*  1810 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  1820 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  1830 */    24,   32,   26,   27,   28,   29,   30,   31,   32,  110,
 /*  1840 */    34,   35,   36,   37,   38,  110,   40,   41,   42,   43,
 /*  1850 */   137,   45,   46,  137,  103,   49,   50,   51,   52,   53,
 /*  1860 */    54,   55,   56,   57,   58,   59,   60,  138,  144,  140,
 /*  1870 */   144,  144,  104,  138,  104,  140,  104,   71,   72,   73,
 /*  1880 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*  1890 */    84,   85,    0,   32,    2,    3,    4,    5,    6,    7,
 /*  1900 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  1910 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  1920 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*  1930 */    38,  110,   40,   41,   42,   43,  177,   45,   46,  177,
 /*  1940 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  1950 */    58,   59,   60,  138,  177,  140,  177,  177,  177,  138,
 /*  1960 */   177,  140,  177,   71,   72,   73,   74,   75,   76,   77,
 /*  1970 */    78,   79,   80,   81,   82,   83,   84,   85,    0,  177,
 /*  1980 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  1990 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  2000 */    22,   23,   24,  177,   26,   27,   28,   29,   30,   31,
 /*  2010 */    32,  110,   34,   35,   36,   37,   38,  110,   40,   41,
 /*  2020 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  2030 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  2040 */   177,  140,  177,  177,  177,  138,  177,  140,  177,   71,
 /*  2050 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*  2060 */    82,   83,   84,   85,    0,  177,    2,    3,    4,    5,
 /*  2070 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  2080 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  2090 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*  2100 */    36,   37,   38,  110,   40,   41,   42,   43,  177,   45,
 /*  2110 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  2120 */    56,   57,   58,   59,   60,  138,  177,  140,  177,  177,
 /*  2130 */   177,  138,  177,  140,  177,   71,   72,   73,   74,   75,
 /*  2140 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  2150 */     0,  177,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  2160 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  2170 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  2180 */    30,   31,   32,  110,   34,   35,   36,   37,   38,  110,
 /*  2190 */    40,   41,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  2200 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  2210 */    60,  138,  177,  140,  177,  177,  177,  138,  177,  140,
 /*  2220 */   177,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*  2230 */    80,   81,   82,   83,   84,   85,    0,  177,    2,    3,
 /*  2240 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  2250 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  2260 */    24,  177,   26,   27,   28,   29,   30,   31,   32,  110,
 /*  2270 */    34,   35,   36,   37,   38,  110,   40,   41,   42,   43,
 /*  2280 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  2290 */    54,   55,   56,   57,   58,   59,   60,  138,  177,  140,
 /*  2300 */   177,  177,  177,  138,  177,  140,  177,   71,   72,   73,
 /*  2310 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*  2320 */    84,   85,    0,  177,    2,    3,    4,    5,    6,    7,
 /*  2330 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  2340 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  2350 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*  2360 */    38,  110,   40,   41,   42,   43,  177,   45,   46,  177,
 /*  2370 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  2380 */    58,   59,   60,  138,  177,  140,  177,  177,  177,  138,
 /*  2390 */   177,  140,  177,   71,   72,   73,   74,   75,   76,   77,
 /*  2400 */    78,   79,   80,   81,   82,   83,   84,   85,    0,  177,
 /*  2410 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  2420 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  2430 */    22,   23,   24,  177,   26,   27,   28,   29,   30,   31,
 /*  2440 */    32,  110,   34,   35,   36,   37,   38,  110,   40,   41,
 /*  2450 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  2460 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  2470 */   177,  140,  177,  177,  177,  138,  177,  140,  177,   71,
 /*  2480 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*  2490 */    82,   83,   84,   85,    0,  177,    2,    3,    4,    5,
 /*  2500 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  2510 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  2520 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*  2530 */    36,   37,   38,  110,   40,   41,   42,   43,  177,   45,
 /*  2540 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  2550 */    56,   57,   58,   59,   60,  138,  177,  140,  177,  177,
 /*  2560 */   177,  138,  177,  140,  177,   71,   72,   73,   74,   75,
 /*  2570 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  2580 */     0,  177,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  2590 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  2600 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  2610 */    30,   31,   32,  110,   34,   35,   36,   37,   38,  110,
 /*  2620 */    40,   41,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  2630 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  2640 */    60,  138,  177,  140,  177,  177,  177,  138,  177,  140,
 /*  2650 */   177,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*  2660 */    80,   81,   82,   83,   84,   85,    0,  177,    2,    3,
 /*  2670 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  2680 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  2690 */    24,  177,   26,   27,   28,   29,   30,   31,   32,  110,
 /*  2700 */    34,   35,   36,   37,   38,  110,   40,   41,   42,   43,
 /*  2710 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  2720 */    54,   55,   56,   57,   58,   59,   60,  138,  177,  140,
 /*  2730 */   177,  177,  177,  138,  177,  140,  177,   71,   72,   73,
 /*  2740 */    74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
 /*  2750 */    84,   85,    0,  177,    2,    3,    4,    5,    6,    7,
 /*  2760 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  2770 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  2780 */    28,   29,   30,   31,   32,  110,   34,   35,   36,   37,
 /*  2790 */    38,  110,   40,   41,   42,   43,  177,   45,   46,  177,
 /*  2800 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  2810 */    58,   59,   60,  138,  177,  140,  177,  177,  177,  138,
 /*  2820 */   177,  140,  177,   71,   72,   73,   74,   75,   76,   77,
 /*  2830 */    78,   79,   80,   81,   82,   83,   84,   85,    0,  177,
 /*  2840 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  2850 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  2860 */    22,   23,   24,  177,   26,   27,   28,   29,   30,   31,
 /*  2870 */    32,  110,   34,   35,   36,   37,   38,  110,   40,   41,
 /*  2880 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  2890 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  2900 */   177,  140,  177,  177,  177,  138,  177,  140,  177,   71,
 /*  2910 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   81,
 /*  2920 */    82,   83,   84,   85,    0,  177,    2,    3,    4,    5,
 /*  2930 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  2940 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  2950 */    26,   27,   28,   29,   30,   31,   32,  110,   34,   35,
 /*  2960 */    36,   37,   38,  110,   40,   41,   42,   43,  177,   45,
 /*  2970 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  2980 */    56,   57,   58,   59,   60,  138,  177,  140,  177,  177,
 /*  2990 */   177,  138,  177,  140,  177,   71,   72,   73,   74,   75,
 /*  3000 */    76,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  3010 */     0,  177,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  3020 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  3030 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  3040 */    30,   31,   32,  110,   34,   35,   36,   37,   38,  110,
 /*  3050 */    40,   41,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  3060 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  3070 */    60,  138,  177,  140,  177,  177,  177,  138,  177,  140,
 /*  3080 */   177,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*  3090 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  3100 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  3110 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  3120 */    27,   28,   29,   30,    3,   32,    5,   34,   35,   36,
 /*  3130 */   110,   38,    3,   40,    5,   42,   43,    5,   45,   46,
 /*  3140 */     5,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  3150 */    57,   58,   59,   60,  177,   34,  177,  177,  138,   30,
 /*  3160 */   140,  177,   30,  177,   71,   72,   73,   74,   36,   34,
 /*  3170 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  3180 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  3190 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  3200 */    24,  177,   26,   27,   28,   29,   30,    3,   32,    5,
 /*  3210 */    34,   35,   36,  107,   38,    5,   40,  111,   42,   43,
 /*  3220 */     5,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  3230 */    54,   55,   56,   57,   58,   59,   60,  177,   34,  177,
 /*  3240 */    30,  177,  136,  177,  177,  177,   36,   71,   72,   73,
 /*  3250 */    74,   36,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  3260 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  3270 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  3280 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  3290 */    41,   32,  107,   34,   35,   36,  111,   38,  110,   40,
 /*  3300 */     3,   42,   43,    5,   45,   46,  177,  177,   49,   50,
 /*  3310 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  3320 */   177,  136,  177,  177,   75,   76,  138,   30,  140,  177,
 /*  3330 */    71,   72,   73,   74,   36,  177,   77,   78,   79,   80,
 /*  3340 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  3350 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  3360 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  3370 */    28,   29,   30,   41,   32,  107,   34,   35,   36,  111,
 /*  3380 */    38,  110,   40,  177,   42,   43,    5,   45,   46,  177,
 /*  3390 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  3400 */    58,   59,   60,  177,  136,  177,  177,   75,  177,  138,
 /*  3410 */   177,  140,  177,   71,   72,   73,   74,   36,  177,   77,
 /*  3420 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  3430 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  3440 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  3450 */   177,   26,   27,   28,   29,   30,  177,   32,  110,   34,
 /*  3460 */    35,   36,  110,   38,    5,   40,  177,   42,   43,    5,
 /*  3470 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  3480 */    55,   56,   57,   58,   59,   60,  138,  177,  140,  177,
 /*  3490 */   138,  177,  140,  177,  177,   36,   71,   72,   73,   74,
 /*  3500 */    36,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  3510 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  3520 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  3530 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  3540 */    32,  110,   34,   35,   36,  110,   38,  177,   40,  177,
 /*  3550 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  3560 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  138,
 /*  3570 */   177,  140,  177,  138,  177,  140,  177,  177,  177,   71,
 /*  3580 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  3590 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  3600 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  3610 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  3620 */    29,   30,  177,   32,  110,   34,   35,   36,  110,   38,
 /*  3630 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  3640 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  3650 */    59,   60,  138,  177,  140,  177,  138,  177,  140,  177,
 /*  3660 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  3670 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  3680 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  3690 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  3700 */    26,   27,   28,   29,   30,  177,   32,  110,   34,   35,
 /*  3710 */    36,  110,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  3720 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  3730 */    56,   57,   58,   59,   60,  138,  177,  140,  177,  138,
 /*  3740 */   177,  140,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  3750 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  3760 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  3770 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  3780 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  3790 */   110,   34,   35,   36,  110,   38,  177,   40,  177,   42,
 /*  3800 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  3810 */    53,   54,   55,   56,   57,   58,   59,   60,  138,  177,
 /*  3820 */   140,  177,  138,  177,  140,  177,  177,  177,   71,   72,
 /*  3830 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  3840 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  3850 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  3860 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  3870 */    30,  177,   32,  110,   34,   35,   36,  110,   38,  177,
 /*  3880 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  3890 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  3900 */    60,  138,  177,  140,  177,  138,  177,  140,  177,  177,
 /*  3910 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  3920 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  3930 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  3940 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  3950 */    27,   28,   29,   30,  177,   32,  110,   34,   35,   36,
 /*  3960 */   110,   38,  177,   40,  177,   42,   43,  177,   45,   46,
 /*  3970 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  3980 */    57,   58,   59,   60,  138,  177,  140,  177,  138,  177,
 /*  3990 */   140,  177,  177,  177,   71,   72,   73,   74,  177,  177,
 /*  4000 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  4010 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  4020 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  4030 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  110,
 /*  4040 */    34,   35,   36,  110,   38,  177,   40,  177,   42,   43,
 /*  4050 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  4060 */    54,   55,   56,   57,   58,   59,   60,  138,  177,  140,
 /*  4070 */   177,  138,  177,  140,  177,  177,  177,   71,   72,   73,
 /*  4080 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  4090 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  4100 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  4110 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  4120 */   177,   32,  110,   34,   35,   36,  110,   38,  177,   40,
 /*  4130 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /*  4140 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  4150 */   138,  177,  140,  177,  138,  177,  140,  177,  177,  177,
 /*  4160 */    71,   72,   73,   74,  177,  177,   77,   78,   79,   80,
 /*  4170 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  4180 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  4190 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  4200 */    28,   29,   30,  177,   32,  110,   34,   35,   36,  110,
 /*  4210 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  4220 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  4230 */    58,   59,   60,  138,  177,  140,  177,  138,  177,  140,
 /*  4240 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  4250 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  4260 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  4270 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  4280 */   177,   26,   27,   28,   29,   30,  177,   32,  110,   34,
 /*  4290 */    35,   36,  177,   38,  177,   40,  177,   42,   43,  177,
 /*  4300 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  4310 */    55,   56,   57,   58,   59,   60,  138,  177,  140,  177,
 /*  4320 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  4330 */   177,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  4340 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  4350 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  4360 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  4370 */    32,  177,   34,   35,   36,  177,   38,  177,   40,  177,
 /*  4380 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  4390 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /*  4400 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /*  4410 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  4420 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  4430 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  4440 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  4450 */    29,   30,  177,   32,  177,   34,   35,   36,  177,   38,
 /*  4460 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  4470 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  4480 */    59,   60,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  4490 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  4500 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  4510 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  4520 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  4530 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  4540 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  4550 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  4560 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  4570 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  4580 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  4590 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  4600 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  4610 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  4620 */   177,   34,   35,   36,  177,   38,  177,   40,  177,   42,
 /*  4630 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  4640 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  177,
 /*  4650 */   177,  177,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  4660 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  4670 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  4680 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  4690 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  4700 */    30,  177,   32,  177,   34,   35,   36,  177,   38,  177,
 /*  4710 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  4720 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  4730 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  4740 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  4750 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  4760 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  4770 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  4780 */    27,   28,   29,   30,  177,   32,  177,   34,   35,   36,
 /*  4790 */   177,   38,  177,   40,  177,   42,   43,  177,   45,   46,
 /*  4800 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  4810 */    57,   58,   59,   60,  177,  177,  177,  177,  177,  177,
 /*  4820 */   177,  177,  177,  177,   71,   72,   73,   74,  177,  177,
 /*  4830 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  4840 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  4850 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  4860 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  177,
 /*  4870 */    34,   35,   36,  177,   38,  177,   40,  177,   42,   43,
 /*  4880 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  4890 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /*  4900 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /*  4910 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  4920 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  4930 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  4940 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  4950 */   177,   32,  177,   34,   35,   36,  177,   38,  177,   40,
 /*  4960 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /*  4970 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  4980 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  4990 */    71,   72,   73,   74,  177,  177,   77,   78,   79,   80,
 /*  5000 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  5010 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  5020 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  5030 */    28,   29,   30,  177,   32,  177,   34,   35,   36,  177,
 /*  5040 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  5050 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  5060 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /*  5070 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  5080 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  5090 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  5100 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  5110 */   177,   26,   27,   28,   29,   30,  177,   32,  177,   34,
 /*  5120 */    35,   36,  177,   38,  177,   40,  177,   42,   43,  177,
 /*  5130 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  5140 */    55,   56,   57,   58,   59,   60,  177,  177,  177,  177,
 /*  5150 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  5160 */   177,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  5170 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  5180 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  5190 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  5200 */    32,  177,   34,   35,   36,  177,   38,  177,   40,  177,
 /*  5210 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  5220 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /*  5230 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /*  5240 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  5250 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  5260 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  5270 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  5280 */    29,   30,  177,   32,  177,   34,   35,   36,  177,   38,
 /*  5290 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  5300 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  5310 */    59,   60,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  5320 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  5330 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  5340 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  5350 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  5360 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  5370 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  5380 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  5390 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  5400 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  5410 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  5420 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  5430 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  5440 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  5450 */   177,   34,   35,   36,  177,   38,  177,   40,  177,   42,
 /*  5460 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  5470 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  177,
 /*  5480 */   177,  177,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  5490 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  5500 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  5510 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  5520 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  5530 */    30,  177,   32,  177,   34,   35,   36,  177,   38,  177,
 /*  5540 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  5550 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  5560 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  5570 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  5580 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  5590 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  5600 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  5610 */    27,   28,   29,   30,  177,   32,  177,   34,   35,   36,
 /*  5620 */   177,   38,  177,   40,  177,   42,   43,  177,   45,   46,
 /*  5630 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  5640 */    57,   58,   59,   60,  177,  177,  177,  177,  177,  177,
 /*  5650 */   177,  177,  177,  177,   71,   72,   73,   74,  177,  177,
 /*  5660 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  5670 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  5680 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  5690 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  177,
 /*  5700 */    34,   35,   36,  177,   38,  177,   40,  177,   42,   43,
 /*  5710 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  5720 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /*  5730 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /*  5740 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  5750 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  5760 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  5770 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  5780 */   177,   32,  177,   34,   35,   36,  177,   38,  177,   40,
 /*  5790 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /*  5800 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  5810 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  5820 */    71,   72,   73,   74,  177,  177,   77,   78,   79,   80,
 /*  5830 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  5840 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  5850 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  5860 */    28,   29,   30,  177,   32,  177,   34,   35,   36,  177,
 /*  5870 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  5880 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  5890 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /*  5900 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  5910 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  5920 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  5930 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  5940 */   177,   26,   27,   28,   29,   30,  177,   32,  177,   34,
 /*  5950 */    35,   36,  177,   38,  177,   40,  177,   42,   43,  177,
 /*  5960 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  5970 */    55,   56,   57,   58,   59,   60,  177,  177,  177,  177,
 /*  5980 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  5990 */   177,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  6000 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  6010 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  6020 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  6030 */    32,  177,   34,   35,   36,  177,   38,  177,   40,  177,
 /*  6040 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  6050 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /*  6060 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /*  6070 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  6080 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  6090 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  6100 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  6110 */    29,   30,  177,   32,  177,   34,   35,   36,  177,   38,
 /*  6120 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  6130 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  6140 */    59,   60,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  6150 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  6160 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  6170 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  6180 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  6190 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  6200 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  6210 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  6220 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  6230 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  6240 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  6250 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  6260 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  6270 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  6280 */   177,   34,   35,   36,  177,   38,  177,   40,  177,   42,
 /*  6290 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  6300 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  177,
 /*  6310 */   177,  177,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  6320 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  6330 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  6340 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  6350 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  6360 */    30,  177,   32,  177,   34,   35,   36,  177,   38,  177,
 /*  6370 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  6380 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  6390 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  6400 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  6410 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  6420 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  6430 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  6440 */    27,   28,   29,   30,  177,   32,  177,   34,   35,   36,
 /*  6450 */   177,   38,  177,   40,  177,   42,   43,  177,   45,   46,
 /*  6460 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  6470 */    57,   58,   59,   60,  177,  177,  177,  177,  177,  177,
 /*  6480 */   177,  177,  177,  177,   71,   72,   73,   74,  177,  177,
 /*  6490 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  6500 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  6510 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  6520 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  177,
 /*  6530 */    34,   35,   36,  177,   38,  177,   40,  177,   42,   43,
 /*  6540 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  6550 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /*  6560 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /*  6570 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  6580 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  6590 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  6600 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  6610 */   177,   32,  177,   34,   35,   36,  177,   38,  177,   40,
 /*  6620 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /*  6630 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  6640 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  6650 */    71,   72,   73,   74,  177,  177,   77,   78,   79,   80,
 /*  6660 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  6670 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  6680 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  6690 */    28,   29,   30,  177,   32,  177,   34,   35,   36,  177,
 /*  6700 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  6710 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  6720 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /*  6730 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  6740 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  6750 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  6760 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  6770 */   177,   26,   27,   28,   29,   30,  177,   32,  177,   34,
 /*  6780 */    35,   36,  177,   38,  177,   40,  177,   42,   43,  177,
 /*  6790 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  6800 */    55,   56,   57,   58,   59,   60,  177,  177,  177,  177,
 /*  6810 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  6820 */   177,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  6830 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  6840 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  6850 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  6860 */    32,  177,   34,   35,   36,  177,   38,  177,   40,  177,
 /*  6870 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  6880 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /*  6890 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /*  6900 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  6910 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  6920 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  6930 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  6940 */    29,   30,  177,   32,  177,   34,   35,   36,  177,   38,
 /*  6950 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  6960 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  6970 */    59,   60,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  6980 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  6990 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  7000 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  7010 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  7020 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  7030 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  7040 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  7050 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  7060 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  7070 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  7080 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  7090 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  7100 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  7110 */   177,   34,   35,   36,  177,   38,  177,   40,  177,   42,
 /*  7120 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  7130 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  177,
 /*  7140 */   177,  177,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  7150 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  7160 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  7170 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  7180 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  7190 */    30,  177,   32,  177,   34,   35,   36,  177,   38,  177,
 /*  7200 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  7210 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  7220 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  7230 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  7240 */    80,   81,   82,   83,   84,   85,    3,    4,    5,    6,
 /*  7250 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*  7260 */    17,   18,   19,   20,   21,   22,   23,   24,  177,   26,
 /*  7270 */    27,   28,   29,   30,  177,   32,  177,   34,   35,   36,
 /*  7280 */   177,   38,  177,   40,  177,   42,   43,  177,   45,   46,
 /*  7290 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  7300 */    57,   58,   59,   60,  177,  177,  177,  177,  177,  177,
 /*  7310 */   177,  177,  177,  177,   71,   72,   73,   74,  177,  177,
 /*  7320 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    3,
 /*  7330 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  7340 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  7350 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  177,
 /*  7360 */    34,   35,   36,  177,   38,  177,   40,  177,   42,   43,
 /*  7370 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  7380 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /*  7390 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /*  7400 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /*  7410 */    84,   85,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  7420 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /*  7430 */    21,   22,   23,   24,  177,   26,   27,   28,   29,   30,
 /*  7440 */   177,   32,  177,   34,   35,   36,  177,   38,  177,   40,
 /*  7450 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /*  7460 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  7470 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  7480 */    71,   72,   73,   74,  177,  177,   77,   78,   79,   80,
 /*  7490 */    81,   82,   83,   84,   85,    3,    4,    5,    6,    7,
 /*  7500 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  7510 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  7520 */    28,   29,   30,  177,   32,  177,   34,   35,   36,  177,
 /*  7530 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  7540 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  7550 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /*  7560 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  7570 */    78,   79,   80,   81,   82,   83,   84,   85,    3,    4,
 /*  7580 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  7590 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  7600 */   177,   26,   27,   28,   29,   30,  177,   32,  177,   34,
 /*  7610 */    35,   36,  177,   38,  177,   40,  177,   42,   43,  177,
 /*  7620 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  7630 */    55,   56,   57,   58,   59,   60,  177,  177,  177,  177,
 /*  7640 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  7650 */   177,  177,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  7660 */    85,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*  7670 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /*  7680 */    22,   23,   24,  177,   26,   27,   28,   29,   30,  177,
 /*  7690 */    32,  177,   34,   35,   36,  177,   38,  177,   40,  177,
 /*  7700 */    42,   43,  177,   45,   46,  177,  177,   49,   50,   51,
 /*  7710 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /*  7720 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /*  7730 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /*  7740 */    82,   83,   84,   85,    3,    4,    5,    6,    7,    8,
 /*  7750 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  7760 */    19,   20,   21,   22,   23,   24,  177,   26,   27,   28,
 /*  7770 */    29,   30,  177,   32,  177,   34,   35,   36,  177,   38,
 /*  7780 */   177,   40,  177,   42,   43,  177,   45,   46,  177,  177,
 /*  7790 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  7800 */    59,   60,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  7810 */   177,  177,   71,   72,   73,   74,  177,  177,   77,   78,
 /*  7820 */    79,   80,   81,   82,   83,   84,   85,    3,    4,    5,
 /*  7830 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  7840 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  7850 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  7860 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  7870 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  7880 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  7890 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  7900 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  7910 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  7920 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  7930 */    23,   24,  177,   26,   27,   28,   29,   30,  177,   32,
 /*  7940 */   177,   34,   35,   36,  177,   38,  177,   40,  177,   42,
 /*  7950 */    43,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  7960 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  177,
 /*  7970 */   177,  177,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  7980 */    73,   74,  177,  177,   77,   78,   79,   80,   81,   82,
 /*  7990 */    83,   84,   85,    3,    4,    5,    6,    7,    8,    9,
 /*  8000 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /*  8010 */    20,   21,   22,   23,   24,  177,   26,   27,   28,   29,
 /*  8020 */    30,  177,   32,  177,   34,   35,   36,  177,   38,  177,
 /*  8030 */    40,  177,   42,   43,  177,   45,   46,  177,  177,   49,
 /*  8040 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /*  8050 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  8060 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /*  8070 */    80,   81,   82,   83,   84,   85,    4,    5,    6,    7,
 /*  8080 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*  8090 */    18,   19,   20,   21,   22,   23,   24,  177,   26,   27,
 /*  8100 */    28,   29,   30,  177,   32,  177,   34,   35,   36,  177,
 /*  8110 */    38,  177,   40,  177,   42,   43,  177,   45,   46,  177,
 /*  8120 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  8130 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /*  8140 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /*  8150 */    78,   79,   80,   81,   82,   83,   84,   85,    4,    5,
 /*  8160 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*  8170 */    16,   17,   18,   19,   20,   21,   22,   23,   24,  177,
 /*  8180 */    26,   27,   28,   29,   30,  177,   32,  177,   34,   35,
 /*  8190 */    36,  177,   38,  177,   40,  177,   42,   43,  177,   45,
 /*  8200 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /*  8210 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /*  8220 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /*  8230 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /*  8240 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  8250 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*  8260 */    24,  177,   26,   27,   28,   29,   30,  177,   32,  177,
 /*  8270 */    34,   35,   36,  177,   38,  177,   40,  177,   42,   43,
 /*  8280 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /*  8290 */    54,   55,   56,   57,   58,   59,   60,    3,  105,    5,
 /*  8300 */   177,  177,    3,  110,    5,  177,  177,   71,   72,   73,
 /*  8310 */    74,  177,   86,   77,   78,   79,   80,   81,   82,   83,
 /*  8320 */    84,   85,  177,  177,   30,  177,  100,  177,   34,   30,
 /*  8330 */    36,  138,  139,  140,  108,   36,  110,  177,  177,  177,
 /*  8340 */   114,  115,  177,  117,  177,  119,  120,  121,  122,  123,
 /*  8350 */   124,  125,  126,  127,  128,  129,  130,  131,  132,  133,
 /*  8360 */   134,    3,  177,    5,  138,  177,  140,  177,  177,  177,
 /*  8370 */   177,  145,  146,  147,  148,  149,  150,  151,  152,  153,
 /*  8380 */   177,   86,  177,  157,  177,  177,  177,  177,   30,  177,
 /*  8390 */   164,  165,  166,  167,   36,  100,  177,  177,  172,  173,
 /*  8400 */   174,  175,  176,  108,  177,  110,  177,  177,  177,  114,
 /*  8410 */   115,  177,  117,  177,  119,  120,  121,  122,  123,  124,
 /*  8420 */   125,  126,  127,  128,  129,  130,  131,  132,  133,  134,
 /*  8430 */   177,  177,  177,  138,  177,  140,  177,  177,  177,  177,
 /*  8440 */   145,  146,  147,  148,  149,  150,  151,  152,  153,  177,
 /*  8450 */   177,   86,  157,  177,  177,  177,  177,  177,  177,  164,
 /*  8460 */   165,  166,  167,  177,  177,  100,  177,  172,  173,  174,
 /*  8470 */   175,  176,  177,  108,  177,  110,  177,  177,  177,  114,
 /*  8480 */   115,  177,  117,  177,  119,  120,  121,  122,  123,  124,
 /*  8490 */   125,  126,  127,  128,  129,  130,  131,  132,  133,  134,
 /*  8500 */   177,  177,  177,  138,  177,  140,  177,  177,  177,  177,
 /*  8510 */   145,  146,  147,  148,  149,  150,  151,  152,  153,  177,
 /*  8520 */    86,  177,  157,  177,  177,  177,  177,  177,  177,  164,
 /*  8530 */   165,  166,  167,  177,  100,  177,  177,  172,  173,  174,
 /*  8540 */   175,  176,  108,  177,  110,  177,  177,  177,  114,  115,
 /*  8550 */   177,  117,  177,  119,  120,  121,  122,  123,  124,  125,
 /*  8560 */   126,  127,  128,  129,  130,  131,  132,  133,  134,  177,
 /*  8570 */   177,  177,  138,  177,  140,  177,  177,  177,  177,  145,
 /*  8580 */   146,  147,  148,  149,  150,  151,  152,  153,  177,  177,
 /*  8590 */    86,  157,  177,  177,  177,  177,  177,  177,  164,  165,
 /*  8600 */   166,  167,  177,  177,  100,  177,  172,  173,  174,  175,
 /*  8610 */   176,  177,  108,  177,  110,  177,  177,  177,  114,  115,
 /*  8620 */   177,  117,  177,  119,  120,  121,  122,  123,  124,  125,
 /*  8630 */   126,  127,  128,  129,  130,  131,  132,  133,  134,  177,
 /*  8640 */   177,  177,  138,  177,  140,  177,  177,  177,  177,  145,
 /*  8650 */   146,  147,  148,  149,  150,  151,  152,  153,  177,   86,
 /*  8660 */   177,  157,  177,  177,  177,  177,  177,  177,  164,  165,
 /*  8670 */   166,  167,  177,  100,  177,  177,  172,  173,  174,  175,
 /*  8680 */   176,  108,  177,  110,  177,  177,  177,  114,  115,  177,
 /*  8690 */   117,  177,  119,  120,  121,  122,  123,  124,  125,  126,
 /*  8700 */   127,  128,  129,  130,  131,  132,  133,  134,  177,  177,
 /*  8710 */   177,  138,  177,  140,  177,  177,  177,  177,  145,  146,
 /*  8720 */   147,  148,  149,  150,  151,  152,  153,  177,  177,   86,
 /*  8730 */   157,  177,  177,  177,  177,  177,  177,  164,  165,  166,
 /*  8740 */   167,  177,  177,  100,  177,  172,  173,  174,  175,  176,
 /*  8750 */   177,  108,  177,  110,  177,  177,  177,  114,  115,  177,
 /*  8760 */   117,  177,  119,  120,  121,  122,  123,  124,  125,  126,
 /*  8770 */   127,  128,  129,  130,  131,  132,  133,  134,  177,  177,
 /*  8780 */   177,  138,  177,  140,  177,  177,  177,  177,  145,  146,
 /*  8790 */   147,  148,  149,  150,  151,  152,  153,  177,   86,  177,
 /*  8800 */   157,  177,  177,  177,  177,  177,  177,  164,  165,  166,
 /*  8810 */   167,  177,  100,  177,  177,  172,  173,  174,  175,  176,
 /*  8820 */   108,  177,  110,  177,  177,  177,  114,  115,  177,  117,
 /*  8830 */   177,  119,  120,  121,  122,  123,  124,  125,  126,  127,
 /*  8840 */   128,  129,  130,  131,  132,  133,  134,  177,  177,  177,
 /*  8850 */   138,  177,  140,  177,  177,  177,  177,  145,  146,  147,
 /*  8860 */   148,  149,  150,  151,  152,  153,  177,  177,   86,  157,
 /*  8870 */   177,  177,  177,  177,  177,  177,  164,  165,  166,  167,
 /*  8880 */   177,  177,  100,  177,  172,  173,  174,  175,  176,  177,
 /*  8890 */   108,  177,  110,  177,  177,  177,  114,  115,  177,  117,
 /*  8900 */   177,  119,  120,  121,  122,  123,  124,  125,  126,  127,
 /*  8910 */   128,  129,  130,  131,  132,  133,  134,  177,  177,  177,
 /*  8920 */   138,  177,  140,  177,  177,  177,  177,  145,  146,  147,
 /*  8930 */   148,  149,  150,  151,  152,  153,  177,   86,  177,  157,
 /*  8940 */   177,  177,  177,  177,  177,  177,  164,  165,  166,  167,
 /*  8950 */   177,  100,  177,  177,  172,  173,  174,  175,  176,  108,
 /*  8960 */   177,  110,  177,  177,  177,  114,  115,  177,  117,  177,
 /*  8970 */   119,  120,  121,  122,  123,  124,  125,  126,  127,  128,
 /*  8980 */   129,  130,  131,  132,  133,  134,  177,  177,  177,  138,
 /*  8990 */   177,  140,  177,  177,  177,  177,  145,  146,  147,  148,
 /*  9000 */   149,  150,  151,  152,  153,  177,  177,   86,  157,  177,
 /*  9010 */   177,  177,  177,  177,  177,  164,  165,  166,  167,  177,
 /*  9020 */   177,  100,  177,  172,  173,  174,  175,  176,  177,  108,
 /*  9030 */   177,  110,  177,  177,  177,  114,  115,  177,  117,  177,
 /*  9040 */   119,  120,  121,  122,  123,  124,  125,  126,  127,  128,
 /*  9050 */   129,  130,  131,  132,  133,  134,  177,  177,  177,  138,
 /*  9060 */   177,  140,  177,  177,  177,  177,  145,  146,  147,  148,
 /*  9070 */   149,  150,  151,  152,  153,  177,   86,  177,  157,  177,
 /*  9080 */   177,  177,  177,  177,  177,  164,  165,  166,  167,  177,
 /*  9090 */   100,  177,  177,  172,  173,  174,  175,  176,  177,  177,
 /*  9100 */   110,  177,  177,  177,  114,  115,  177,  117,  118,  119,
 /*  9110 */   120,  121,  122,  123,  124,  125,  126,  127,  128,  129,
 /*  9120 */   130,  131,  132,  133,  134,  177,  177,  177,  138,  177,
 /*  9130 */   140,  177,  177,  177,  177,  145,  146,  147,  148,  149,
 /*  9140 */   150,  151,  152,  153,  105,  177,  177,  157,  177,  110,
 /*  9150 */   177,  177,  177,  105,  164,  165,  166,  167,  110,  177,
 /*  9160 */   177,  177,  172,  173,  174,  175,  176,  105,    5,  177,
 /*  9170 */   177,    8,  110,  177,  177,  177,  177,  138,  177,  140,
 /*  9180 */   177,  177,  177,   20,   21,  177,  138,  177,  140,   26,
 /*  9190 */    27,   28,  177,   30,  177,   32,  177,   34,   35,   36,
 /*  9200 */   138,   38,  140,   40,  177,   42,   43,  177,   45,   46,
 /*  9210 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  9220 */    57,   58,   59,   60,  177,   86,  177,  177,  177,  177,
 /*  9230 */   177,  177,  177,  177,   71,   72,   73,   74,  177,  100,
 /*  9240 */    77,   78,   79,   80,   81,   82,   83,   84,   85,  110,
 /*  9250 */   177,  177,  177,  114,  115,  177,  117,  177,  119,  120,
 /*  9260 */   121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*  9270 */   131,  132,  133,  134,  177,  177,  177,  138,  177,  140,
 /*  9280 */   177,  177,  177,  177,  145,  146,  147,  148,  149,  150,
 /*  9290 */   151,  152,  153,  177,  177,  177,  157,  177,  177,  177,
 /*  9300 */   177,  177,  177,  164,  165,  166,  167,  100,  177,  177,
 /*  9310 */   177,  172,  173,  174,  175,  176,  177,  110,  177,  177,
 /*  9320 */   177,  114,  115,  177,  117,  118,  119,  120,  121,  122,
 /*  9330 */   123,  124,  125,  126,  127,  128,  129,  130,  131,  132,
 /*  9340 */   133,  134,  177,  177,  177,  138,  177,  140,  177,  177,
 /*  9350 */   177,  177,  145,  146,  147,  148,  149,  150,  151,  152,
 /*  9360 */   153,  177,  177,  177,  157,  177,  177,  177,  177,  177,
 /*  9370 */   177,  164,  165,  166,  167,  177,  177,  177,  100,  172,
 /*  9380 */   173,  174,  175,  176,  177,  177,  177,  177,  110,  177,
 /*  9390 */   177,  177,  114,  115,  177,  117,  118,  119,  120,  121,
 /*  9400 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*  9410 */   132,  133,  134,  177,  177,  177,  138,  177,  140,  177,
 /*  9420 */   177,  177,  177,  145,  146,  147,  148,  149,  150,  151,
 /*  9430 */   152,  153,  105,  105,  177,  157,  177,  110,  110,  177,
 /*  9440 */   177,  105,  164,  165,  166,  167,  110,  177,  177,  177,
 /*  9450 */   172,  173,  174,  175,  176,  177,  177,  177,  177,    8,
 /*  9460 */   177,  177,  177,  177,  177,  138,  138,  140,  140,  177,
 /*  9470 */   177,   20,   21,  177,  138,  177,  140,   26,   27,   28,
 /*  9480 */   177,   30,  177,   32,  177,  110,   35,  177,  177,   38,
 /*  9490 */   177,   40,   41,   42,  177,  177,   45,   46,  123,  124,
 /*  9500 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  9510 */    59,   60,  177,  138,  177,  140,  177,  177,  177,  177,
 /*  9520 */   145,  146,   71,   72,   73,   74,   75,   76,   77,   78,
 /*  9530 */    79,   80,   81,   82,   83,   84,   85,    8,  177,  177,
 /*  9540 */   177,  177,  177,  177,  177,  170,  171,  177,  177,   20,
 /*  9550 */    21,  177,  177,  177,  177,   26,   27,   28,  177,   30,
 /*  9560 */   177,   32,  177,  110,   35,  177,  177,   38,  177,   40,
 /*  9570 */    41,   42,  177,  177,   45,   46,  123,  124,   49,   50,
 /*  9580 */    51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
 /*  9590 */   177,  138,  177,  140,  177,  177,  177,  177,  145,  146,
 /*  9600 */    71,   72,   73,   74,   75,   76,   77,   78,   79,   80,
 /*  9610 */    81,   82,   83,   84,   85,    8,  177,  177,  177,  177,
 /*  9620 */   177,  177,  177,  170,  177,  177,  177,   20,   21,  177,
 /*  9630 */   177,  177,  177,   26,   27,   28,  105,   30,  177,   32,
 /*  9640 */   177,  110,   35,  177,  177,   38,  177,   40,   41,   42,
 /*  9650 */   177,  177,   45,   46,  177,  177,   49,   50,   51,   52,
 /*  9660 */    53,   54,   55,   56,   57,   58,   59,   60,  177,  138,
 /*  9670 */   177,  140,  177,  177,  177,  177,  177,  177,   71,   72,
 /*  9680 */    73,   74,   75,   76,   77,   78,   79,   80,   81,   82,
 /*  9690 */    83,   84,   85,    8,  177,  177,  177,  177,  177,  177,
 /*  9700 */   177,  177,  177,  177,  177,   20,   21,  177,  177,  177,
 /*  9710 */   177,   26,   27,   28,  105,   30,  177,   32,  177,  110,
 /*  9720 */    35,  177,  177,   38,  177,   40,   41,   42,  177,  177,
 /*  9730 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /*  9740 */    55,   56,   57,   58,   59,   60,  177,  138,  177,  140,
 /*  9750 */   177,  177,  177,  177,  177,  177,   71,   72,   73,   74,
 /*  9760 */    75,   76,   77,   78,   79,   80,   81,   82,   83,   84,
 /*  9770 */    85,    8,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  9780 */   177,  177,  177,   20,   21,  177,  177,  177,  177,   26,
 /*  9790 */    27,   28,  105,   30,  177,   32,  177,  110,   35,  177,
 /*  9800 */   177,   38,  177,   40,   41,   42,  177,  177,   45,   46,
 /*  9810 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /*  9820 */    57,   58,   59,   60,  177,  138,  177,  140,  177,  177,
 /*  9830 */   177,  177,  177,  177,   71,   72,   73,   74,   75,   76,
 /*  9840 */    77,   78,   79,   80,   81,   82,   83,   84,   85,    8,
 /*  9850 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /*  9860 */   177,   20,   21,  177,  177,  177,  177,   26,   27,   28,
 /*  9870 */   105,   30,  177,   32,  177,  110,   35,  177,  177,   38,
 /*  9880 */   177,   40,   41,   42,  177,  177,   45,   46,  177,  177,
 /*  9890 */    49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
 /*  9900 */    59,   60,  177,  138,  105,  140,  177,  177,  177,  110,
 /*  9910 */   177,  177,   71,   72,   73,   74,   75,   76,   77,   78,
 /*  9920 */    79,   80,   81,   82,   83,   84,   85,    5,  105,  177,
 /*  9930 */     8,  177,  177,  110,  177,  177,  177,  138,  177,  140,
 /*  9940 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /*  9950 */    28,  105,   30,  177,   32,  177,  110,   35,  177,  177,
 /*  9960 */    38,  138,   40,  140,   42,  177,  177,   45,   46,  177,
 /*  9970 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /*  9980 */    58,   59,   60,  177,  138,  177,  140,  177,  177,  177,
 /*  9990 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /* 10000 */    78,   79,   80,   81,   82,   83,   84,   85,    8,  177,
 /* 10010 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10020 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  105,
 /* 10030 */    30,  177,   32,  177,  110,   35,  177,  177,   38,  177,
 /* 10040 */    40,   41,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 10050 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /* 10060 */    60,  177,  138,  177,  140,  177,  177,  177,  177,  177,
 /* 10070 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /* 10080 */    80,   81,   82,   83,   84,   85,    8,  177,  177,  177,
 /* 10090 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 10100 */   177,  177,  177,  177,   26,   27,   28,  177,   30,  177,
 /* 10110 */    32,  177,  177,   35,  177,  177,   38,  177,   40,   41,
 /* 10120 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 10130 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /* 10140 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /* 10150 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /* 10160 */    82,   83,   84,   85,    8,  177,  177,  177,  177,  177,
 /* 10170 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 10180 */   177,  177,   26,   27,   28,  177,   30,  177,   32,  177,
 /* 10190 */    34,   35,  177,  177,   38,  177,   40,  177,   42,  177,
 /* 10200 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 10210 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /* 10220 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /* 10230 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /* 10240 */    84,   85,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 10250 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 10260 */    26,   27,   28,  177,   30,  177,   32,  177,  177,   35,
 /* 10270 */   177,  177,   38,  177,   40,   41,   42,  177,  177,   45,
 /* 10280 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 10290 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /* 10300 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /* 10310 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /* 10320 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10330 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 10340 */    28,  177,   30,  177,   32,  177,  177,   35,  177,  177,
 /* 10350 */    38,  177,   40,   41,   42,  177,  177,   45,   46,  177,
 /* 10360 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /* 10370 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /* 10380 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /* 10390 */    78,   79,   80,   81,   82,   83,   84,   85,    8,  177,
 /* 10400 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10410 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 10420 */    30,  177,   32,  177,  177,   35,  177,  177,   38,  177,
 /* 10430 */    40,   41,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 10440 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /* 10450 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10460 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /* 10470 */    80,   81,   82,   83,   84,   85,    8,  177,  177,  177,
 /* 10480 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 10490 */   177,  177,  177,  177,   26,   27,   28,  177,   30,  177,
 /* 10500 */    32,  177,  177,   35,  177,  177,   38,  177,   40,   41,
 /* 10510 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 10520 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /* 10530 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /* 10540 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /* 10550 */    82,   83,   84,   85,    8,  177,  177,  177,  177,  177,
 /* 10560 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 10570 */   177,  177,   26,   27,   28,  177,   30,  177,   32,  177,
 /* 10580 */   177,   35,  177,  177,   38,  177,   40,  177,   42,  177,
 /* 10590 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 10600 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /* 10610 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /* 10620 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /* 10630 */    84,   85,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 10640 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 10650 */    26,   27,   28,  177,   30,  177,   32,  177,  177,   35,
 /* 10660 */   177,  177,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 10670 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 10680 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /* 10690 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /* 10700 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /* 10710 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10720 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 10730 */    28,  177,   30,  177,   32,  177,  177,   35,  177,  177,
 /* 10740 */    38,  177,   40,  177,   42,  177,  177,   45,   46,  177,
 /* 10750 */   177,   49,   50,   51,   52,   53,   54,   55,   56,   57,
 /* 10760 */    58,   59,   60,  177,  177,  177,  177,  177,  177,  177,
 /* 10770 */   177,  177,  177,   71,   72,   73,   74,  177,  177,   77,
 /* 10780 */    78,   79,   80,   81,   82,   83,   84,   85,    8,  177,
 /* 10790 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10800 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 10810 */    30,  177,   32,  177,  177,   35,  177,  177,   38,  177,
 /* 10820 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 10830 */    50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
 /* 10840 */    60,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 10850 */   177,   71,   72,   73,   74,  177,  177,   77,   78,   79,
 /* 10860 */    80,   81,   82,   83,   84,   85,    8,  177,  177,  177,
 /* 10870 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 10880 */   177,  177,  177,  177,   26,   27,   28,  177,   30,  177,
 /* 10890 */    32,  177,  177,   35,  177,  177,   38,  177,   40,  177,
 /* 10900 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 10910 */    52,   53,   54,   55,   56,   57,   58,   59,   60,  177,
 /* 10920 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   71,
 /* 10930 */    72,   73,   74,  177,  177,   77,   78,   79,   80,   81,
 /* 10940 */    82,   83,   84,   85,    8,  177,  177,  177,  177,  177,
 /* 10950 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 10960 */   177,  177,   26,   27,   28,  177,   30,  177,   32,  177,
 /* 10970 */   177,   35,  177,  177,   38,  177,   40,  177,   42,  177,
 /* 10980 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 10990 */    54,   55,   56,   57,   58,   59,   60,  177,  177,  177,
 /* 11000 */   177,  177,  177,  177,  177,  177,  177,   71,   72,   73,
 /* 11010 */    74,  177,  177,   77,   78,   79,   80,   81,   82,   83,
 /* 11020 */    84,   85,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 11030 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 11040 */    26,   27,   28,  177,   30,  177,   32,  177,  177,   35,
 /* 11050 */   177,  177,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 11060 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 11070 */    56,   57,   58,   59,   60,  177,  177,  177,  177,  177,
 /* 11080 */   177,  177,  177,  177,  177,   71,   72,   73,   74,  177,
 /* 11090 */   177,   77,   78,   79,   80,   81,   82,   83,   84,   85,
 /* 11100 */     3,    4,    5,    6,    7,  177,    9,   10,   11,   12,
 /* 11110 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 11120 */    23,   24,  177,  177,   27,   28,   29,   30,  177,    4,
 /* 11130 */   177,    6,    7,   36,    9,   10,   11,   12,   13,   14,
 /* 11140 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 11150 */   177,  177,   27,   28,   29,   30,   59,   60,   61,   62,
 /* 11160 */    63,   64,   65,   66,   67,   68,   69,   70,    3,    4,
 /* 11170 */     5,    6,    7,  177,    9,   10,   11,   12,   13,   14,
 /* 11180 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 11190 */   177,  177,   27,   28,   29,   30,  177,    4,  177,    6,
 /* 11200 */     7,   36,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 11210 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 11220 */    27,   28,   29,   30,   59,   60,   61,   62,   63,   64,
 /* 11230 */    65,   66,   67,   68,   69,   70,    3,    4,    5,    6,
 /* 11240 */     7,  177,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 11250 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 11260 */    27,   28,   29,   30,  177,    4,  177,    6,    7,   36,
 /* 11270 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 11280 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 11290 */    29,   30,   59,   60,   61,   62,   63,   64,   65,   66,
 /* 11300 */    67,   68,   69,   70,    0,  177,  177,  177,  177,  177,
 /* 11310 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 11320 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 11330 */    26,   27,   28,  177,  177,   31,   32,  177,  177,   35,
 /* 11340 */   177,   37,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 11350 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 11360 */    56,    4,   58,    6,    7,  177,    9,   10,   11,   12,
 /* 11370 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 11380 */    23,   24,  177,  177,   27,   28,   29,   83,   84,   85,
 /* 11390 */     0,  177,  177,  177,  177,  177,  177,  177,    8,  177,
 /* 11400 */    43,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 11410 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 11420 */   177,   31,   32,  177,  177,   35,  177,   37,   38,  177,
 /* 11430 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 11440 */    50,   51,   52,   53,   54,   55,   56,    4,   58,    6,
 /* 11450 */     7,  177,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 11460 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 11470 */    27,   28,   29,   83,   84,   85,    0,   34,  177,  177,
 /* 11480 */   177,  177,  177,  177,    8,  177,  177,  177,  177,  177,
 /* 11490 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 11500 */   177,  177,   26,   27,   28,  177,  177,   31,   32,  177,
 /* 11510 */   177,   35,  177,   37,   38,  177,   40,  177,   42,  177,
 /* 11520 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 11530 */    54,   55,   56,    4,   58,    6,    7,  177,    9,   10,
 /* 11540 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 11550 */    21,   22,   23,   24,  177,  177,   27,   28,   29,   83,
 /* 11560 */    84,   85,    0,  177,  177,   36,  177,  177,  177,  177,
 /* 11570 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 11580 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 11590 */    28,  177,  177,   31,   32,  177,  177,   35,  177,   37,
 /* 11600 */    38,  177,   40,  177,   42,  177,  177,   45,   46,  177,
 /* 11610 */   177,   49,   50,   51,   52,   53,   54,   55,   56,    4,
 /* 11620 */    58,    6,    7,  177,    9,   10,   11,   12,   13,   14,
 /* 11630 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 11640 */   177,  177,   27,   28,   29,   83,   84,   85,    0,  177,
 /* 11650 */   177,   36,  177,  177,  177,  177,    8,  177,  177,  177,
 /* 11660 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 11670 */   177,  177,  177,  177,   26,   27,   28,  177,  177,   31,
 /* 11680 */    32,  177,  177,   35,  177,   37,   38,  177,   40,  177,
 /* 11690 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 11700 */    52,   53,   54,   55,   56,    4,   58,    6,    7,  177,
 /* 11710 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 11720 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 11730 */    29,   83,   84,   85,    0,  177,  177,   36,  177,  177,
 /* 11740 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 11750 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 11760 */    26,   27,   28,  177,  177,   31,   32,  177,  177,   35,
 /* 11770 */   177,   37,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 11780 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 11790 */    56,    4,   58,    6,    7,  177,    9,   10,   11,   12,
 /* 11800 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 11810 */    23,   24,  177,  177,   27,   28,   29,   83,   84,   85,
 /* 11820 */     0,  177,  177,   36,  177,  177,  177,  177,    8,  177,
 /* 11830 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 11840 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 11850 */   177,   31,   32,  177,  177,   35,  177,   37,   38,  177,
 /* 11860 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 11870 */    50,   51,   52,   53,   54,   55,   56,    4,   58,    6,
 /* 11880 */     7,  177,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 11890 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 11900 */    27,   28,   29,   83,   84,   85,    0,  177,  177,   36,
 /* 11910 */   177,  177,  177,  177,    8,  177,  177,  177,  177,  177,
 /* 11920 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 11930 */   177,  177,   26,   27,   28,  177,  177,   31,   32,  177,
 /* 11940 */   177,   35,  177,   37,   38,  177,   40,  177,   42,  177,
 /* 11950 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 11960 */    54,   55,   56,    4,   58,    6,    7,  177,    9,   10,
 /* 11970 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 11980 */    21,   22,   23,   24,  177,  177,   27,   28,   29,   83,
 /* 11990 */    84,   85,    0,  177,  177,   36,  177,  177,  177,  177,
 /* 12000 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 12010 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 12020 */    28,  177,  177,   31,   32,  177,  177,   35,  177,   37,
 /* 12030 */    38,  177,   40,  177,   42,  177,  177,   45,   46,  177,
 /* 12040 */   177,   49,   50,   51,   52,   53,   54,   55,   56,    4,
 /* 12050 */    58,    6,    7,  177,    9,   10,   11,   12,   13,   14,
 /* 12060 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 12070 */   177,  177,   27,   28,   29,   83,   84,   85,    0,  177,
 /* 12080 */   177,   36,  177,  177,  177,  177,    8,  177,  177,  177,
 /* 12090 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 12100 */   177,  177,  177,  177,   26,   27,   28,  177,  177,   31,
 /* 12110 */    32,  177,  177,   35,  177,   37,   38,  177,   40,  177,
 /* 12120 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 12130 */    52,   53,   54,   55,   56,    4,   58,    6,    7,  177,
 /* 12140 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 12150 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 12160 */    29,   83,   84,   85,    0,  177,  177,  177,  177,  177,
 /* 12170 */   177,  177,    8,  177,   43,  177,  177,  177,  177,  177,
 /* 12180 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 12190 */    26,   27,   28,  177,  177,   31,   32,  177,  177,   35,
 /* 12200 */   177,   37,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 12210 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 12220 */    56,    4,   58,    6,    7,  177,    9,   10,   11,   12,
 /* 12230 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 12240 */    23,   24,  177,  177,   27,   28,   29,   83,   84,   85,
 /* 12250 */     0,  177,  177,   36,  177,  177,  177,  177,    8,  177,
 /* 12260 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 12270 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 12280 */   177,   31,   32,  177,  177,   35,  177,   37,   38,  177,
 /* 12290 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 12300 */    50,   51,   52,   53,   54,   55,   56,    4,   58,    6,
 /* 12310 */     7,  177,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 12320 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 12330 */    27,   28,   29,   83,   84,   85,    0,  177,  177,   36,
 /* 12340 */   177,  177,  177,  177,    8,  177,  177,  177,  177,  177,
 /* 12350 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 12360 */   177,  177,   26,   27,   28,  177,  177,   31,   32,  177,
 /* 12370 */   177,   35,  177,   37,   38,  177,   40,  177,   42,  177,
 /* 12380 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 12390 */    54,   55,   56,    4,   58,    6,    7,  177,    9,   10,
 /* 12400 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 12410 */    21,   22,   23,   24,  177,  177,   27,   28,   29,   83,
 /* 12420 */    84,   85,    0,  177,  177,   36,  177,  177,  177,  177,
 /* 12430 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 12440 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 12450 */    28,  177,  177,   31,   32,  177,  177,   35,  177,   37,
 /* 12460 */    38,  177,   40,  177,   42,  177,  177,   45,   46,  177,
 /* 12470 */   177,   49,   50,   51,   52,   53,   54,   55,   56,    4,
 /* 12480 */    58,    6,    7,  177,    9,   10,   11,   12,   13,   14,
 /* 12490 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 12500 */   177,  177,   27,   28,   29,   83,   84,   85,    0,  177,
 /* 12510 */   177,   36,  177,  177,  177,  177,    8,  177,  177,  177,
 /* 12520 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 12530 */   177,  177,  177,  177,   26,   27,   28,  177,  177,   31,
 /* 12540 */    32,  177,  177,   35,  177,   37,   38,  177,   40,  177,
 /* 12550 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 12560 */    52,   53,   54,   55,   56,    4,   58,    6,    7,  177,
 /* 12570 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 12580 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 12590 */    29,   83,   84,   85,    0,  177,  177,  177,  177,  177,
 /* 12600 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 12610 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 12620 */    26,   27,   28,  177,  177,   31,   32,  177,  177,   35,
 /* 12630 */   177,   37,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 12640 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 12650 */    56,    4,   58,    6,    7,  177,    9,   10,   11,   12,
 /* 12660 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 12670 */    23,   24,  177,  177,   27,   28,   29,   83,   84,   85,
 /* 12680 */     0,  177,  177,  177,  177,  177,  177,  177,    8,  177,
 /* 12690 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 12700 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 12710 */   177,   31,   32,  177,  177,   35,  177,   37,   38,  177,
 /* 12720 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 12730 */    50,   51,   52,   53,   54,   55,   56,    4,   58,    6,
 /* 12740 */     7,  177,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 12750 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 12760 */    27,   28,   29,   83,   84,   85,    0,  177,  177,  177,
 /* 12770 */     3,  177,    5,  177,    8,  177,  177,  177,  177,  177,
 /* 12780 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 12790 */   177,  177,   26,   27,   28,  177,  177,   31,   32,  177,
 /* 12800 */   177,   35,  177,   37,   38,  177,   40,  177,   42,  177,
 /* 12810 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 12820 */    54,   55,   56,  177,   58,  177,   59,   60,   61,   62,
 /* 12830 */    63,   64,   65,   66,   67,   68,   69,   70,  177,  177,
 /* 12840 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   83,
 /* 12850 */    84,   85,    0,  177,  177,  177,  177,  177,  177,  177,
 /* 12860 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 12870 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 12880 */    28,  177,  177,   31,   32,  177,  177,   35,  177,   37,
 /* 12890 */    38,  177,   40,  177,   42,  177,  177,   45,   46,  177,
 /* 12900 */   177,   49,   50,   51,   52,   53,   54,   55,   56,  177,
 /* 12910 */    58,  177,  177,  177,  110,  177,  177,  177,  177,  177,
 /* 12920 */   177,  177,  177,  119,  177,  121,  122,  123,  177,  177,
 /* 12930 */   177,  177,  177,  177,  177,   83,   84,   85,    0,  177,
 /* 12940 */   177,  177,  138,  177,  140,  177,    8,  177,  177,  145,
 /* 12950 */   146,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 12960 */   177,  177,  177,  177,   26,   27,   28,  177,  177,   31,
 /* 12970 */    32,  177,  168,   35,  177,   37,   38,  177,   40,  177,
 /* 12980 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 12990 */    52,   53,   54,   55,   56,  177,   58,  177,  177,  177,
 /* 13000 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13010 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13020 */   177,   83,   84,   85,    0,  177,  177,  177,  177,  177,
 /* 13030 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 13040 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 13050 */    26,   27,   28,  177,  177,   31,   32,  177,  177,   35,
 /* 13060 */   177,   37,   38,  177,   40,  177,   42,  177,  177,   45,
 /* 13070 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 13080 */    56,  177,   58,  177,  177,  177,  177,  177,  177,  177,
 /* 13090 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13100 */   177,  177,  177,  177,  177,  177,  177,   83,   84,   85,
 /* 13110 */     0,  177,  177,  177,  177,  177,  177,  177,    8,  177,
 /* 13120 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13130 */    20,   21,  177,  177,  177,  177,   26,   27,   28,  177,
 /* 13140 */   177,   31,   32,  177,  177,   35,  177,   37,   38,  177,
 /* 13150 */    40,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 13160 */    50,   51,   52,   53,   54,   55,   56,  177,   58,  177,
 /* 13170 */   177,  177,  177,  110,  177,  177,  177,  177,  177,  177,
 /* 13180 */   177,  177,  119,  177,  121,  122,  123,  177,  177,  177,
 /* 13190 */   177,  177,  177,   83,   84,   85,  177,  177,  177,  177,
 /* 13200 */   177,  138,    8,  140,  177,  177,  177,  177,  145,  146,
 /* 13210 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 13220 */    26,   27,   28,  177,   30,  177,   32,  177,  177,   35,
 /* 13230 */   177,  168,  169,  177,   40,  177,   42,  177,  177,   45,
 /* 13240 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 13250 */    56,  177,   58,   59,   60,  177,  177,  177,  177,  177,
 /* 13260 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 13270 */   177,  177,  177,  177,   20,   21,  177,   83,   84,   85,
 /* 13280 */    26,   27,   28,  177,   30,  177,   32,  177,  177,   35,
 /* 13290 */   177,  177,  177,  177,   40,  177,   42,  177,  177,   45,
 /* 13300 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 13310 */    56,  177,   58,   59,   60,  177,  177,  177,  177,  177,
 /* 13320 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13330 */   177,  177,  177,  177,  177,  177,  177,   83,   84,   85,
 /* 13340 */   177,    3,    4,    5,    6,    7,  177,    9,   10,   11,
 /* 13350 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /* 13360 */    22,   23,   24,    8,  177,   27,   28,   29,   30,  177,
 /* 13370 */   177,  177,  177,  177,   36,   20,   21,  177,  177,  177,
 /* 13380 */   177,   26,   27,   28,  177,  177,  177,   32,  177,  177,
 /* 13390 */    35,  177,  177,  177,  177,   40,  177,   42,  177,  177,
 /* 13400 */    45,   46,  177,  177,   49,   50,   51,   52,   53,   54,
 /* 13410 */    55,   56,  177,   58,   59,   60,  177,  177,  177,  177,
 /* 13420 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13430 */   177,  177,  177,  177,  177,  177,  177,  177,   83,   84,
 /* 13440 */    85,  177,    3,    4,    5,    6,    7,  177,    9,   10,
 /* 13450 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 13460 */    21,   22,   23,   24,  177,  177,   27,   28,   29,  177,
 /* 13470 */   177,    4,    5,    6,    7,   36,    9,   10,   11,   12,
 /* 13480 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 13490 */    23,   24,  177,  177,   27,   28,   29,   30,  177,    4,
 /* 13500 */     5,    6,    7,   36,    9,   10,   11,   12,   13,   14,
 /* 13510 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 13520 */   177,  177,   27,   28,   29,   30,  177,    4,    5,    6,
 /* 13530 */     7,   36,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 13540 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 13550 */    27,   28,   29,   30,  177,    4,    5,    6,    7,   36,
 /* 13560 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 13570 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 13580 */    29,   30,  177,    4,    5,    6,    7,   36,    9,   10,
 /* 13590 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 13600 */    21,   22,   23,   24,  177,  177,   27,   28,   29,   30,
 /* 13610 */   177,    4,    5,    6,    7,   36,    9,   10,   11,   12,
 /* 13620 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 13630 */    23,   24,  177,  177,   27,   28,   29,   30,  177,    4,
 /* 13640 */     5,    6,    7,   36,    9,   10,   11,   12,   13,   14,
 /* 13650 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 13660 */   177,  177,   27,   28,   29,   30,  177,    4,    5,    6,
 /* 13670 */     7,   36,    9,   10,   11,   12,   13,   14,   15,   16,
 /* 13680 */    17,   18,   19,   20,   21,   22,   23,   24,  177,  177,
 /* 13690 */    27,   28,   29,   30,  177,    4,    5,    6,    7,   36,
 /* 13700 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /* 13710 */    19,   20,   21,   22,   23,   24,  177,  177,   27,   28,
 /* 13720 */    29,   30,  177,    4,    5,    6,    7,   36,    9,   10,
 /* 13730 */    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
 /* 13740 */    21,   22,   23,   24,  177,  177,   27,   28,   29,   30,
 /* 13750 */   177,    4,    5,    6,    7,   36,    9,   10,   11,   12,
 /* 13760 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 13770 */    23,   24,  177,  177,   27,   28,   29,   30,  177,    4,
 /* 13780 */     5,    6,    7,   36,    9,   10,   11,   12,   13,   14,
 /* 13790 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 13800 */     8,  177,   27,   28,   29,   30,  177,  177,  177,  177,
 /* 13810 */   177,   36,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 13820 */    28,  177,  177,  177,   32,  177,  177,   35,   36,  177,
 /* 13830 */   177,  177,  177,  177,   42,  177,  177,   45,   46,  177,
 /* 13840 */   177,   49,   50,   51,   52,   53,   54,   55,   56,  177,
 /* 13850 */   177,   59,   60,  177,    8,  177,  177,  177,  177,  177,
 /* 13860 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 13870 */   177,  177,   26,   27,   28,   83,   84,   85,   32,  177,
 /* 13880 */   177,   35,   36,  177,  177,  177,  177,  177,   42,  177,
 /* 13890 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 13900 */    54,   55,   56,  177,  177,   59,   60,  177,  177,  177,
 /* 13910 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 13920 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   83,
 /* 13930 */    84,   85,  177,  177,    4,    5,    6,    7,  177,    9,
 /* 13940 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
 /* 13950 */    20,   21,   22,   23,   24,  177,  177,   27,   28,   29,
 /* 13960 */   177,  177,    4,    5,    6,    7,   36,    9,   10,   11,
 /* 13970 */    12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
 /* 13980 */    22,   23,   24,  177,  177,   27,   28,   29,  177,  177,
 /* 13990 */     4,  177,    6,    7,   36,    9,   10,   11,   12,   13,
 /* 14000 */    14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /* 14010 */    24,  177,  177,   27,   28,   29,   30,    8,  177,  177,
 /* 14020 */   177,  177,  177,  177,   38,  177,  177,  177,  177,   20,
 /* 14030 */    21,  177,  177,  177,  177,   26,   27,   28,  177,  177,
 /* 14040 */   177,   32,  177,  177,   35,   36,  177,  177,  177,  177,
 /* 14050 */   177,   42,   43,  177,   45,   46,  177,  177,   49,   50,
 /* 14060 */    51,   52,   53,   54,   55,   56,  177,  177,  177,  177,
 /* 14070 */   177,    8,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 14080 */   177,  177,  177,   20,   21,  177,  177,  177,  177,   26,
 /* 14090 */    27,   28,   83,   84,   85,   32,  177,  177,   35,  177,
 /* 14100 */   177,  177,  177,  177,  177,   42,  177,  177,   45,   46,
 /* 14110 */   177,  177,   49,   50,   51,   52,   53,   54,   55,   56,
 /* 14120 */   177,  177,   59,   60,  177,  177,  177,  177,  177,  177,
 /* 14130 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 14140 */   177,  177,  177,  177,  177,  177,   83,   84,   85,  177,
 /* 14150 */   177,    4,  177,    6,    7,  177,    9,   10,   11,   12,
 /* 14160 */    13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
 /* 14170 */    23,   24,  177,  177,   27,   28,   29,   30,  177,    4,
 /* 14180 */   177,    6,    7,  177,    9,   10,   11,   12,   13,   14,
 /* 14190 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /* 14200 */     8,  177,   27,   28,   29,   30,  177,  177,  177,  177,
 /* 14210 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 14220 */    28,  177,  177,  177,   32,  177,  177,   35,   36,  177,
 /* 14230 */   177,  177,  177,  177,   42,  177,  177,   45,   46,  177,
 /* 14240 */   177,   49,   50,   51,   52,   53,   54,   55,   56,  177,
 /* 14250 */   177,  177,  177,  177,  177,  177,  177,  177,   86,  177,
 /* 14260 */   177,   89,   90,   91,   92,   93,   94,   95,   96,   97,
 /* 14270 */    98,   99,  100,  101,  102,   83,   84,   85,  106,  177,
 /* 14280 */   177,  109,  110,  177,    8,  177,  177,  115,  177,  117,
 /* 14290 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 14300 */   177,  177,   26,   27,   28,  177,   30,  177,   32,  177,
 /* 14310 */   138,   35,  140,  177,  177,  177,  177,  177,   42,  177,
 /* 14320 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 14330 */    54,   55,   56,  177,  177,  177,  177,  177,    8,  177,
 /* 14340 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 14350 */    20,   21,  177,  177,  177,  177,   26,   27,   28,   83,
 /* 14360 */    84,   85,   32,  177,  177,   35,   36,  177,  177,  177,
 /* 14370 */   177,  177,   42,  177,  177,   45,   46,  177,  177,   49,
 /* 14380 */    50,   51,   52,   53,   54,   55,   56,  177,  177,  177,
 /* 14390 */   177,  177,    8,  177,  177,  177,  177,  177,  177,  177,
 /* 14400 */   177,  177,  177,  177,   20,   21,  177,  177,  177,  177,
 /* 14410 */    26,   27,   28,   83,   84,   85,   32,  177,  177,   35,
 /* 14420 */   177,  177,  177,  177,  177,  177,   42,  177,  177,   45,
 /* 14430 */    46,  177,  177,   49,   50,   51,   52,   53,   54,   55,
 /* 14440 */    56,  177,  177,  177,  177,  177,    8,  177,  177,  177,
 /* 14450 */   177,  177,  177,  177,  177,  177,  177,  177,   20,   21,
 /* 14460 */   177,  177,  177,  177,   26,   27,   28,   83,   84,   85,
 /* 14470 */    32,  177,  177,   35,  177,  177,  177,  177,  177,  177,
 /* 14480 */    42,  177,  177,   45,   46,  177,  177,   49,   50,   51,
 /* 14490 */    52,   53,   54,   55,   56,  177,  177,  177,  177,  177,
 /* 14500 */     8,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 14510 */   177,  177,   20,   21,  177,  177,  177,  177,   26,   27,
 /* 14520 */    28,   83,   84,   85,   32,  177,  177,   35,  177,  177,
 /* 14530 */   177,  177,  177,  177,   42,  177,  177,   45,   46,  177,
 /* 14540 */   177,   49,   50,   51,   52,   53,   54,   55,   56,  177,
 /* 14550 */   177,  177,  177,  177,    8,  177,  177,  177,  177,  177,
 /* 14560 */   177,  177,  177,  177,  177,  177,   20,   21,  177,  177,
 /* 14570 */   177,  177,   26,   27,   28,   83,   84,   85,   32,  177,
 /* 14580 */   177,   35,  177,  177,  177,  177,  177,  177,   42,  177,
 /* 14590 */   177,   45,   46,  177,  177,   49,   50,   51,   52,   53,
 /* 14600 */    54,   55,   56,  177,  177,  177,  177,  177,  177,  177,
 /* 14610 */   177,  177,  177,  177,  177,  177,  177,  177,  177,  177,
 /* 14620 */   177,  177,  177,  177,  177,  177,  177,  177,  177,   83,
 /* 14630 */    84,   85,
};
#define YY_SHIFT_USE_DFLT (-30)
#define YY_SHIFT_COUNT (479)
#define YY_SHIFT_MIN   (-29)
#define YY_SHIFT_MAX   (14546)
static const short yy_shift_ofst[] = {
 /*     0 */  13110, 10468, 11014, 11014, 11014, 11014, 11014, 11014, 11014, 11014,
 /*    10 */  11014, 11014, 11014, 9841, 9763, 10390, 10312, 10234, 13024, 13254,
 /*    20 */  13355, 13846, 14063, 14330, 14330, 14330, 14330, 14330, 14330, 14330,
 /*    30 */  14330, 14330, 14330, 14276, 3249, 14192, 14492, 14492, 14492, 14492,
 /*    40 */  14492, 14492, 14546, 14546, 14492, 14546, 14492, 14492, 14492, 14492,
 /*    50 */  14492, 14492, 14492, 3332, 3010, 14009, 14492, 14492, 14492, 14492,
 /*    60 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*    70 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*    80 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*    90 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*   100 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*   110 */  14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492, 14492,
 /*   120 */  14492,  958,  958,  958,  629, 1861, 1861, 1861, 1861, 1861,
 /*   130 */  10156, 10156, 10156, 3464, 3464, 1224,  703, 1799, 1799, 1799,
 /*   140 */  1746, 1744, 2924, 2838, 2752, 2666, 2580, 2494, 2408, 2322,
 /*   150 */  2236, 2150, 2064, 1978, 1892, 1806, 1720, 1634, 1548, 1462,
 /*   160 */  1376, 1290, 1204, 1118, 1032,  946,  860,  774,  688,  602,
 /*   170 */   516,  430,  344,  258,  172,   86,    0, 4504, 4421, 4338,
 /*   180 */  4255, 4172, 4089, 4006, 3923, 3840, 3757, 3674, 3591, 3508,
 /*   190 */  3425, 3342, 3259, 3176, 3093, 7990, 7907, 7824, 7741, 7658,
 /*   200 */  7575, 7492, 7409, 7326, 7243, 7160, 7077, 6994, 6911, 6828,
 /*   210 */  6745, 6662, 6579, 6496, 6413, 6330, 6247, 6164, 6081, 5998,
 /*   220 */  5915, 5832, 5749, 5666, 5583, 5500, 5417, 5334, 5251, 5168,
 /*   230 */  5085, 5002, 4919, 4836, 4753, 4670, 4587, 8236, 8154, 8072,
 /*   240 */  9163, 9685, 9607, 9529, 9451, 10078, 10000, 9922, 10936, 10858,
 /*   250 */  10780, 10702, 10624, 10546, 11233, 11165, 11097, 12938, 12852, 12766,
 /*   260 */  12680, 12594, 12508, 12422, 12336, 12250, 12164, 12078, 11992, 11906,
 /*   270 */  11820, 11734, 11648, 11562, 11476, 11390, 11304, 13194, 13338, 13792,
 /*   280 */  13775, 13747, 13719, 13691, 13663, 13635, 13607, 13579, 13551, 13523,
 /*   290 */  13495, 13467, 13439, 13986, 13958, 13930, 14175, 14147, 11261, 11193,
 /*   300 */  11125, 12475, 12389, 12303, 12217, 12131, 12045, 11959, 11873, 11787,
 /*   310 */  11701, 11615, 11529, 11443, 11357, 12733, 12647, 14438, 14384, 12561,
 /*   320 */  12767, 8294, 8358, 8299,  543,  457,  371,  285,  199,  783,
 /*   330 */  1282,  852, 3210, 3132, 1152, 1066,  980, 3204, 3121, 3129,
 /*   340 */  1322, 1241, 1236, 1154, 1068,  982, 1243, 1439, 1175, 3297,
 /*   350 */  1089, 3459, 3135, 3381, 3298, 3215, 1324, 1003,  899,  831,
 /*   360 */   745,  641,  555, 1238, 1232,  894, 1435, 1351,  469,  753,
 /*   370 */   383,   57,  636,  550,  464,  340,  254,  168,   12,  273,
 /*   380 */   187,  101, 1732, 1731, 1734, 1709, 1675, 1672, 1670, 1667,
 /*   390 */  1662, 1646, 1645, 1642, 1623, 1577, 1582, 1578, 1586, 1576,
 /*   400 */  1569, 1565, 1562, 1543, 1496, 1498, 1501, 1491, 1490, 1480,
 /*   410 */  1482, 1470, 1460, 1436, 1405, 1403, 1388, 1396, 1393, 1365,
 /*   420 */  1350, 1326, 1302, 1310, 1288, 1255, 1220, 1248, 1145, 1123,
 /*   430 */  1129, 1126, 1116, 1063, 1053, 1052, 1040, 1030,  977,  966,
 /*   440 */   944,  920,  897,  881,  880,  858,  801,  776,  771,  704,
 /*   450 */   683,  659,  620,  619,  597,  573,  534,  533,  511,  476,
 /*   460 */   448,  450,  382,  412,  388,  350,  363,  333,  301,  297,
 /*   470 */   274,  251,  190,  165,  122,  118,  104,   81,   -5,  -29,
};
#define YY_REDUCE_USE_DFLT (-92)
#define YY_REDUCE_COUNT (141)
#define YY_REDUCE_MIN   (-91)
#define YY_REDUCE_MAX   (14172)
static const short yy_reduce_ofst[] = {
 /*     0 */   154, 8990, 8921, 8851, 8782, 8712, 8643, 8573, 8504, 8434,
 /*    10 */  8365, 8295, 8226, 9139, 9278, 9139, 9207, 9139, 14172, 13063,
 /*    20 */  12804, 9375, 9453,  697,  611,  525,  439,  353,  267,  181,
 /*    30 */    95,    9,  -77, 8193,  763,   15, 9924, 9846, 9823, 9799,
 /*    40 */  9765, 9687, 1041,  955, 9609,  869, 9531, 9336, 9328, 9327,
 /*    50 */  9062, 9048, 9039,  -91,  687,  617, 4178, 4099, 4095, 4016,
 /*    60 */  4012, 3933, 3929, 3850, 3846, 3767, 3763, 3684, 3680, 3601,
 /*    70 */  3597, 3518, 3514, 3435, 3431, 3352, 3348, 3271, 3188, 3020,
 /*    80 */  2939, 2933, 2853, 2847, 2767, 2761, 2681, 2675, 2595, 2589,
 /*    90 */  2509, 2503, 2423, 2417, 2337, 2331, 2251, 2245, 2165, 2159,
 /*   100 */  2079, 2073, 1993, 1987, 1907, 1901, 1821, 1815, 1735, 1729,
 /*   110 */  1649, 1643, 1563, 1557, 1477, 1471, 1391, 1385, 1305, 1299,
 /*   120 */   617, 3268, 3185, 3106,  -65, 1671, 1585, 1499, 1413, 1223,
 /*   130 */  1772, 1770, 1768, 1727, 1726, 1724, 1751, 1716, 1713, 1653,
 /*   140 */  1651, 1668,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    10 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    20 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    30 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    40 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    50 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    60 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    70 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    80 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*    90 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   100 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   110 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   120 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   130 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   140 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   150 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   160 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   170 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   180 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   190 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   200 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   210 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   220 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   230 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   240 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   250 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   260 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   270 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   280 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   290 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   300 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   310 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   320 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   330 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   340 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   350 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   360 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   370 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   380 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   390 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   400 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   410 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   420 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   430 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   440 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   450 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   460 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   470 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  ParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

// We always want to have a ParseTrace. ParseTrace is only available on NDEBUG mode, so we explicitly set it.
#ifdef NDEBUG
#undef NDEBUG
#endif



#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static const char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/*
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ParseTrace(FILE *TraceFILE, const char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "IFX",           "ELSE",          "ASSIGN",      
  "QMARK",         "COMMA",         "LOR",           "LAND",        
  "LNOT",          "EQ",            "LE",            "LT",          
  "GE",            "GT",            "NE",            "BITOR",       
  "BITXOR",        "BITAND",        "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "DIVIDE",        "MULTIPLY",    
  "MOD",           "UNARY",         "BITNOT",        "LPAREN",      
  "LSQBRACKET",    "PERIOD",        "SEMICOLON",     "IMPORT",      
  "NAME",          "AS",            "COLON",         "FUNCTION",    
  "RPAREN",        "OBJECT",        "LBRACKET",      "EXTENDS",     
  "VAR",           "RBRACKET",      "NUMBER",        "RSQBRACKET",  
  "SUBSCRIPT",     "STRING",        "KILLS",         "MEMBER",      
  "FUNCCALL",      "L2V",           "MAPSTRING",     "UNIT",        
  "SWITCH",        "LOCATION",      "STATTXTTBL",    "VARRAY",      
  "LIST",          "STATIC",        "CONST",         "INC",         
  "DEC",           "IADD",          "ISUB",          "IMUL",        
  "IDIV",          "IMOD",          "ILSH",          "IRSH",        
  "IBND",          "IBOR",          "IBXR",          "ONCE",        
  "IF",            "EPDSWITCH",     "SWITCHCASE",    "CASE",        
  "DEFAULT",       "WHILE",         "FOR",           "FOREACH",     
  "CONTINUE",      "BREAK",         "RETURN",        "CONDITIONNAME",
  "ACTIONNAME",    "ACTIONALLPNAME",  "error",         "program",     
  "chunks",        "chunk",         "relimp_chunk",  "import_chunk",
  "fdef_chunk",    "fdecl_chunk",   "objdef_chunk",  "objdecl_chunk",
  "vdef_global_stmt",  "funccall_global_stmt",  "vdefAssign_global_stmt",  "cdef_global_stmt",
  "blockStmt",     "relimp_start",  "relimp_path",   "dottedName",  
  "fdef_rettypes",  "exprList_nonEmpty",  "fdef_header",   "typedNameList",
  "stmt",          "object_body",   "expr",          "typedNameList_nonEmpty",
  "method_header",  "method_chunk",  "bodyStmt",      "lbracket",    
  "rbracket",      "blockStmtSub",  "bodyStmtList",  "vdef_stmt",   
  "vdefAssignStatic_stmt",  "vdefAssign_stmt",  "cdef_stmt",     "assign_stmt", 
  "funcexprStmt",  "actionStmt",    "once_stmt",     "if_stmt",     
  "while_stmt",    "for_stmt",      "foreach_stmt",  "switchcase_stmt",
  "continue_stmt",  "break_stmt",    "return_stmt",   "numList_nonEmpty",
  "typedName",     "nameList_nonEmpty",  "funcexpr",      "exprList",    
  "lambdaExprStart",  "fArg",          "fArgs_nonEmpty",  "fArgs",       
  "commaSkippable",  "lvalue",        "lvalueList_nonEmpty",  "once_start",  
  "once_header",   "once_block",    "once_nocond",   "if_start",    
  "if_header",     "if_block",      "elif_start",    "elif_header", 
  "else_header",   "switchcase_header",  "case_start",    "case_clause", 
  "case_chunk",    "case_chunks",   "default_clause",  "default_chunk",
  "switchcase_block",  "while_start",   "while_header",  "for_opener",  
  "for_init_stmt_nonEmpty",  "for_init_stmt",  "for_action_stmt_nonEmpty",  "for_action_stmt",
  "for_header1",   "for_header2",   "for_header",    "foreach_opener",
  "foreach_header",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "program ::= chunks",
 /*   1 */ "chunks ::=",
 /*   2 */ "chunks ::= chunks chunk",
 /*   3 */ "chunks ::= chunks error",
 /*   4 */ "chunk ::= relimp_chunk",
 /*   5 */ "chunk ::= import_chunk SEMICOLON",
 /*   6 */ "chunk ::= fdef_chunk",
 /*   7 */ "chunk ::= fdecl_chunk",
 /*   8 */ "chunk ::= objdef_chunk",
 /*   9 */ "chunk ::= objdecl_chunk",
 /*  10 */ "chunk ::= vdef_global_stmt SEMICOLON",
 /*  11 */ "chunk ::= funccall_global_stmt SEMICOLON",
 /*  12 */ "chunk ::= vdefAssign_global_stmt SEMICOLON",
 /*  13 */ "chunk ::= cdef_global_stmt SEMICOLON",
 /*  14 */ "chunk ::= blockStmt",
 /*  15 */ "relimp_start ::= IMPORT PERIOD",
 /*  16 */ "relimp_start ::= relimp_start PERIOD",
 /*  17 */ "relimp_path ::= relimp_start NAME",
 /*  18 */ "relimp_path ::= relimp_path PERIOD NAME",
 /*  19 */ "relimp_chunk ::= relimp_path AS NAME SEMICOLON",
 /*  20 */ "relimp_chunk ::= relimp_path SEMICOLON",
 /*  21 */ "dottedName ::= NAME",
 /*  22 */ "dottedName ::= dottedName PERIOD NAME",
 /*  23 */ "import_chunk ::= IMPORT dottedName AS NAME",
 /*  24 */ "import_chunk ::= IMPORT dottedName",
 /*  25 */ "fdef_rettypes ::=",
 /*  26 */ "fdef_rettypes ::= COLON exprList_nonEmpty",
 /*  27 */ "fdef_header ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes",
 /*  28 */ "fdef_chunk ::= fdef_header stmt",
 /*  29 */ "fdecl_chunk ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes SEMICOLON",
 /*  30 */ "object_body ::= OBJECT NAME LBRACKET",
 /*  31 */ "object_body ::= OBJECT NAME EXTENDS expr LBRACKET",
 /*  32 */ "object_body ::= object_body VAR typedNameList_nonEmpty SEMICOLON",
 /*  33 */ "method_header ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes",
 /*  34 */ "method_chunk ::= method_header stmt",
 /*  35 */ "object_body ::= object_body method_chunk",
 /*  36 */ "objdef_chunk ::= object_body RBRACKET SEMICOLON",
 /*  37 */ "objdecl_chunk ::= OBJECT NAME SEMICOLON",
 /*  38 */ "objdecl_chunk ::= OBJECT NAME EXTENDS expr SEMICOLON",
 /*  39 */ "stmt ::= error SEMICOLON",
 /*  40 */ "stmt ::= bodyStmt",
 /*  41 */ "lbracket ::= LBRACKET",
 /*  42 */ "rbracket ::= RBRACKET",
 /*  43 */ "blockStmt ::= blockStmtSub rbracket",
 /*  44 */ "blockStmt ::= lbracket error RBRACKET",
 /*  45 */ "blockStmtSub ::= lbracket",
 /*  46 */ "blockStmtSub ::= lbracket bodyStmtList",
 /*  47 */ "bodyStmt ::= blockStmt",
 /*  48 */ "bodyStmt ::= SEMICOLON",
 /*  49 */ "bodyStmt ::= vdef_stmt SEMICOLON",
 /*  50 */ "bodyStmt ::= vdefAssignStatic_stmt SEMICOLON",
 /*  51 */ "bodyStmt ::= vdefAssign_stmt SEMICOLON",
 /*  52 */ "bodyStmt ::= cdef_stmt SEMICOLON",
 /*  53 */ "bodyStmt ::= assign_stmt SEMICOLON",
 /*  54 */ "bodyStmt ::= funcexprStmt SEMICOLON",
 /*  55 */ "bodyStmt ::= actionStmt",
 /*  56 */ "bodyStmt ::= once_stmt",
 /*  57 */ "bodyStmt ::= if_stmt",
 /*  58 */ "bodyStmt ::= while_stmt",
 /*  59 */ "bodyStmt ::= for_stmt",
 /*  60 */ "bodyStmt ::= foreach_stmt",
 /*  61 */ "bodyStmt ::= switchcase_stmt",
 /*  62 */ "bodyStmt ::= continue_stmt SEMICOLON",
 /*  63 */ "bodyStmt ::= break_stmt SEMICOLON",
 /*  64 */ "bodyStmt ::= return_stmt SEMICOLON",
 /*  65 */ "bodyStmtList ::= bodyStmt",
 /*  66 */ "bodyStmtList ::= bodyStmtList bodyStmt",
 /*  67 */ "bodyStmtList ::= bodyStmtList error",
 /*  68 */ "numList_nonEmpty ::= NUMBER",
 /*  69 */ "numList_nonEmpty ::= numList_nonEmpty COMMA NUMBER",
 /*  70 */ "typedName ::= NAME",
 /*  71 */ "typedName ::= NAME COLON expr",
 /*  72 */ "typedNameList_nonEmpty ::= typedName",
 /*  73 */ "typedNameList_nonEmpty ::= typedName COMMA typedNameList_nonEmpty",
 /*  74 */ "typedNameList ::=",
 /*  75 */ "typedNameList ::= typedNameList_nonEmpty",
 /*  76 */ "nameList_nonEmpty ::= NAME",
 /*  77 */ "nameList_nonEmpty ::= nameList_nonEmpty COMMA NAME",
 /*  78 */ "exprList_nonEmpty ::= funcexpr LSQBRACKET LSQBRACKET numList_nonEmpty RSQBRACKET RSQBRACKET",
 /*  79 */ "expr ::= funcexpr LSQBRACKET LSQBRACKET NUMBER RSQBRACKET RSQBRACKET",
 /*  80 */ "exprList_nonEmpty ::= expr",
 /*  81 */ "exprList_nonEmpty ::= exprList_nonEmpty COMMA expr",
 /*  82 */ "exprList ::=",
 /*  83 */ "exprList ::= exprList_nonEmpty",
 /*  84 */ "expr ::= NUMBER",
 /*  85 */ "expr ::= STRING",
 /*  86 */ "expr ::= KILLS",
 /*  87 */ "expr ::= NAME",
 /*  88 */ "expr ::= expr PERIOD NAME",
 /*  89 */ "expr ::= expr LSQBRACKET expr RSQBRACKET",
 /*  90 */ "lambdaExprStart ::= FUNCTION LPAREN typedNameList RPAREN fdef_rettypes",
 /*  91 */ "expr ::= lambdaExprStart stmt",
 /*  92 */ "fArg ::= expr",
 /*  93 */ "fArg ::= NAME ASSIGN expr",
 /*  94 */ "fArgs_nonEmpty ::= fArg",
 /*  95 */ "fArgs_nonEmpty ::= fArgs_nonEmpty COMMA fArg",
 /*  96 */ "fArgs ::=",
 /*  97 */ "fArgs ::= fArgs_nonEmpty",
 /*  98 */ "fArgs ::= fArgs_nonEmpty COMMA",
 /*  99 */ "funcexprStmt ::= funcexpr",
 /* 100 */ "funcexpr ::= NAME LPAREN fArgs RPAREN",
 /* 101 */ "funcexpr ::= expr LPAREN fArgs RPAREN",
 /* 102 */ "funccall_global_stmt ::= NAME LPAREN fArgs RPAREN",
 /* 103 */ "funccall_global_stmt ::= expr LPAREN fArgs RPAREN",
 /* 104 */ "expr ::= funcexpr",
 /* 105 */ "expr ::= LPAREN expr RPAREN",
 /* 106 */ "commaSkippable ::= COMMA",
 /* 107 */ "commaSkippable ::=",
 /* 108 */ "expr ::= LSQBRACKET exprList_nonEmpty commaSkippable RSQBRACKET",
 /* 109 */ "expr ::= L2V LPAREN expr RPAREN",
 /* 110 */ "expr ::= MAPSTRING LPAREN expr RPAREN",
 /* 111 */ "expr ::= UNIT LPAREN expr RPAREN",
 /* 112 */ "expr ::= SWITCH LPAREN expr RPAREN",
 /* 113 */ "expr ::= LOCATION LPAREN expr RPAREN",
 /* 114 */ "expr ::= STATTXTTBL LPAREN expr RPAREN",
 /* 115 */ "expr ::= VARRAY LPAREN exprList_nonEmpty commaSkippable RPAREN",
 /* 116 */ "expr ::= LIST LPAREN exprList_nonEmpty commaSkippable RPAREN",
 /* 117 */ "expr ::= expr QMARK expr COLON expr",
 /* 118 */ "expr ::= expr PLUS expr",
 /* 119 */ "expr ::= expr MINUS expr",
 /* 120 */ "expr ::= expr MULTIPLY expr",
 /* 121 */ "expr ::= expr DIVIDE expr",
 /* 122 */ "expr ::= expr MOD expr",
 /* 123 */ "expr ::= expr LSHIFT expr",
 /* 124 */ "expr ::= expr RSHIFT expr",
 /* 125 */ "expr ::= expr BITAND expr",
 /* 126 */ "expr ::= expr BITOR expr",
 /* 127 */ "expr ::= expr BITXOR expr",
 /* 128 */ "expr ::= PLUS expr",
 /* 129 */ "expr ::= MINUS expr",
 /* 130 */ "expr ::= BITNOT expr",
 /* 131 */ "expr ::= expr PERIOD NAME EQ expr",
 /* 132 */ "expr ::= expr PERIOD NAME NE expr",
 /* 133 */ "expr ::= expr PERIOD NAME LE expr",
 /* 134 */ "expr ::= expr PERIOD NAME GE expr",
 /* 135 */ "expr ::= expr PERIOD NAME LT expr",
 /* 136 */ "expr ::= expr PERIOD NAME GT expr",
 /* 137 */ "expr ::= expr LSQBRACKET expr RSQBRACKET EQ expr",
 /* 138 */ "expr ::= expr LSQBRACKET expr RSQBRACKET NE expr",
 /* 139 */ "expr ::= expr LSQBRACKET expr RSQBRACKET LE expr",
 /* 140 */ "expr ::= expr LSQBRACKET expr RSQBRACKET GE expr",
 /* 141 */ "expr ::= expr LSQBRACKET expr RSQBRACKET LT expr",
 /* 142 */ "expr ::= expr LSQBRACKET expr RSQBRACKET GT expr",
 /* 143 */ "expr ::= expr EQ expr",
 /* 144 */ "expr ::= expr NE expr",
 /* 145 */ "expr ::= expr LE expr",
 /* 146 */ "expr ::= expr GE expr",
 /* 147 */ "expr ::= expr LT expr",
 /* 148 */ "expr ::= expr GT expr",
 /* 149 */ "expr ::= expr LAND expr",
 /* 150 */ "expr ::= expr LOR expr",
 /* 151 */ "expr ::= LNOT expr",
 /* 152 */ "vdef_global_stmt ::= VAR typedNameList_nonEmpty",
 /* 153 */ "vdef_stmt ::= VAR typedNameList_nonEmpty",
 /* 154 */ "vdefAssign_stmt ::= VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 155 */ "vdefAssignStatic_stmt ::= STATIC VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 156 */ "vdefAssign_global_stmt ::= VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 157 */ "cdef_stmt ::= CONST nameList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 158 */ "cdef_global_stmt ::= CONST nameList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 159 */ "lvalue ::= NAME",
 /* 160 */ "lvalue ::= expr LSQBRACKET expr RSQBRACKET",
 /* 161 */ "lvalue ::= expr PERIOD NAME",
 /* 162 */ "lvalueList_nonEmpty ::= lvalue",
 /* 163 */ "lvalueList_nonEmpty ::= lvalueList_nonEmpty COMMA lvalue",
 /* 164 */ "assign_stmt ::= lvalue ASSIGN expr",
 /* 165 */ "assign_stmt ::= lvalueList_nonEmpty ASSIGN exprList_nonEmpty",
 /* 166 */ "assign_stmt ::= INC lvalue",
 /* 167 */ "assign_stmt ::= lvalue INC",
 /* 168 */ "assign_stmt ::= DEC lvalue",
 /* 169 */ "assign_stmt ::= lvalue DEC",
 /* 170 */ "assign_stmt ::= lvalue IADD expr",
 /* 171 */ "assign_stmt ::= lvalue ISUB expr",
 /* 172 */ "assign_stmt ::= lvalue IMUL expr",
 /* 173 */ "assign_stmt ::= lvalue IDIV expr",
 /* 174 */ "assign_stmt ::= lvalue IMOD expr",
 /* 175 */ "assign_stmt ::= lvalue ILSH expr",
 /* 176 */ "assign_stmt ::= lvalue IRSH expr",
 /* 177 */ "assign_stmt ::= lvalue IBND expr",
 /* 178 */ "assign_stmt ::= lvalue IBOR expr",
 /* 179 */ "assign_stmt ::= lvalue IBXR expr",
 /* 180 */ "once_start ::= ONCE",
 /* 181 */ "once_header ::= once_start LPAREN expr",
 /* 182 */ "once_block ::= once_header RPAREN stmt",
 /* 183 */ "once_nocond ::= once_start",
 /* 184 */ "once_block ::= once_nocond stmt",
 /* 185 */ "once_stmt ::= once_block",
 /* 186 */ "if_start ::= IF",
 /* 187 */ "if_header ::= if_start LPAREN expr",
 /* 188 */ "if_block ::= if_header RPAREN stmt",
 /* 189 */ "elif_start ::= ELSE IF",
 /* 190 */ "elif_header ::= elif_start LPAREN expr",
 /* 191 */ "if_block ::= if_block elif_header RPAREN stmt",
 /* 192 */ "else_header ::= ELSE",
 /* 193 */ "if_stmt ::= if_block",
 /* 194 */ "if_stmt ::= if_block else_header stmt",
 /* 195 */ "switchcase_header ::= EPDSWITCH LPAREN exprList_nonEmpty",
 /* 196 */ "switchcase_header ::= SWITCHCASE LPAREN exprList_nonEmpty",
 /* 197 */ "case_start ::= CASE",
 /* 198 */ "case_clause ::= case_start exprList_nonEmpty COLON",
 /* 199 */ "case_chunk ::= case_clause",
 /* 200 */ "case_chunk ::= case_clause bodyStmtList",
 /* 201 */ "case_chunks ::= case_chunks case_chunk",
 /* 202 */ "case_chunks ::= case_chunk",
 /* 203 */ "default_clause ::= DEFAULT COLON",
 /* 204 */ "default_chunk ::= default_clause",
 /* 205 */ "default_chunk ::= default_clause bodyStmtList",
 /* 206 */ "switchcase_block ::= switchcase_header RPAREN LBRACKET case_chunks default_chunk",
 /* 207 */ "switchcase_block ::= switchcase_header RPAREN LBRACKET case_chunks",
 /* 208 */ "switchcase_block ::= switchcase_header RPAREN LBRACKET",
 /* 209 */ "switchcase_stmt ::= switchcase_block RBRACKET",
 /* 210 */ "while_start ::= WHILE",
 /* 211 */ "while_header ::= while_start LPAREN expr",
 /* 212 */ "while_stmt ::= while_header RPAREN stmt",
 /* 213 */ "for_opener ::= FOR LPAREN",
 /* 214 */ "for_init_stmt_nonEmpty ::= vdef_stmt",
 /* 215 */ "for_init_stmt_nonEmpty ::= vdefAssign_stmt",
 /* 216 */ "for_init_stmt_nonEmpty ::= cdef_stmt",
 /* 217 */ "for_init_stmt_nonEmpty ::= assign_stmt",
 /* 218 */ "for_init_stmt_nonEmpty ::= for_init_stmt_nonEmpty COMMA for_init_stmt_nonEmpty",
 /* 219 */ "for_init_stmt ::= for_init_stmt_nonEmpty",
 /* 220 */ "for_init_stmt ::=",
 /* 221 */ "for_action_stmt_nonEmpty ::= funcexprStmt",
 /* 222 */ "for_action_stmt_nonEmpty ::= assign_stmt",
 /* 223 */ "for_action_stmt_nonEmpty ::= for_action_stmt_nonEmpty COMMA for_action_stmt_nonEmpty",
 /* 224 */ "for_action_stmt ::=",
 /* 225 */ "for_action_stmt ::= for_action_stmt_nonEmpty",
 /* 226 */ "for_header1 ::= for_opener for_init_stmt SEMICOLON",
 /* 227 */ "for_header2 ::= for_header1 expr SEMICOLON",
 /* 228 */ "for_header ::= for_header2 for_action_stmt",
 /* 229 */ "for_stmt ::= for_header RPAREN stmt",
 /* 230 */ "foreach_opener ::= FOREACH LPAREN",
 /* 231 */ "foreach_header ::= foreach_opener nameList_nonEmpty COLON exprList_nonEmpty",
 /* 232 */ "foreach_stmt ::= foreach_header RPAREN stmt",
 /* 233 */ "continue_stmt ::= CONTINUE",
 /* 234 */ "break_stmt ::= BREAK",
 /* 235 */ "return_stmt ::= RETURN exprList",
 /* 236 */ "expr ::= CONDITIONNAME LPAREN fArgs RPAREN",
 /* 237 */ "expr ::= KILLS LPAREN fArgs RPAREN",
 /* 238 */ "actionStmt ::= ACTIONNAME LPAREN fArgs RPAREN SEMICOLON",
 /* 239 */ "actionStmt ::= ACTIONALLPNAME LPAREN fArgs RPAREN SEMICOLON",
 /* 240 */ "expr ::= ACTIONNAME LPAREN fArgs RPAREN",
 /* 241 */ "expr ::= ACTIONALLPNAME LPAREN fArgs RPAREN",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to Parse and ParseFree.
*/
void *ParseAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
      /* TERMINAL Destructor */
    case 1: /* IFX */
    case 2: /* ELSE */
    case 3: /* ASSIGN */
    case 4: /* QMARK */
    case 5: /* COMMA */
    case 6: /* LOR */
    case 7: /* LAND */
    case 8: /* LNOT */
    case 9: /* EQ */
    case 10: /* LE */
    case 11: /* LT */
    case 12: /* GE */
    case 13: /* GT */
    case 14: /* NE */
    case 15: /* BITOR */
    case 16: /* BITXOR */
    case 17: /* BITAND */
    case 18: /* LSHIFT */
    case 19: /* RSHIFT */
    case 20: /* PLUS */
    case 21: /* MINUS */
    case 22: /* DIVIDE */
    case 23: /* MULTIPLY */
    case 24: /* MOD */
    case 25: /* UNARY */
    case 26: /* BITNOT */
    case 27: /* LPAREN */
    case 28: /* LSQBRACKET */
    case 29: /* PERIOD */
    case 30: /* SEMICOLON */
    case 31: /* IMPORT */
    case 32: /* NAME */
    case 33: /* AS */
    case 34: /* COLON */
    case 35: /* FUNCTION */
    case 36: /* RPAREN */
    case 37: /* OBJECT */
    case 38: /* LBRACKET */
    case 39: /* EXTENDS */
    case 40: /* VAR */
    case 41: /* RBRACKET */
    case 42: /* NUMBER */
    case 43: /* RSQBRACKET */
    case 44: /* SUBSCRIPT */
    case 45: /* STRING */
    case 46: /* KILLS */
    case 47: /* MEMBER */
    case 48: /* FUNCCALL */
    case 49: /* L2V */
    case 50: /* MAPSTRING */
    case 51: /* UNIT */
    case 52: /* SWITCH */
    case 53: /* LOCATION */
    case 54: /* STATTXTTBL */
    case 55: /* VARRAY */
    case 56: /* LIST */
    case 57: /* STATIC */
    case 58: /* CONST */
    case 59: /* INC */
    case 60: /* DEC */
    case 61: /* IADD */
    case 62: /* ISUB */
    case 63: /* IMUL */
    case 64: /* IDIV */
    case 65: /* IMOD */
    case 66: /* ILSH */
    case 67: /* IRSH */
    case 68: /* IBND */
    case 69: /* IBOR */
    case 70: /* IBXR */
    case 71: /* ONCE */
    case 72: /* IF */
    case 73: /* EPDSWITCH */
    case 74: /* SWITCHCASE */
    case 75: /* CASE */
    case 76: /* DEFAULT */
    case 77: /* WHILE */
    case 78: /* FOR */
    case 79: /* FOREACH */
    case 80: /* CONTINUE */
    case 81: /* BREAK */
    case 82: /* RETURN */
    case 83: /* CONDITIONNAME */
    case 84: /* ACTIONNAME */
    case 85: /* ACTIONALLPNAME */
{
 delete (yypminor->yy0); 
}
      break;
      /* Default NON-TERMINAL Destructor */
    case 87: /* program */
    case 88: /* chunks */
    case 89: /* chunk */
    case 90: /* relimp_chunk */
    case 91: /* import_chunk */
    case 92: /* fdef_chunk */
    case 93: /* fdecl_chunk */
    case 94: /* objdef_chunk */
    case 95: /* objdecl_chunk */
    case 96: /* vdef_global_stmt */
    case 97: /* funccall_global_stmt */
    case 98: /* vdefAssign_global_stmt */
    case 99: /* cdef_global_stmt */
    case 100: /* blockStmt */
    case 101: /* relimp_start */
    case 102: /* relimp_path */
    case 103: /* dottedName */
    case 104: /* fdef_rettypes */
    case 105: /* exprList_nonEmpty */
    case 106: /* fdef_header */
    case 107: /* typedNameList */
    case 108: /* stmt */
    case 109: /* object_body */
    case 110: /* expr */
    case 111: /* typedNameList_nonEmpty */
    case 112: /* method_header */
    case 113: /* method_chunk */
    case 114: /* bodyStmt */
    case 115: /* lbracket */
    case 116: /* rbracket */
    case 117: /* blockStmtSub */
    case 118: /* bodyStmtList */
    case 119: /* vdef_stmt */
    case 120: /* vdefAssignStatic_stmt */
    case 121: /* vdefAssign_stmt */
    case 122: /* cdef_stmt */
    case 123: /* assign_stmt */
    case 124: /* funcexprStmt */
    case 125: /* actionStmt */
    case 126: /* once_stmt */
    case 127: /* if_stmt */
    case 128: /* while_stmt */
    case 129: /* for_stmt */
    case 130: /* foreach_stmt */
    case 131: /* switchcase_stmt */
    case 132: /* continue_stmt */
    case 133: /* break_stmt */
    case 134: /* return_stmt */
    case 135: /* numList_nonEmpty */
    case 136: /* typedName */
    case 137: /* nameList_nonEmpty */
    case 138: /* funcexpr */
    case 139: /* exprList */
    case 140: /* lambdaExprStart */
    case 141: /* fArg */
    case 142: /* fArgs_nonEmpty */
    case 143: /* fArgs */
    case 144: /* commaSkippable */
    case 145: /* lvalue */
    case 146: /* lvalueList_nonEmpty */
    case 147: /* once_start */
    case 148: /* once_header */
    case 149: /* once_block */
    case 150: /* once_nocond */
    case 151: /* if_start */
    case 152: /* if_header */
    case 153: /* if_block */
    case 154: /* elif_start */
    case 155: /* elif_header */
    case 156: /* else_header */
    case 157: /* switchcase_header */
    case 158: /* case_start */
    case 159: /* case_clause */
    case 160: /* case_chunk */
    case 161: /* case_chunks */
    case 162: /* default_clause */
    case 163: /* default_chunk */
    case 164: /* switchcase_block */
    case 165: /* while_start */
    case 166: /* while_header */
    case 167: /* for_opener */
    case 168: /* for_init_stmt_nonEmpty */
    case 169: /* for_init_stmt */
    case 170: /* for_action_stmt_nonEmpty */
    case 171: /* for_action_stmt */
    case 172: /* for_header1 */
    case 173: /* for_header2 */
    case 174: /* for_header */
    case 175: /* foreach_opener */
    case 176: /* foreach_header */
{
 delete (yypminor->yy0); 
}
      break;
    case 86: /* error */
{

}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from ParseAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void ParseFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   ParseARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
   ParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 87, 1 },
  { 88, 0 },
  { 88, 2 },
  { 88, 2 },
  { 89, 1 },
  { 89, 2 },
  { 89, 1 },
  { 89, 1 },
  { 89, 1 },
  { 89, 1 },
  { 89, 2 },
  { 89, 2 },
  { 89, 2 },
  { 89, 2 },
  { 89, 1 },
  { 101, 2 },
  { 101, 2 },
  { 102, 2 },
  { 102, 3 },
  { 90, 4 },
  { 90, 2 },
  { 103, 1 },
  { 103, 3 },
  { 91, 4 },
  { 91, 2 },
  { 104, 0 },
  { 104, 2 },
  { 106, 6 },
  { 92, 2 },
  { 93, 7 },
  { 109, 3 },
  { 109, 5 },
  { 109, 4 },
  { 112, 6 },
  { 113, 2 },
  { 109, 2 },
  { 94, 3 },
  { 95, 3 },
  { 95, 5 },
  { 108, 2 },
  { 108, 1 },
  { 115, 1 },
  { 116, 1 },
  { 100, 2 },
  { 100, 3 },
  { 117, 1 },
  { 117, 2 },
  { 114, 1 },
  { 114, 1 },
  { 114, 2 },
  { 114, 2 },
  { 114, 2 },
  { 114, 2 },
  { 114, 2 },
  { 114, 2 },
  { 114, 1 },
  { 114, 1 },
  { 114, 1 },
  { 114, 1 },
  { 114, 1 },
  { 114, 1 },
  { 114, 1 },
  { 114, 2 },
  { 114, 2 },
  { 114, 2 },
  { 118, 1 },
  { 118, 2 },
  { 118, 2 },
  { 135, 1 },
  { 135, 3 },
  { 136, 1 },
  { 136, 3 },
  { 111, 1 },
  { 111, 3 },
  { 107, 0 },
  { 107, 1 },
  { 137, 1 },
  { 137, 3 },
  { 105, 6 },
  { 110, 6 },
  { 105, 1 },
  { 105, 3 },
  { 139, 0 },
  { 139, 1 },
  { 110, 1 },
  { 110, 1 },
  { 110, 1 },
  { 110, 1 },
  { 110, 3 },
  { 110, 4 },
  { 140, 5 },
  { 110, 2 },
  { 141, 1 },
  { 141, 3 },
  { 142, 1 },
  { 142, 3 },
  { 143, 0 },
  { 143, 1 },
  { 143, 2 },
  { 124, 1 },
  { 138, 4 },
  { 138, 4 },
  { 97, 4 },
  { 97, 4 },
  { 110, 1 },
  { 110, 3 },
  { 144, 1 },
  { 144, 0 },
  { 110, 4 },
  { 110, 4 },
  { 110, 4 },
  { 110, 4 },
  { 110, 4 },
  { 110, 4 },
  { 110, 4 },
  { 110, 5 },
  { 110, 5 },
  { 110, 5 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 2 },
  { 110, 2 },
  { 110, 2 },
  { 110, 5 },
  { 110, 5 },
  { 110, 5 },
  { 110, 5 },
  { 110, 5 },
  { 110, 5 },
  { 110, 6 },
  { 110, 6 },
  { 110, 6 },
  { 110, 6 },
  { 110, 6 },
  { 110, 6 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 3 },
  { 110, 2 },
  { 96, 2 },
  { 119, 2 },
  { 121, 4 },
  { 120, 5 },
  { 98, 4 },
  { 122, 4 },
  { 99, 4 },
  { 145, 1 },
  { 145, 4 },
  { 145, 3 },
  { 146, 1 },
  { 146, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 2 },
  { 123, 2 },
  { 123, 2 },
  { 123, 2 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 123, 3 },
  { 147, 1 },
  { 148, 3 },
  { 149, 3 },
  { 150, 1 },
  { 149, 2 },
  { 126, 1 },
  { 151, 1 },
  { 152, 3 },
  { 153, 3 },
  { 154, 2 },
  { 155, 3 },
  { 153, 4 },
  { 156, 1 },
  { 127, 1 },
  { 127, 3 },
  { 157, 3 },
  { 157, 3 },
  { 158, 1 },
  { 159, 3 },
  { 160, 1 },
  { 160, 2 },
  { 161, 2 },
  { 161, 1 },
  { 162, 2 },
  { 163, 1 },
  { 163, 2 },
  { 164, 5 },
  { 164, 4 },
  { 164, 3 },
  { 131, 2 },
  { 165, 1 },
  { 166, 3 },
  { 128, 3 },
  { 167, 2 },
  { 168, 1 },
  { 168, 1 },
  { 168, 1 },
  { 168, 1 },
  { 168, 3 },
  { 169, 1 },
  { 169, 0 },
  { 170, 1 },
  { 170, 1 },
  { 170, 3 },
  { 171, 0 },
  { 171, 1 },
  { 172, 3 },
  { 173, 3 },
  { 174, 2 },
  { 129, 3 },
  { 175, 2 },
  { 176, 4 },
  { 130, 3 },
  { 132, 1 },
  { 133, 1 },
  { 134, 2 },
  { 110, 4 },
  { 110, 4 },
  { 125, 5 },
  { 125, 5 },
  { 110, 4 },
  { 110, 4 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ParseARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* program ::= chunks */
{
  yy_destructor(yypParser,88,&yymsp[0].minor);
}
        break;
      case 2: /* chunks ::= chunks chunk */
{
  yy_destructor(yypParser,88,&yymsp[-1].minor);
  yy_destructor(yypParser,89,&yymsp[0].minor);
}
        break;
      case 3: /* chunks ::= chunks error */
{
    throw_error(13494, "Chunk-level error");
  yy_destructor(yypParser,88,&yymsp[-1].minor);
  yy_destructor(yypParser,86,&yymsp[0].minor);
}
        break;
      case 4: /* chunk ::= relimp_chunk */
{
  yy_destructor(yypParser,90,&yymsp[0].minor);
}
        break;
      case 5: /* chunk ::= import_chunk SEMICOLON */
{
  yy_destructor(yypParser,91,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 6: /* chunk ::= fdef_chunk */
{
  yy_destructor(yypParser,92,&yymsp[0].minor);
}
        break;
      case 7: /* chunk ::= fdecl_chunk */
{
  yy_destructor(yypParser,93,&yymsp[0].minor);
}
        break;
      case 8: /* chunk ::= objdef_chunk */
{
  yy_destructor(yypParser,94,&yymsp[0].minor);
}
        break;
      case 9: /* chunk ::= objdecl_chunk */
{
  yy_destructor(yypParser,95,&yymsp[0].minor);
}
        break;
      case 10: /* chunk ::= vdef_global_stmt SEMICOLON */
{
  yy_destructor(yypParser,96,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 11: /* chunk ::= funccall_global_stmt SEMICOLON */
{
  yy_destructor(yypParser,97,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 12: /* chunk ::= vdefAssign_global_stmt SEMICOLON */
{
  yy_destructor(yypParser,98,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 13: /* chunk ::= cdef_global_stmt SEMICOLON */
{
  yy_destructor(yypParser,99,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 14: /* chunk ::= blockStmt */
{
    throw_error(48993, "Misplaced block statement");
  yy_destructor(yypParser,100,&yymsp[0].minor);
}
        break;
      case 15: /* relimp_start ::= IMPORT PERIOD */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->data = ".";
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yy_destructor(yypParser,29,&yymsp[0].minor);
}
        break;
      case 16: /* relimp_start ::= relimp_start PERIOD */
{
    yymsp[-1].minor.yy0->data = yymsp[-1].minor.yy0->data + ".";
    yygotominor.yy0 = yymsp[-1].minor.yy0;
  yy_destructor(yypParser,29,&yymsp[0].minor);
}
        break;
      case 17: /* relimp_path ::= relimp_start NAME */
{
    yymsp[0].minor.yy0->data = yymsp[-1].minor.yy0->data + yymsp[0].minor.yy0->data;
    delete yymsp[-1].minor.yy0;
    yygotominor.yy0 = yymsp[0].minor.yy0;
}
        break;
      case 18: /* relimp_path ::= relimp_path PERIOD NAME */
      case 22: /* dottedName ::= dottedName PERIOD NAME */ yytestcase(yyruleno==22);
{
    yymsp[0].minor.yy0->data = yymsp[-2].minor.yy0->data + "." + yymsp[0].minor.yy0->data;
    delete yymsp[-2].minor.yy0;
    yygotominor.yy0 = yymsp[0].minor.yy0;
  yy_destructor(yypParser,29,&yymsp[-1].minor);
}
        break;
      case 19: /* relimp_chunk ::= relimp_path AS NAME SEMICOLON */
{
    std::string impPath, impModname;
    bool isPy = impPathProcess(yymsp[-3].minor.yy0->data, impPath, impModname);
    if(isBuiltinConst(yymsp[-1].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[-1].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-1].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if (isPy && !ps->closure.defPyModule(yymsp[-1].minor.yy0->data)) {
        throw_error(6754, "Importing already-declared module " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    } else if (!isPy && !ps->closure.defModule(yymsp[-1].minor.yy0->data)) {
        throw_error(6754, "Importing already-declared module " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }

    ps->gen << "try:\n";
    ps->gen.indent();
    ps->gen << yymsp[-1].minor.yy0->data << " = _RELIMP(\"" << impPath << "\", \"" << impModname << "\")" << std::endl;
    ps->gen.unindent(false);
    ps->gen << "except ImportError:\n";
    ps->gen.indent();
    if(!impPath.empty()) ps->gen << "from " << impPath << " ";
    ps->gen << "import " << impModname << " as " << yymsp[-1].minor.yy0->data << std::endl;
    ps->gen.unindent(false);

    delete yymsp[-3].minor.yy0; delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,33,&yymsp[-2].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 20: /* relimp_chunk ::= relimp_path SEMICOLON */
{
    std::string impPath, impModname;
    bool isPy = impPathProcess(yymsp[-1].minor.yy0->data, impPath, impModname);

    if(isBuiltinConst(impModname)) {
        throw_error(6755, "Name collision with eudplib global " + impModname, yymsp[-1].minor.yy0->line);
    }
    if(isPyKeyword(impModname)) {
        throw_error(6756, "Name collision with Python keyword " + impModname, yymsp[-1].minor.yy0->line);
    }
    if(isPyBuiltin(impModname)) {
        throw_error(6757, "Name collision with Python builtin " + impModname, yymsp[-1].minor.yy0->line);
    }
    if (isPy && !ps->closure.defPyModule(impModname)) {
        throw_error(6754, "Importing already-declared module " + impModname, yymsp[-1].minor.yy0->line);
    } else if (!isPy && !ps->closure.defModule(impModname)) {
        throw_error(6754, "Importing already-declared module " + impModname, yymsp[-1].minor.yy0->line);
    }

    ps->gen << "try:\n";
    ps->gen.indent();
    ps->gen << impModname << " = _RELIMP(\"" << impPath << "\", \"" << impModname << "\")" << std::endl;
    ps->gen.unindent(false);
    ps->gen << "except ImportError:\n";
    ps->gen.indent();
    if(!impPath.empty()) ps->gen << "from " << impPath << " ";
    ps->gen << "import " << impModname << std::endl;
    ps->gen.unindent(false);

    delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 21: /* dottedName ::= NAME */
      case 68: /* numList_nonEmpty ::= NUMBER */ yytestcase(yyruleno==68);
      case 75: /* typedNameList ::= typedNameList_nonEmpty */ yytestcase(yyruleno==75);
      case 76: /* nameList_nonEmpty ::= NAME */ yytestcase(yyruleno==76);
      case 80: /* exprList_nonEmpty ::= expr */ yytestcase(yyruleno==80);
      case 83: /* exprList ::= exprList_nonEmpty */ yytestcase(yyruleno==83);
      case 84: /* expr ::= NUMBER */ yytestcase(yyruleno==84);
      case 85: /* expr ::= STRING */ yytestcase(yyruleno==85);
      case 92: /* fArg ::= expr */ yytestcase(yyruleno==92);
      case 94: /* fArgs_nonEmpty ::= fArg */ yytestcase(yyruleno==94);
      case 97: /* fArgs ::= fArgs_nonEmpty */ yytestcase(yyruleno==97);
      case 104: /* expr ::= funcexpr */ yytestcase(yyruleno==104);
      case 162: /* lvalueList_nonEmpty ::= lvalue */ yytestcase(yyruleno==162);
{ yygotominor.yy0 = yymsp[0].minor.yy0; }
        break;
      case 23: /* import_chunk ::= IMPORT dottedName AS NAME */
{
    std::string impPath, impModname;
    bool isPy = impPathProcess(yymsp[-2].minor.yy0->data, impPath, impModname);

    if(isBuiltinConst(yymsp[0].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[0].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[0].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    }
    if (isPy && !ps->closure.defPyModule(yymsp[0].minor.yy0->data)) {
        throw_error(6754, "Importing already-declared module " + yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    } else if (!isPy && !ps->closure.defModule(yymsp[0].minor.yy0->data)) {
        throw_error(6754, "Importing already-declared module " + yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    }

    if(!impPath.empty()) ps->gen << "from " << impPath << " ";
    ps->gen << "import " << impModname << " as " << yymsp[0].minor.yy0->data << std::endl;
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,31,&yymsp[-3].minor);
  yy_destructor(yypParser,33,&yymsp[-1].minor);
}
        break;
      case 24: /* import_chunk ::= IMPORT dottedName */
{
    std::string impPath, impModname;
    bool isPy = impPathProcess(yymsp[0].minor.yy0->data, impPath, impModname);

    if(isBuiltinConst(impModname)) {
        throw_error(6755, "Name collision with eudplib global " + impModname, yymsp[0].minor.yy0->line);
    }
    if(isPyKeyword(impModname)) {
        throw_error(6756, "Name collision with Python keyword " + impModname, yymsp[0].minor.yy0->line);
    }
    if(isPyBuiltin(impModname)) {
        throw_error(6757, "Name collision with Python builtin " + impModname, yymsp[0].minor.yy0->line);
    }
    if (isPy && !ps->closure.defPyModule(impModname)) {
        throw_error(6754, "Importing already-declared module " + impModname, yymsp[0].minor.yy0->line);
    } else if (!isPy && !ps->closure.defModule(impModname)) {
        throw_error(6754, "Importing already-declared module " + impModname, yymsp[0].minor.yy0->line);
    }

    if(!impPath.empty()) ps->gen << "from " << impPath << " ";
    ps->gen << "import " << impModname << std::endl;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,31,&yymsp[-1].minor);
}
        break;
      case 25: /* fdef_rettypes ::= */
      case 74: /* typedNameList ::= */ yytestcase(yyruleno==74);
{ yygotominor.yy0 = nullptr; }
        break;
      case 26: /* fdef_rettypes ::= COLON exprList_nonEmpty */
{ yygotominor.yy0 = yymsp[0].minor.yy0;   yy_destructor(yypParser,34,&yymsp[-1].minor);
}
        break;
      case 27: /* fdef_header ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes */
{
    // Preprocess yymsp[-4].minor.yy0
    funcNamePreprocess(yymsp[-4].minor.yy0->data);
    if(isPyKeyword(yymsp[-4].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-4].minor.yy0->data, yymsp[-4].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-4].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-4].minor.yy0->data, yymsp[-4].minor.yy0->line);
    }
    if(!ps->closure.defFunction(yymsp[-4].minor.yy0->data)) {
        throw_error(4495, "Duplicate function " + yymsp[-4].minor.yy0->data, yymsp[-4].minor.yy0->line);
    }

    ps->closure.pushScope();
    currentFunction = yymsp[-4].minor.yy0->data;

    // Register variables.
    // yymsp[-2].minor.yy0->data is a comma-separated list of (yymsp[-4].minor.yy0, type). To pair names and types,
    // we store varname in odd loops and define variables on even loops.
    std::string argname;
    std::vector<std::string> argnames, argtypes;
    bool isTypedFunction = !!yymsp[0].minor.yy0;

    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto argnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string argname = argnameToken->data;

        if(isPyKeyword(argname)) {
            throw_error(6756, "Name collision with Python keyword " + argname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(argname)) {
            throw_error(196, ("Redeclaration of variable \'" + argname + "\'"), yymsp[-2].minor.yy0->line);
        }
        argnames.push_back(argname);
        if(typeToken == nullptr) {
            argtypes.push_back("None");
        }
        else {
            isTypedFunction = true;
            argtypes.push_back(typeToken->data);
        }
    });

    // Add decorator header
    if (!isTypedFunction) {
        if(MAP_DEBUG) ps->gen << "@EUDTracedFunc" << std::endl;
        else ps->gen << "@EUDFunc" << std::endl;
    }
    else {
        if(MAP_DEBUG) ps->gen << "@EUDTracedTypedFunc([";
        else ps->gen << "@EUDTypedFunc([";
        writeStringList(ps->gen, argtypes);
        if(!yymsp[0].minor.yy0) ps->gen << "])" << std::endl;
        else ps->gen << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;
    }

    // Write argument names
    ps->gen << "def " << yymsp[-4].minor.yy0->data << "(";
    writeStringList(ps->gen, argnames);
    ps->gen << "):" << std::endl;

    ps->gen.indent();

    tmpIndex = 1;
    delete yymsp[-4].minor.yy0;
    delete yymsp[-2].minor.yy0;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,35,&yymsp[-5].minor);
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
}
        break;
      case 28: /* fdef_chunk ::= fdef_header stmt */
{
    ps->gen.unindent(true);
    ps->closure.popScope();
    currentFunction = "";
  yy_destructor(yypParser,106,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 29: /* fdecl_chunk ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes SEMICOLON */
{
    // Preprocess yymsp[-5].minor.yy0
    funcNamePreprocess(yymsp[-5].minor.yy0->data);
    if(isPyKeyword(yymsp[-5].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-5].minor.yy0->data, yymsp[-5].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-5].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-5].minor.yy0->data, yymsp[-5].minor.yy0->line);
    }
    if(!ps->closure.declareFunction(yymsp[-5].minor.yy0->data)) {
        throw_error(72461, "Declaring function with non-function yymsp[-5].minor.yy0 " + yymsp[-5].minor.yy0->data, yymsp[-5].minor.yy0->line);
    }
  yy_destructor(yypParser,35,&yymsp[-6].minor);
  yy_destructor(yypParser,27,&yymsp[-4].minor);
  yy_destructor(yypParser,107,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-2].minor);
  yy_destructor(yypParser,104,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 30: /* object_body ::= OBJECT NAME LBRACKET */
{
    ps->gen << "class " << yymsp[-1].minor.yy0->data << "(EUDStruct):\n";
    ps->gen.indent();

    if(isBuiltinConst(yymsp[-1].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[-1].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-1].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(!ps->closure.defConstant(yymsp[-1].minor.yy0->data)) {
        throw_error(8228, "Declaring object with non-function yymsp[-1].minor.yy0 " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    ps->closure.pushScope();

    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[-1].minor.yy0;
    yygotominor.yy0->subToken[1] = nullptr;
  yy_destructor(yypParser,37,&yymsp[-2].minor);
  yy_destructor(yypParser,38,&yymsp[0].minor);
}
        break;
      case 31: /* object_body ::= OBJECT NAME EXTENDS expr LBRACKET */
{
    ps->gen << "class " << yymsp[-3].minor.yy0->data << "(" << yymsp[-1].minor.yy0->data << "):\n";
    ps->gen.indent();

    if(isBuiltinConst(yymsp[-3].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[-3].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-3].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(!ps->closure.defConstant(yymsp[-3].minor.yy0->data)) {
        throw_error(8228, "Declaring object with non-function yymsp[-3].minor.yy0 " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    ps->closure.pushScope();

    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[-3].minor.yy0;
    yygotominor.yy0->subToken[1] = nullptr;
  yy_destructor(yypParser,37,&yymsp[-4].minor);
  yy_destructor(yypParser,39,&yymsp[-2].minor);
  yy_destructor(yypParser,38,&yymsp[0].minor);
}
        break;
      case 32: /* object_body ::= object_body VAR typedNameList_nonEmpty SEMICOLON */
{
    yygotominor.yy0 = yymsp[-3].minor.yy0;

    // Append to subTokenList
    Token* t = genEmpty();
    t->subToken[0] = yymsp[-1].minor.yy0;
    t->subToken[1] = nullptr;
    subTokenListGetTail(yygotominor.yy0)->subToken[1] = t;
    yygotominor.yy0->line = currentTokenizingLine;
  yy_destructor(yypParser,40,&yymsp[-2].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 33: /* method_header ::= FUNCTION NAME LPAREN typedNameList RPAREN fdef_rettypes */
{
    // Method can't be called directly, so we shouldn't have to register it to closure.
    // duplicate method names should be checked at python-compile time.

    ps->closure.pushScope();
    if(isPyKeyword(yymsp[-4].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-4].minor.yy0->data, yymsp[-4].minor.yy0->line);
    }

    // Register variables.
    std::string _this = "this";  // This may be modified...?
    if(!ps->closure.defConstant(_this)) {
        throw_error(656, ("Redeclaration of variable \'this\'"), yymsp[-2].minor.yy0->line);
    }

    std::string argname;
    std::vector<std::string> argnames, argtypes, rettypes;
    bool isTypedFunction = !!yymsp[0].minor.yy0;

    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto argnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string argname = argnameToken->data;

        if(isPyKeyword(argname)) {
            throw_error(6756, "Name collision with Python keyword " + argname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(argname)) {
            throw_error(2656, ("Redeclaration of variable \'" + argname + "\'"), yymsp[-2].minor.yy0->line);
        }
        argnames.push_back(argname);
        if(typeToken == nullptr) {
            argtypes.push_back("None");
        }
        else {
            isTypedFunction = true;
            argtypes.push_back(typeToken->data);
        }
    });

    // Add decorator header
    if (!isTypedFunction) {
        if(MAP_DEBUG) ps->gen << "@EUDTracedMethod\n";
        else ps->gen << "@EUDMethod\n";
    }
    else {
        if(MAP_DEBUG) ps->gen << "@EUDTracedTypedMethod([";
        else ps->gen << "@EUDTypedMethod([";
        writeStringList(ps->gen, argtypes);
        if(!yymsp[0].minor.yy0) ps->gen << "])" << std::endl;
        else ps->gen << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;
    }

    // Add default argument 'self'
    ps->gen << "def " << yymsp[-4].minor.yy0->data << "(" << _this;
    if (argnames.empty()) ps->gen << "):" << std::endl;
    else {
        ps->gen << ", ";
        writeStringList(ps->gen, argnames);
        ps->gen << "):" << std::endl;
    }
    ps->gen.indent();

    currentFunction = yymsp[-4].minor.yy0->data;

    tmpIndex = 1;
    delete yymsp[-2].minor.yy0;
    delete yymsp[0].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-4].minor.yy0);
  yy_destructor(yypParser,35,&yymsp[-5].minor);
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
}
        break;
      case 34: /* method_chunk ::= method_header stmt */
{
    ps->gen.unindent(true);
    ps->closure.popScope();
    currentFunction = "";
    yygotominor.yy0 = yymsp[-1].minor.yy0;
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 35: /* object_body ::= object_body method_chunk */
{
    yygotominor.yy0 = yymsp[-1].minor.yy0;
    yygotominor.yy0->line = currentTokenizingLine;
  yy_destructor(yypParser,113,&yymsp[0].minor);
}
        break;
      case 36: /* objdef_chunk ::= object_body RBRACKET SEMICOLON */
{
    ps->gen << "_fields_ = [\n";
    subTokenListIter(yymsp[-2].minor.yy0->subToken[1], [&](const Token* tok) {
        subTokenListIter(tok, [&](const Token* nameType) {
            ps->gen.indent();
            if(isPyKeyword(nameType->subToken[0]->data)) {
                throw_error(6756, "Name collision with Python keyword " + nameType->subToken[0]->data, yymsp[-2].minor.yy0->line);
            }
            if(!ps->closure.defConstant(nameType->subToken[0]->data)) {
                throw_error(7720, ("Duplicated field name \'" + nameType->subToken[0]->data + "\'"), yymsp[-2].minor.yy0->line);
            }
            if(nameType->subToken[1]) {
                ps->gen << "('" << nameType->subToken[0]->data << "', " << nameType->subToken[1]->data << "),\n";
            }
            else {
                ps->gen << "'" << nameType->subToken[0]->data << "',\n";
            }
            ps->gen.unindent(false);
        });
    });
    ps->gen << "]\n";
    ps->closure.popScope();
    ps->gen.unindent(true);
    delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,41,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 37: /* objdecl_chunk ::= OBJECT NAME SEMICOLON */
{
    if(isBuiltinConst(yymsp[-1].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[-1].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-1].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
    if(!ps->closure.declareConstant(yymsp[-1].minor.yy0->data)) {
        throw_error(8228, "Declaring object with non-function yymsp[-1].minor.yy0 " + yymsp[-1].minor.yy0->data, yymsp[-1].minor.yy0->line);
    }
  yy_destructor(yypParser,37,&yymsp[-2].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 38: /* objdecl_chunk ::= OBJECT NAME EXTENDS expr SEMICOLON */
{
    if(isBuiltinConst(yymsp[-3].minor.yy0->data)) {
        throw_error(6755, "Name collision with eudplib global " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(isPyKeyword(yymsp[-3].minor.yy0->data)) {
        throw_error(6756, "Name collision with Python keyword " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(isPyBuiltin(yymsp[-3].minor.yy0->data)) {
        throw_error(6757, "Name collision with Python builtin " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
    if(!ps->closure.declareConstant(yymsp[-3].minor.yy0->data)) {
        throw_error(8228, "Declaring object with non-function yymsp[-3].minor.yy0 " + yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    }
  yy_destructor(yypParser,37,&yymsp[-4].minor);
  yy_destructor(yypParser,39,&yymsp[-2].minor);
  yy_destructor(yypParser,110,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 39: /* stmt ::= error SEMICOLON */
{ throw_error(6974, "Error while parsing statement", yymsp[0].minor.yy0->line); delete yymsp[0].minor.yy0;   yy_destructor(yypParser,86,&yymsp[-1].minor);
}
        break;
      case 40: /* stmt ::= bodyStmt */
      case 65: /* bodyStmtList ::= bodyStmt */ yytestcase(yyruleno==65);
{
  yy_destructor(yypParser,114,&yymsp[0].minor);
}
        break;
      case 41: /* lbracket ::= LBRACKET */
{ ps->closure.pushScope();   yy_destructor(yypParser,38,&yymsp[0].minor);
}
        break;
      case 42: /* rbracket ::= RBRACKET */
{ ps->closure.popScope();   yy_destructor(yypParser,41,&yymsp[0].minor);
}
        break;
      case 43: /* blockStmt ::= blockStmtSub rbracket */
{
  yy_destructor(yypParser,117,&yymsp[-1].minor);
  yy_destructor(yypParser,116,&yymsp[0].minor);
}
        break;
      case 44: /* blockStmt ::= lbracket error RBRACKET */
{
    throw_error(6298, "Block not terminated properly.", yymsp[0].minor.yy0->line);
    ps->closure.popScope();
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,115,&yymsp[-2].minor);
  yy_destructor(yypParser,86,&yymsp[-1].minor);
}
        break;
      case 45: /* blockStmtSub ::= lbracket */
{
  yy_destructor(yypParser,115,&yymsp[0].minor);
}
        break;
      case 46: /* blockStmtSub ::= lbracket bodyStmtList */
{
  yy_destructor(yypParser,115,&yymsp[-1].minor);
  yy_destructor(yypParser,118,&yymsp[0].minor);
}
        break;
      case 47: /* bodyStmt ::= blockStmt */
{
  yy_destructor(yypParser,100,&yymsp[0].minor);
}
        break;
      case 48: /* bodyStmt ::= SEMICOLON */
{
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 49: /* bodyStmt ::= vdef_stmt SEMICOLON */
{
  yy_destructor(yypParser,119,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 50: /* bodyStmt ::= vdefAssignStatic_stmt SEMICOLON */
{
  yy_destructor(yypParser,120,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 51: /* bodyStmt ::= vdefAssign_stmt SEMICOLON */
{
  yy_destructor(yypParser,121,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 52: /* bodyStmt ::= cdef_stmt SEMICOLON */
{
  yy_destructor(yypParser,122,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 53: /* bodyStmt ::= assign_stmt SEMICOLON */
{
  yy_destructor(yypParser,123,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 54: /* bodyStmt ::= funcexprStmt SEMICOLON */
{
  yy_destructor(yypParser,124,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 55: /* bodyStmt ::= actionStmt */
{
  yy_destructor(yypParser,125,&yymsp[0].minor);
}
        break;
      case 56: /* bodyStmt ::= once_stmt */
{
  yy_destructor(yypParser,126,&yymsp[0].minor);
}
        break;
      case 57: /* bodyStmt ::= if_stmt */
{
  yy_destructor(yypParser,127,&yymsp[0].minor);
}
        break;
      case 58: /* bodyStmt ::= while_stmt */
{
  yy_destructor(yypParser,128,&yymsp[0].minor);
}
        break;
      case 59: /* bodyStmt ::= for_stmt */
{
  yy_destructor(yypParser,129,&yymsp[0].minor);
}
        break;
      case 60: /* bodyStmt ::= foreach_stmt */
{
  yy_destructor(yypParser,130,&yymsp[0].minor);
}
        break;
      case 61: /* bodyStmt ::= switchcase_stmt */
{
  yy_destructor(yypParser,131,&yymsp[0].minor);
}
        break;
      case 62: /* bodyStmt ::= continue_stmt SEMICOLON */
{
  yy_destructor(yypParser,132,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 63: /* bodyStmt ::= break_stmt SEMICOLON */
{
  yy_destructor(yypParser,133,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 64: /* bodyStmt ::= return_stmt SEMICOLON */
{
  yy_destructor(yypParser,134,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 66: /* bodyStmtList ::= bodyStmtList bodyStmt */
{
  yy_destructor(yypParser,118,&yymsp[-1].minor);
  yy_destructor(yypParser,114,&yymsp[0].minor);
}
        break;
      case 67: /* bodyStmtList ::= bodyStmtList error */
{
    throw_error(8510, "Incomplete statement. Check if the previous line have ended properly.");
  yy_destructor(yypParser,118,&yymsp[-1].minor);
  yy_destructor(yypParser,86,&yymsp[0].minor);
}
        break;
      case 69: /* numList_nonEmpty ::= numList_nonEmpty COMMA NUMBER */
      case 77: /* nameList_nonEmpty ::= nameList_nonEmpty COMMA NAME */ yytestcase(yyruleno==77);
      case 163: /* lvalueList_nonEmpty ::= lvalueList_nonEmpty COMMA lvalue */ yytestcase(yyruleno==163);
{ yygotominor.yy0 = commaConcat(yymsp[-2].minor.yy0, yymsp[0].minor.yy0);   yy_destructor(yypParser,5,&yymsp[-1].minor);
}
        break;
      case 70: /* typedName ::= NAME */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[0].minor.yy0;
    yygotominor.yy0->subToken[1] = nullptr;  // Type is null.
}
        break;
      case 71: /* typedName ::= NAME COLON expr */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[-2].minor.yy0;
    yygotominor.yy0->subToken[1] = yymsp[0].minor.yy0;
  yy_destructor(yypParser,34,&yymsp[-1].minor);
}
        break;
      case 72: /* typedNameList_nonEmpty ::= typedName */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[0].minor.yy0;
    yygotominor.yy0->subToken[1] = nullptr;
}
        break;
      case 73: /* typedNameList_nonEmpty ::= typedName COMMA typedNameList_nonEmpty */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->subToken[0] = yymsp[-2].minor.yy0;
    yygotominor.yy0->subToken[1] = yymsp[0].minor.yy0;
  yy_destructor(yypParser,5,&yymsp[-1].minor);
}
        break;
      case 78: /* exprList_nonEmpty ::= funcexpr LSQBRACKET LSQBRACKET numList_nonEmpty RSQBRACKET RSQBRACKET */
{
    yymsp[-2].minor.yy0->data = "_SRET(" + yymsp[-5].minor.yy0->data + ", [" + yymsp[-2].minor.yy0->data + "])";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,28,&yymsp[-3].minor);
  yy_destructor(yypParser,43,&yymsp[-1].minor);
  yy_destructor(yypParser,43,&yymsp[0].minor);
}
        break;
      case 79: /* expr ::= funcexpr LSQBRACKET LSQBRACKET NUMBER RSQBRACKET RSQBRACKET */
{
    yymsp[-2].minor.yy0->data = yymsp[-5].minor.yy0->data + "[" + yymsp[-2].minor.yy0->data + "]";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,28,&yymsp[-3].minor);
  yy_destructor(yypParser,43,&yymsp[-1].minor);
  yy_destructor(yypParser,43,&yymsp[0].minor);
}
        break;
      case 81: /* exprList_nonEmpty ::= exprList_nonEmpty COMMA expr */
{ yygotominor.yy0 = new Token((yymsp[-2].minor.yy0->data) + ", " + (yymsp[0].minor.yy0->data), yymsp[0].minor.yy0->line); delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,5,&yymsp[-1].minor);
}
        break;
      case 82: /* exprList ::= */
      case 96: /* fArgs ::= */ yytestcase(yyruleno==96);
{ yygotominor.yy0 = genEmpty(); }
        break;
      case 86: /* expr ::= KILLS */
{
    yymsp[0].minor.yy0->data = "4";
    yygotominor.yy0 = yymsp[0].minor.yy0;
}
        break;
      case 87: /* expr ::= NAME */
{
    checkIsRValue(yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    yygotominor.yy0 = yymsp[0].minor.yy0;
}
        break;
      case 88: /* expr ::= expr PERIOD NAME */
{
    yymsp[-2].minor.yy0->data = yymsp[-2].minor.yy0->data + "." + yymsp[0].minor.yy0->data;
    delete yymsp[0].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,29,&yymsp[-1].minor);
}
        break;
      case 89: /* expr ::= expr LSQBRACKET expr RSQBRACKET */
{
    yymsp[-3].minor.yy0->data = yymsp[-3].minor.yy0->data + "[" + yymsp[-1].minor.yy0->data + "]";
    delete yymsp[-1].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-3].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-2].minor);
  yy_destructor(yypParser,43,&yymsp[0].minor);
}
        break;
      case 90: /* lambdaExprStart ::= FUNCTION LPAREN typedNameList RPAREN fdef_rettypes */
{
    std::string funcname = "_lambda" + std::to_string(++lambdaIndex);
    ps->closure.pushScope();

    // Register variables.
    // we store varname in odd loops and define variables on even loops.
    std::string argname;
    std::vector<std::string> argnames, argtypes, rettypes;
    bool isTypedFunction = !!yymsp[0].minor.yy0;

    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto argnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string argname = argnameToken->data;

        if(isPyKeyword(argname)) {
            throw_error(6756, "Name collision with Python keyword " + argname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(argname)) {
            throw_error(196, ("Redeclaration of variable \'" + argname + "\'"), yymsp[-2].minor.yy0->line);
        }
        argnames.push_back(argname);
        if(typeToken == nullptr) {
            argtypes.push_back("None");
        }
        else {
            isTypedFunction = true;
            argtypes.push_back(typeToken->data);
        }
    });

    // Add decorator header
    if (!isTypedFunction) {
        if(MAP_DEBUG) ps->gen << "@EUDTracedFunc" << std::endl;
        else ps->gen << "@EUDFunc" << std::endl;
    }
    else {
        if(MAP_DEBUG) ps->gen << "@EUDTracedTypedFunc([";
        else ps->gen << "@EUDTypedFunc([";
        writeStringList(ps->gen, argtypes);
        if(!yymsp[0].minor.yy0) ps->gen << "])" << std::endl;
        else ps->gen << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;
    }

    // Write argument names
    ps->gen << "def " << funcname << "(";
    writeStringList(ps->gen, argnames);
    ps->gen << "):" << std::endl;

    ps->gen.indent();
    tmpIndex = 1;

    delete yymsp[-2].minor.yy0;

    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->data = funcname;
  yy_destructor(yypParser,35,&yymsp[-4].minor);
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
}
        break;
      case 91: /* expr ::= lambdaExprStart stmt */
{
    ps->gen.unindent(true);
    ps->closure.popScope();
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 93: /* fArg ::= NAME ASSIGN expr */
{  // Keyword argument
    yymsp[0].minor.yy0->data = yymsp[-2].minor.yy0->data + "=" + yymsp[0].minor.yy0->data;
    yymsp[0].minor.yy0->type = TOKEN_TEMP;
    yygotominor.yy0 = yymsp[0].minor.yy0;
    delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 95: /* fArgs_nonEmpty ::= fArgs_nonEmpty COMMA fArg */
{
    yymsp[-2].minor.yy0->data = yymsp[-2].minor.yy0->data + ", " + yymsp[0].minor.yy0->data;
    yymsp[-2].minor.yy0->type = TOKEN_TEMP;
    yygotominor.yy0 = yymsp[-2].minor.yy0;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,5,&yymsp[-1].minor);
}
        break;
      case 98: /* fArgs ::= fArgs_nonEmpty COMMA */
{ yygotominor.yy0 = yymsp[-1].minor.yy0;   yy_destructor(yypParser,5,&yymsp[0].minor);
}
        break;
      case 99: /* funcexprStmt ::= funcexpr */
{
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    ps->gen << yymsp[0].minor.yy0->data << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 100: /* funcexpr ::= NAME LPAREN fArgs RPAREN */
{
    // Preprocess yymsp[-3].minor.yy0
    checkIsFunction(yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    yymsp[-3].minor.yy0->data += "(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-3].minor.yy0);
    delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 101: /* funcexpr ::= expr LPAREN fArgs RPAREN */
{
    // If calling function imported from another module, add f_ prefix to function yymsp[-3].minor.yy0.
    static std::regex prefixedFuncNameRegex("^[a-z][_a-zA-Z0-9]*");
    std::string& nameStr = yymsp[-3].minor.yy0->data;
    if(std::count(nameStr.begin(), nameStr.end(), '.') == 1) {
        size_t p = nameStr.find('.');
        std::string moduleName = nameStr.substr(0, p);
        std::string funcName = nameStr.substr(p + 1);
        if (closure->isModule(moduleName)) {
            if (!closure->isPyModule(moduleName) && std::regex_match(funcName, prefixedFuncNameRegex)) {
                funcNamePreprocess(funcName);
            }
            yymsp[-3].minor.yy0->data = moduleName + '.' + funcName;
        }
    }

    // Preprocess yymsp[-3].minor.yy0
    yymsp[-3].minor.yy0->data += "(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-3].minor.yy0);
    delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 102: /* funccall_global_stmt ::= NAME LPAREN fArgs RPAREN */
{
    // Preprocess yymsp[-3].minor.yy0
    checkIsFunction(yymsp[-3].minor.yy0->data, yymsp[-3].minor.yy0->line);
    ps->gen << yymsp[-3].minor.yy0->data << "(" << yymsp[-1].minor.yy0->data << ")" << std::endl;
    delete yymsp[-3].minor.yy0; delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 103: /* funccall_global_stmt ::= expr LPAREN fArgs RPAREN */
{
    // If calling function imported from another module, add f_ prefix to function yymsp[-3].minor.yy0.
    static std::regex prefixedFuncNameRegex("^[a-z][_a-zA-Z0-9]*");
    std::string& nameStr = yymsp[-3].minor.yy0->data;
    if(std::count(nameStr.begin(), nameStr.end(), '.') == 1) {
        size_t p = nameStr.find('.');
        std::string moduleName = nameStr.substr(0, p);
        std::string funcName = nameStr.substr(p + 1);
        if (closure->isModule(moduleName)) {
            if (!closure->isPyModule(moduleName) && std::regex_match(funcName, prefixedFuncNameRegex)) {
                funcNamePreprocess(funcName);
            }
            yymsp[-3].minor.yy0->data = moduleName + '.' + funcName;
        }
    }

    ps->gen << yymsp[-3].minor.yy0->data << "(" << yymsp[-1].minor.yy0->data << ")" << std::endl;
    delete yymsp[-3].minor.yy0; delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 105: /* expr ::= LPAREN expr RPAREN */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->data = "(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0->type = TOKEN_EXPR;
    yygotominor.yy0->subToken[0] = yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 106: /* commaSkippable ::= COMMA */
{
  yy_destructor(yypParser,5,&yymsp[0].minor);
}
        break;
      case 108: /* expr ::= LSQBRACKET exprList_nonEmpty commaSkippable RSQBRACKET */
{
    yymsp[-2].minor.yy0->data = "_ARR(FlattenList([" + yymsp[-2].minor.yy0->data + "]))";
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-3].minor);
  yy_destructor(yypParser,144,&yymsp[-1].minor);
  yy_destructor(yypParser,43,&yymsp[0].minor);
}
        break;
      case 109: /* expr ::= L2V LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "_L2V(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 110: /* expr ::= MAPSTRING LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "GetStringIndex(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,50,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 111: /* expr ::= UNIT LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "EncodeUnit(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,51,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 112: /* expr ::= SWITCH LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "EncodeSwitch(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,52,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 113: /* expr ::= LOCATION LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "EncodeLocation(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,53,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 114: /* expr ::= STATTXTTBL LPAREN expr RPAREN */
{
    yymsp[-1].minor.yy0->data = "EncodeTBL(" + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
  yy_destructor(yypParser,54,&yymsp[-3].minor);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 115: /* expr ::= VARRAY LPAREN exprList_nonEmpty commaSkippable RPAREN */
{
    yymsp[-2].minor.yy0->data = "_VARR(FlattenList([" + yymsp[-2].minor.yy0->data + "]))";
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,55,&yymsp[-4].minor);
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,144,&yymsp[-1].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 116: /* expr ::= LIST LPAREN exprList_nonEmpty commaSkippable RPAREN */
{
    yymsp[-2].minor.yy0->data = "FlattenList([" + yymsp[-2].minor.yy0->data + "])";
    yygotominor.yy0 = mkTokenTemp(yymsp[-2].minor.yy0);
  yy_destructor(yypParser,56,&yymsp[-4].minor);
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,144,&yymsp[-1].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 117: /* expr ::= expr QMARK expr COLON expr */
{
    std::stringstream ss;
    ss << "EUDTernary";
    applyNegativeOptimization(ss, yymsp[-4].minor.yy0);
    ss << "(" << yymsp[-2].minor.yy0->data << ")(" << yymsp[0].minor.yy0->data << ")";
    yymsp[0].minor.yy0->data = ss.str();
    delete yymsp[-4].minor.yy0;
    delete yymsp[-2].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);
  yy_destructor(yypParser,4,&yymsp[-3].minor);
  yy_destructor(yypParser,34,&yymsp[-1].minor);
}
        break;
      case 118: /* expr ::= expr PLUS expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "+",  yymsp[0].minor.yy0);   yy_destructor(yypParser,20,&yymsp[-1].minor);
}
        break;
      case 119: /* expr ::= expr MINUS expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "-",  yymsp[0].minor.yy0);   yy_destructor(yypParser,21,&yymsp[-1].minor);
}
        break;
      case 120: /* expr ::= expr MULTIPLY expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "*",  yymsp[0].minor.yy0);   yy_destructor(yypParser,23,&yymsp[-1].minor);
}
        break;
      case 121: /* expr ::= expr DIVIDE expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "//", yymsp[0].minor.yy0);   yy_destructor(yypParser,22,&yymsp[-1].minor);
}
        break;
      case 122: /* expr ::= expr MOD expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "%",  yymsp[0].minor.yy0);   yy_destructor(yypParser,24,&yymsp[-1].minor);
}
        break;
      case 123: /* expr ::= expr LSHIFT expr */
{
    yymsp[0].minor.yy0->data = "_LSH(" + yymsp[-2].minor.yy0->data + "," + yymsp[0].minor.yy0->data + ")";
    delete yymsp[-2].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);
  yy_destructor(yypParser,18,&yymsp[-1].minor);
}
        break;
      case 124: /* expr ::= expr RSHIFT expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, ">>", yymsp[0].minor.yy0);   yy_destructor(yypParser,19,&yymsp[-1].minor);
}
        break;
      case 125: /* expr ::= expr BITAND expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "&",  yymsp[0].minor.yy0);   yy_destructor(yypParser,17,&yymsp[-1].minor);
}
        break;
      case 126: /* expr ::= expr BITOR expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "|",  yymsp[0].minor.yy0);   yy_destructor(yypParser,15,&yymsp[-1].minor);
}
        break;
      case 127: /* expr ::= expr BITXOR expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "^",  yymsp[0].minor.yy0);   yy_destructor(yypParser,16,&yymsp[-1].minor);
}
        break;
      case 128: /* expr ::= PLUS expr */
{ yymsp[0].minor.yy0->data = "+" + yymsp[0].minor.yy0->data; yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);   yy_destructor(yypParser,20,&yymsp[-1].minor);
}
        break;
      case 129: /* expr ::= MINUS expr */
{ yymsp[0].minor.yy0->data = "-" + yymsp[0].minor.yy0->data; yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);   yy_destructor(yypParser,21,&yymsp[-1].minor);
}
        break;
      case 130: /* expr ::= BITNOT expr */
{ yymsp[0].minor.yy0->data = "~" + yymsp[0].minor.yy0->data; yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);   yy_destructor(yypParser,26,&yymsp[-1].minor);
}
        break;
      case 131: /* expr ::= expr PERIOD NAME EQ expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "==", yymsp[0].minor.yy0);
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,9,&yymsp[-1].minor);
}
        break;
      case 132: /* expr ::= expr PERIOD NAME NE expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, "==", yymsp[0].minor.yy0));
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
}
        break;
      case 133: /* expr ::= expr PERIOD NAME LE expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "<=", yymsp[0].minor.yy0);
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,10,&yymsp[-1].minor);
}
        break;
      case 134: /* expr ::= expr PERIOD NAME GE expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, ">=", yymsp[0].minor.yy0);
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,12,&yymsp[-1].minor);
}
        break;
      case 135: /* expr ::= expr PERIOD NAME LT expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, ">=", yymsp[0].minor.yy0));
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,11,&yymsp[-1].minor);
}
        break;
      case 136: /* expr ::= expr PERIOD NAME GT expr */
{
    yymsp[-2].minor.yy0->data = "_ATTC(" + yymsp[-4].minor.yy0->data + ", '" + yymsp[-2].minor.yy0->data + "')";
    delete yymsp[-4].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, "<=", yymsp[0].minor.yy0));
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,13,&yymsp[-1].minor);
}
        break;
      case 137: /* expr ::= expr LSQBRACKET expr RSQBRACKET EQ expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-3].minor.yy0, "==", yymsp[0].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,9,&yymsp[-1].minor);
}
        break;
      case 138: /* expr ::= expr LSQBRACKET expr RSQBRACKET NE expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-3].minor.yy0, "==", yymsp[0].minor.yy0));
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
}
        break;
      case 139: /* expr ::= expr LSQBRACKET expr RSQBRACKET LE expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-3].minor.yy0, "<=", yymsp[0].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,10,&yymsp[-1].minor);
}
        break;
      case 140: /* expr ::= expr LSQBRACKET expr RSQBRACKET GE expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = binopConcat(yymsp[-3].minor.yy0, ">=", yymsp[0].minor.yy0);
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,12,&yymsp[-1].minor);
}
        break;
      case 141: /* expr ::= expr LSQBRACKET expr RSQBRACKET LT expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-3].minor.yy0, ">=", yymsp[0].minor.yy0));
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,11,&yymsp[-1].minor);
}
        break;
      case 142: /* expr ::= expr LSQBRACKET expr RSQBRACKET GT expr */
{
    yymsp[-3].minor.yy0->data = "_ARRC(" + yymsp[-5].minor.yy0->data + ", " + yymsp[-3].minor.yy0->data + ")";
    delete yymsp[-5].minor.yy0;
    yygotominor.yy0 = negate(binopConcat(yymsp[-3].minor.yy0, "<=", yymsp[0].minor.yy0));
  yy_destructor(yypParser,28,&yymsp[-4].minor);
  yy_destructor(yypParser,43,&yymsp[-2].minor);
  yy_destructor(yypParser,13,&yymsp[-1].minor);
}
        break;
      case 143: /* expr ::= expr EQ expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "==", yymsp[0].minor.yy0);   yy_destructor(yypParser,9,&yymsp[-1].minor);
}
        break;
      case 144: /* expr ::= expr NE expr */
{ yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, "==", yymsp[0].minor.yy0));   yy_destructor(yypParser,14,&yymsp[-1].minor);
}
        break;
      case 145: /* expr ::= expr LE expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, "<=", yymsp[0].minor.yy0);   yy_destructor(yypParser,10,&yymsp[-1].minor);
}
        break;
      case 146: /* expr ::= expr GE expr */
{ yygotominor.yy0 = binopConcat(yymsp[-2].minor.yy0, ">=", yymsp[0].minor.yy0);   yy_destructor(yypParser,12,&yymsp[-1].minor);
}
        break;
      case 147: /* expr ::= expr LT expr */
{ yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, ">=", yymsp[0].minor.yy0));   yy_destructor(yypParser,11,&yymsp[-1].minor);
}
        break;
      case 148: /* expr ::= expr GT expr */
{ yygotominor.yy0 = negate(binopConcat(yymsp[-2].minor.yy0, "<=", yymsp[0].minor.yy0));   yy_destructor(yypParser,13,&yymsp[-1].minor);
}
        break;
      case 149: /* expr ::= expr LAND expr */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->line = yymsp[0].minor.yy0->line;

    // Generate data!
    yygotominor.yy0->type = TOKEN_LAND;
    yygotominor.yy0->subToken[0] = yymsp[-2].minor.yy0;
    yygotominor.yy0->subToken[1] = yymsp[0].minor.yy0;

    std::stringstream ss;
    ss << "EUDSCAnd()";
    shortCircuitCondListGetter(ss, yygotominor.yy0, TOKEN_LAND);
    ss << "()";
    yygotominor.yy0->data = ss.str();
  yy_destructor(yypParser,7,&yymsp[-1].minor);
}
        break;
      case 150: /* expr ::= expr LOR expr */
{
    yygotominor.yy0 = genEmpty();
    yygotominor.yy0->line = yymsp[0].minor.yy0->line;

    // Generate data!
    yygotominor.yy0->type = TOKEN_LOR;
    yygotominor.yy0->subToken[0] = yymsp[-2].minor.yy0;
    yygotominor.yy0->subToken[1] = yymsp[0].minor.yy0;

    std::stringstream ss;
    ss << "EUDSCOr()";
    shortCircuitCondListGetter(ss, yygotominor.yy0, TOKEN_LOR);
    ss << "()";
    yygotominor.yy0->data = ss.str();
  yy_destructor(yypParser,6,&yymsp[-1].minor);
}
        break;
      case 151: /* expr ::= LNOT expr */
{ yygotominor.yy0 = negate(yymsp[0].minor.yy0);   yy_destructor(yypParser,8,&yymsp[-1].minor);
}
        break;
      case 152: /* vdef_global_stmt ::= VAR typedNameList_nonEmpty */
{
    std::string varname;
    std::vector<std::string> varnames, vartypes;
    int varCount = 0;
    bool hasTypedVariable = false;

    // Register variables.
    subTokenListIter(yymsp[0].minor.yy0, [&](const Token* typedNameToken) {
        auto varnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string varname = varnameToken->data;

        if(isBuiltinConst(varname)) {
            throw_error(6755, "Name collision with eudplib global " + varname, yymsp[0].minor.yy0->line);
        }
        if(isPyKeyword(varname)) {
            throw_error(6756, "Name collision with Python keyword " + varname, yymsp[0].minor.yy0->line);
        }
        if(isPyBuiltin(varname)) {
            throw_error(6757, "Name collision with Python builtin " + varname, yymsp[0].minor.yy0->line);
        }
        if(!ps->closure.defVariable(varname)) {
            throw_error(196, ("Redeclaration of variable \'" + varname + "\'"), yymsp[0].minor.yy0->line);
        }
        if(typeToken == nullptr) {
            varnames.push_back(varname);
            vartypes.push_back("None");
        }
        else {
            throw_error(7278, "Typed variable without initial value is not supported", yymsp[0].minor.yy0->line);
            varnames.push_back(varname);
            vartypes.push_back(typeToken->data);
            hasTypedVariable = true;
        }
        varCount += 1;
    });

    writeStringList(ps->gen, varnames);
    if (!hasTypedVariable) {
        if(varCount == 1) {
            ps->gen << " = EUDVariable()" << std::endl;
        }
        else {
            ps->gen << " = EUDCreateVariables(" << varCount << ")" << std::endl;
        }
    } else {
        // FIXME: should we support typed variable declaration without initial value?
        if(varCount == 1) {
            ps->gen << " = EUDVariable()" << std::endl;
        }
        else {
            ps->gen << " = EUDCreateVariables(" << varCount << ")" << std::endl;
        }
    }

    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,40,&yymsp[-1].minor);
}
        break;
      case 153: /* vdef_stmt ::= VAR typedNameList_nonEmpty */
{
    std::string varname;
    std::vector<std::string> varnames, vartypes;
    int varCount = 0;
    bool hasTypedVariable = false;

    // Register variables.
    subTokenListIter(yymsp[0].minor.yy0, [&](const Token* typedNameToken) {
        auto varnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string varname = varnameToken->data;

        if(isPyKeyword(varname)) {
            throw_error(6756, "Name collision with Python keyword " + varname, yymsp[0].minor.yy0->line);
        }
        if(!ps->closure.defVariable(varname)) {
            throw_error(196, ("Redeclaration of variable \'" + varname + "\'"), yymsp[0].minor.yy0->line);
        }
        if(typeToken == nullptr) {
            varnames.push_back(varname);
            vartypes.push_back("None");
        }
        else {
            throw_error(7278, "Typed variable without initial value is not supported", yymsp[0].minor.yy0->line);
            varnames.push_back(varname);
            vartypes.push_back(typeToken->data);
            hasTypedVariable = true;
        }
        varCount += 1;
    });

    writeStringList(ps->gen, varnames);
    if (!hasTypedVariable) {
        if(varCount == 1) {
            ps->gen << " = EUDVariable()" << std::endl;
        }
        else {
            ps->gen << " = EUDCreateVariables(" << varCount << ")" << std::endl;
        }
    } else {
        // FIXME: should we support typed variable declaration without initial value?
        if(varCount == 1) {
            ps->gen << " = EUDVariable()" << std::endl;
        }
        else {
            ps->gen << " = EUDCreateVariables(" << varCount << ")" << std::endl;
        }
    }

    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,40,&yymsp[-1].minor);
}
        break;
      case 154: /* vdefAssign_stmt ::= VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty */
{
    writeTraceInfo(ps->gen, yymsp[-3].minor.yy0);
    delete yymsp[-3].minor.yy0;

    std::string varname;
    std::vector<std::string> varnames, vartypes;

    // Register variables.
    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto varnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string varname = varnameToken->data;

        if(isPyKeyword(varname)) {
            throw_error(6756, "Name collision with Python keyword " + varname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(varname)) {
            throw_error(7998, ("Redeclaration of variable \'" + varname + "\'"), yymsp[-2].minor.yy0->line);
        }
        if(typeToken == nullptr) {
            varnames.push_back(varname);
            vartypes.push_back("None");
        }
        else {
            varnames.push_back(varname);
            vartypes.push_back(typeToken->data);
        }
    });

    writeStringList(ps->gen, varnames);
    ps->gen << " = _TYLV([";
    writeStringList(ps->gen, vartypes);
    ps->gen << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;

    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 155: /* vdefAssignStatic_stmt ::= STATIC VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty */
{
    std::string varname;
    std::vector<std::string> varnames, vartypes;

    // Register variables.
    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto varnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string varname = varnameToken->data;

        if(isPyKeyword(varname)) {
            throw_error(6756, "Name collision with Python keyword " + varname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(varname)) {
            throw_error(7998, ("Redeclaration of variable \'" + varname + "\'"), yymsp[-2].minor.yy0->line);
        }
        if(typeToken == nullptr) {
            varnames.push_back(varname);
            vartypes.push_back("None");
        }
        else {
            varnames.push_back(varname);
            vartypes.push_back(typeToken->data);
        }
    });

    writeStringList(ps->gen, varnames);
    ps->gen << " = _TYSV([";
    writeStringList(ps->gen, vartypes);
    ps->gen << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;

    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,57,&yymsp[-4].minor);
  yy_destructor(yypParser,40,&yymsp[-3].minor);
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 156: /* vdefAssign_global_stmt ::= VAR typedNameList_nonEmpty ASSIGN exprList_nonEmpty */
{
    std::string varname;
    std::vector<std::string> varnames, vartypes;

    // Register variables.
    subTokenListIter(yymsp[-2].minor.yy0, [&](const Token* typedNameToken) {
        auto varnameToken = typedNameToken->subToken[0];
        auto typeToken = typedNameToken->subToken[1];
        std::string varname = varnameToken->data;

        if(isBuiltinConst(varname)) {
            throw_error(6755, "Name collision with eudplib global " + varname, yymsp[-2].minor.yy0->line);
        }
        if(isPyKeyword(varname)) {
            throw_error(6756, "Name collision with Python keyword " + varname, yymsp[-2].minor.yy0->line);
        }
        if(isPyBuiltin(varname)) {
            throw_error(6757, "Name collision with Python builtin " + varname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defVariable(varname)) {
            throw_error(7998, ("Redeclaration of variable \'" + varname + "\'"), yymsp[-2].minor.yy0->line);
        }
        if(typeToken == nullptr) {
            varnames.push_back(varname);
            vartypes.push_back("None");
        }
        else {
            varnames.push_back(varname);
            vartypes.push_back(typeToken->data);
        }
    });

    writeStringList(ps->gen, varnames);
    ps->gen << " = _TYGV([";
    writeStringList(ps->gen, vartypes);
    ps->gen << "], lambda: [" << yymsp[0].minor.yy0->data << "])" << std::endl;

    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,40,&yymsp[-3].minor);
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 157: /* cdef_stmt ::= CONST nameList_nonEmpty ASSIGN exprList_nonEmpty */
{
    writeTraceInfo(ps->gen, yymsp[-3].minor.yy0);
    delete yymsp[-3].minor.yy0;

    std::string& s = yymsp[-2].minor.yy0->data;
    int nameCount = std::count(s.begin(), s.end(), ',') + 1;

    // Register constants.
    commaListIter(s, [&](std::string& constname) {
        if(isPyKeyword(constname)) {
            throw_error(6756, "Name collision with Python keyword " + constname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defConstant(constname)) {
            throw_error(7719, ("Redeclaration of constant \'" + constname + "\'"), yymsp[-2].minor.yy0->line);
        }
    });
    if(nameCount == 1) {
        ps->gen << s << " = " << yymsp[0].minor.yy0->data << std::endl;
    }
    else {
        ps->gen << s << " = List2Assignable([" << yymsp[0].minor.yy0->data << "])" << std::endl;
    }
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 158: /* cdef_global_stmt ::= CONST nameList_nonEmpty ASSIGN exprList_nonEmpty */
{
    std::string& s = yymsp[-2].minor.yy0->data;
    int nameCount = std::count(s.begin(), s.end(), ',') + 1;

    // Register constants.
    commaListIter(s, [&](std::string& constname) {
        if(isBuiltinConst(constname)) {
            throw_error(6755, "Name collision with eudplib global " + constname, yymsp[-2].minor.yy0->line);
        }
        if(isPyKeyword(constname)) {
            throw_error(6756, "Name collision with Python keyword " + constname, yymsp[-2].minor.yy0->line);
        }
        if(checkPyBuiltinForEpsGlobalConst(constname)) {
            throw_error(6757, "Name collision with Python builtin " + constname, yymsp[-2].minor.yy0->line);
        }
        if(!ps->closure.defConstant(constname)) {
            throw_error(7719, ("Redeclaration of constant \'" + constname + "\'"), yymsp[-2].minor.yy0->line);
        }
    });
    if(nameCount == 1) {
        ps->gen << s << " = _CGFW(lambda: [" << yymsp[0].minor.yy0->data << "], 1)[0]" << std::endl;
    }
    else {
        ps->gen << s << " = List2Assignable(_CGFW(lambda: [" << yymsp[0].minor.yy0->data << "], " << nameCount << "))" << std::endl;
    }
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,58,&yymsp[-3].minor);
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 159: /* lvalue ::= NAME */
{
    checkIsVariable(yymsp[0].minor.yy0->data, yymsp[0].minor.yy0->line);
    yygotominor.yy0 = yymsp[0].minor.yy0;
}
        break;
      case 160: /* lvalue ::= expr LSQBRACKET expr RSQBRACKET */
{
    yymsp[-1].minor.yy0->data = "_ARRW(" + yymsp[-3].minor.yy0->data + ", " + yymsp[-1].minor.yy0->data + ")";
    yygotominor.yy0 = mkTokenTemp(yymsp[-1].minor.yy0);
    delete yymsp[-3].minor.yy0;
  yy_destructor(yypParser,28,&yymsp[-2].minor);
  yy_destructor(yypParser,43,&yymsp[0].minor);
}
        break;
      case 161: /* lvalue ::= expr PERIOD NAME */
{
    yymsp[0].minor.yy0->data = "_ATTW(" + yymsp[-2].minor.yy0->data + ", '" + yymsp[0].minor.yy0->data + "')";
    yygotominor.yy0 = mkTokenTemp(yymsp[0].minor.yy0);
    delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,29,&yymsp[-1].minor);
}
        break;
      case 164: /* assign_stmt ::= lvalue ASSIGN expr */
{
    writeTraceInfo(ps->gen, yymsp[-2].minor.yy0);
    ps->gen << yymsp[-2].minor.yy0->data << " << (" << yymsp[0].minor.yy0->data << ")" << std::endl;
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 165: /* assign_stmt ::= lvalueList_nonEmpty ASSIGN exprList_nonEmpty */
{
    writeTraceInfo(ps->gen, yymsp[-2].minor.yy0);
    ps->gen << "_SV([" << yymsp[-2].minor.yy0->data << "], [" << yymsp[0].minor.yy0->data << "])" << std::endl;
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,3,&yymsp[-1].minor);
}
        break;
      case 166: /* assign_stmt ::= INC lvalue */
{ writeTraceInfo(ps->gen, yymsp[0].minor.yy0); ps->gen << yymsp[0].minor.yy0->data << ".__iadd__(1)" << std::endl; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,59,&yymsp[-1].minor);
}
        break;
      case 167: /* assign_stmt ::= lvalue INC */
{ writeTraceInfo(ps->gen, yymsp[-1].minor.yy0); ps->gen << yymsp[-1].minor.yy0->data << ".__iadd__(1)" << std::endl; delete yymsp[-1].minor.yy0;   yy_destructor(yypParser,59,&yymsp[0].minor);
}
        break;
      case 168: /* assign_stmt ::= DEC lvalue */
{ writeTraceInfo(ps->gen, yymsp[0].minor.yy0); ps->gen << yymsp[0].minor.yy0->data << ".__isub__(1)" << std::endl; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,60,&yymsp[-1].minor);
}
        break;
      case 169: /* assign_stmt ::= lvalue DEC */
{ writeTraceInfo(ps->gen, yymsp[-1].minor.yy0); ps->gen << yymsp[-1].minor.yy0->data << ".__isub__(1)" << std::endl; delete yymsp[-1].minor.yy0;   yy_destructor(yypParser,60,&yymsp[0].minor);
}
        break;
      case 170: /* assign_stmt ::= lvalue IADD expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__iadd__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,61,&yymsp[-1].minor);
}
        break;
      case 171: /* assign_stmt ::= lvalue ISUB expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__isub__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,62,&yymsp[-1].minor);
}
        break;
      case 172: /* assign_stmt ::= lvalue IMUL expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__imul__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,63,&yymsp[-1].minor);
}
        break;
      case 173: /* assign_stmt ::= lvalue IDIV expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__ifloordiv__("  << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,64,&yymsp[-1].minor);
}
        break;
      case 174: /* assign_stmt ::= lvalue IMOD expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__imod__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,65,&yymsp[-1].minor);
}
        break;
      case 175: /* assign_stmt ::= lvalue ILSH expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__ilshift__("    << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,66,&yymsp[-1].minor);
}
        break;
      case 176: /* assign_stmt ::= lvalue IRSH expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__irshift__("    << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,67,&yymsp[-1].minor);
}
        break;
      case 177: /* assign_stmt ::= lvalue IBND expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__iand__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,68,&yymsp[-1].minor);
}
        break;
      case 178: /* assign_stmt ::= lvalue IBOR expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__ior__("        << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,69,&yymsp[-1].minor);
}
        break;
      case 179: /* assign_stmt ::= lvalue IBXR expr */
{ writeTraceInfo(ps->gen, yymsp[-2].minor.yy0); ps->gen << yymsp[-2].minor.yy0->data << ".__ixor__("       << yymsp[0].minor.yy0->data << ")" << std::endl; delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;   yy_destructor(yypParser,70,&yymsp[-1].minor);
}
        break;
      case 180: /* once_start ::= ONCE */
{
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen << yygotominor.yy0->data << " = EUDExecuteOnce()" << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 181: /* once_header ::= once_start LPAREN expr */
{
    writeCsOpener(*pGen, yymsp[-2].minor.yy0, yymsp[0].minor.yy0);
    ps->gen.indent();
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-1].minor);
}
        break;
      case 182: /* once_block ::= once_header RPAREN stmt */
{
  yy_destructor(yypParser,148,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 183: /* once_nocond ::= once_start */
{
    ps->gen << "if " << yymsp[0].minor.yy0->data << "():" << std::endl;
    ps->gen.indent();
    delete yymsp[0].minor.yy0;
}
        break;
      case 184: /* once_block ::= once_nocond stmt */
{
  yy_destructor(yypParser,150,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 185: /* once_stmt ::= once_block */
{
    ps->gen.unindent(false);
    ps->gen << "EUDEndExecuteOnce()" << std::endl;
  yy_destructor(yypParser,149,&yymsp[0].minor);
}
        break;
      case 186: /* if_start ::= IF */
{
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen << yygotominor.yy0->data << " = EUDIf()" << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 187: /* if_header ::= if_start LPAREN expr */
      case 190: /* elif_header ::= elif_start LPAREN expr */ yytestcase(yyruleno==190);
{  // RPAREN is at if_block. see (2)
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    writeCsOpener(*pGen, yymsp[-2].minor.yy0, yymsp[0].minor.yy0);
    ps->gen.indent();
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-1].minor);
}
        break;
      case 188: /* if_block ::= if_header RPAREN stmt */
{
  yy_destructor(yypParser,152,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 189: /* elif_start ::= ELSE IF */
{
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen.unindent(false);
    ps->gen << yygotominor.yy0->data << " = EUDElseIf()" << std::endl;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,2,&yymsp[-1].minor);
}
        break;
      case 191: /* if_block ::= if_block elif_header RPAREN stmt */
{
  yy_destructor(yypParser,153,&yymsp[-3].minor);
  yy_destructor(yypParser,155,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 192: /* else_header ::= ELSE */
{
    ps->gen.unindent(false);
    ps->gen << "if EUDElse()():" << std::endl;
    ps->gen.indent();
  yy_destructor(yypParser,2,&yymsp[0].minor);
}
        break;
      case 193: /* if_stmt ::= if_block */
{
    ps->gen.unindent(false);
    ps->gen << "EUDEndIf()" << std::endl;
  yy_destructor(yypParser,153,&yymsp[0].minor);
}
        break;
      case 194: /* if_stmt ::= if_block else_header stmt */
{
    ps->gen.unindent(false);
    ps->gen << "EUDEndIf()" << std::endl;
  yy_destructor(yypParser,153,&yymsp[-2].minor);
  yy_destructor(yypParser,156,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 195: /* switchcase_header ::= EPDSWITCH LPAREN exprList_nonEmpty */
{ // RPAREN is at switchcase_stmt. see (2)
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    ps->gen << "EPDSwitch(" << yymsp[0].minor.yy0->data << ")" << std::endl;
  yy_destructor(yypParser,73,&yymsp[-2].minor);
  yy_destructor(yypParser,27,&yymsp[-1].minor);
}
        break;
      case 196: /* switchcase_header ::= SWITCHCASE LPAREN exprList_nonEmpty */
{ // RPAREN is at switchcase_stmt. see (2)
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    ps->gen << "EUDSwitch(" << yymsp[0].minor.yy0->data << ")" << std::endl;
  yy_destructor(yypParser,74,&yymsp[-2].minor);
  yy_destructor(yypParser,27,&yymsp[-1].minor);
}
        break;
      case 197: /* case_start ::= CASE */
{
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen << yygotominor.yy0->data << " = EUDSwitchCase()" << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 198: /* case_clause ::= case_start exprList_nonEmpty COLON */
{
    writeTraceInfo(ps->gen, yymsp[-1].minor.yy0);
    writeCsOpener(*pGen, yymsp[-2].minor.yy0, yymsp[-1].minor.yy0);
    ps->gen.indent();
    delete yymsp[-2].minor.yy0; delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,34,&yymsp[0].minor);
}
        break;
      case 199: /* case_chunk ::= case_clause */
{
    ps->gen << "pass" << std::endl;
    ps->gen.unindent(false);
  yy_destructor(yypParser,159,&yymsp[0].minor);
}
        break;
      case 200: /* case_chunk ::= case_clause bodyStmtList */
{
    ps->gen.unindent(false);
  yy_destructor(yypParser,159,&yymsp[-1].minor);
  yy_destructor(yypParser,118,&yymsp[0].minor);
}
        break;
      case 201: /* case_chunks ::= case_chunks case_chunk */
{
  yy_destructor(yypParser,161,&yymsp[-1].minor);
  yy_destructor(yypParser,160,&yymsp[0].minor);
}
        break;
      case 202: /* case_chunks ::= case_chunk */
{
  yy_destructor(yypParser,160,&yymsp[0].minor);
}
        break;
      case 203: /* default_clause ::= DEFAULT COLON */
{
    writeTraceInfo(ps->gen, yymsp[-1].minor.yy0);
    delete yymsp[-1].minor.yy0;

    ps->gen << "if EUDSwitchDefault()():" << std::endl;
    ps->gen.indent();
  yy_destructor(yypParser,34,&yymsp[0].minor);
}
        break;
      case 204: /* default_chunk ::= default_clause */
{
    ps->gen << "pass" << std::endl;
    ps->gen.unindent(false);
  yy_destructor(yypParser,162,&yymsp[0].minor);
}
        break;
      case 205: /* default_chunk ::= default_clause bodyStmtList */
{
    ps->gen.unindent(false);
  yy_destructor(yypParser,162,&yymsp[-1].minor);
  yy_destructor(yypParser,118,&yymsp[0].minor);
}
        break;
      case 206: /* switchcase_block ::= switchcase_header RPAREN LBRACKET case_chunks default_chunk */
{
  yy_destructor(yypParser,157,&yymsp[-4].minor);
  yy_destructor(yypParser,36,&yymsp[-3].minor);
  yy_destructor(yypParser,38,&yymsp[-2].minor);
  yy_destructor(yypParser,161,&yymsp[-1].minor);
  yy_destructor(yypParser,163,&yymsp[0].minor);
}
        break;
      case 207: /* switchcase_block ::= switchcase_header RPAREN LBRACKET case_chunks */
{
  yy_destructor(yypParser,157,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-2].minor);
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yy_destructor(yypParser,161,&yymsp[0].minor);
}
        break;
      case 208: /* switchcase_block ::= switchcase_header RPAREN LBRACKET */
{
  yy_destructor(yypParser,157,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,38,&yymsp[0].minor);
}
        break;
      case 209: /* switchcase_stmt ::= switchcase_block RBRACKET */
{
    ps->gen << "EUDEndSwitch()" << std::endl;
  yy_destructor(yypParser,164,&yymsp[-1].minor);
  yy_destructor(yypParser,41,&yymsp[0].minor);
}
        break;
      case 210: /* while_start ::= WHILE */
{
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen << yygotominor.yy0->data << " = EUDWhile()" << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 211: /* while_header ::= while_start LPAREN expr */
{  // RPAREN is at while_stmt. see (2)
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    writeCsOpener(*pGen, yymsp[-2].minor.yy0, yymsp[0].minor.yy0);
    ps->gen.indent();
    delete yymsp[-2].minor.yy0; delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-1].minor);
}
        break;
      case 212: /* while_stmt ::= while_header RPAREN stmt */
{
    ps->gen.unindent(false);
    ps->gen << "EUDEndWhile()" << std::endl;
  yy_destructor(yypParser,166,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 213: /* for_opener ::= FOR LPAREN */
{
    ps->closure.pushScope();
    delete yymsp[-1].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[0].minor);
}
        break;
      case 214: /* for_init_stmt_nonEmpty ::= vdef_stmt */
{
  yy_destructor(yypParser,119,&yymsp[0].minor);
}
        break;
      case 215: /* for_init_stmt_nonEmpty ::= vdefAssign_stmt */
{
  yy_destructor(yypParser,121,&yymsp[0].minor);
}
        break;
      case 216: /* for_init_stmt_nonEmpty ::= cdef_stmt */
{
  yy_destructor(yypParser,122,&yymsp[0].minor);
}
        break;
      case 217: /* for_init_stmt_nonEmpty ::= assign_stmt */
      case 222: /* for_action_stmt_nonEmpty ::= assign_stmt */ yytestcase(yyruleno==222);
{
  yy_destructor(yypParser,123,&yymsp[0].minor);
}
        break;
      case 218: /* for_init_stmt_nonEmpty ::= for_init_stmt_nonEmpty COMMA for_init_stmt_nonEmpty */
{
  yy_destructor(yypParser,168,&yymsp[-2].minor);
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yy_destructor(yypParser,168,&yymsp[0].minor);
}
        break;
      case 219: /* for_init_stmt ::= for_init_stmt_nonEmpty */
{
  yy_destructor(yypParser,168,&yymsp[0].minor);
}
        break;
      case 221: /* for_action_stmt_nonEmpty ::= funcexprStmt */
{
  yy_destructor(yypParser,124,&yymsp[0].minor);
}
        break;
      case 223: /* for_action_stmt_nonEmpty ::= for_action_stmt_nonEmpty COMMA for_action_stmt_nonEmpty */
{
  yy_destructor(yypParser,170,&yymsp[-2].minor);
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yy_destructor(yypParser,170,&yymsp[0].minor);
}
        break;
      case 225: /* for_action_stmt ::= for_action_stmt_nonEmpty */
{
  yy_destructor(yypParser,170,&yymsp[0].minor);
}
        break;
      case 226: /* for_header1 ::= for_opener for_init_stmt SEMICOLON */
{
    // opening for expr
    yygotominor.yy0 = genTemp(yymsp[0].minor.yy0);
    ps->gen << yygotominor.yy0->data << " = EUDWhile()" << std::endl;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,167,&yymsp[-2].minor);
  yy_destructor(yypParser,169,&yymsp[-1].minor);
}
        break;
      case 227: /* for_header2 ::= for_header1 expr SEMICOLON */
{
    writeTraceInfo(ps->gen, yymsp[-1].minor.yy0);

    writeCsOpener(*pGen, yymsp[-2].minor.yy0, yymsp[-1].minor.yy0);
    ps->gen.indent();
    delete yymsp[-2].minor.yy0;

    // Opening for assign_statement
    yygotominor.yy0 = genTemp(yymsp[-1].minor.yy0);
    delete yymsp[-1].minor.yy0;
    ps->gen << "def " << yygotominor.yy0->data <<"():" << std::endl;
    ps->gen.indent();
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 228: /* for_header ::= for_header2 for_action_stmt */
{  // RPAREN is at for_stmt. see (2)
    yygotominor.yy0 = yymsp[-1].minor.yy0;
    ps->gen.unindent(false);
  yy_destructor(yypParser,171,&yymsp[0].minor);
}
        break;
      case 229: /* for_stmt ::= for_header RPAREN stmt */
{
    ps->gen << "EUDSetContinuePoint()" << std::endl;
    ps->gen << yymsp[-2].minor.yy0->data << "()" << std::endl;
    ps->gen.unindent(false);
    ps->gen << "EUDEndWhile()" << std::endl;
    ps->closure.popScope();
    delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 230: /* foreach_opener ::= FOREACH LPAREN */
{
    ps->closure.pushScope();
  yy_destructor(yypParser,79,&yymsp[-1].minor);
  yy_destructor(yypParser,27,&yymsp[0].minor);
}
        break;
      case 231: /* foreach_header ::= foreach_opener nameList_nonEmpty COLON exprList_nonEmpty */
{  // RPAREN is at foreach_stmt. see (2)
    commaListIter(yymsp[-2].minor.yy0->data, [&](std::string& s) {
        ps->closure.defVariable(s);
    });
    ps->gen << "for " << yymsp[-2].minor.yy0->data << " in " << yymsp[0].minor.yy0->data << ":" << std::endl;
    ps->gen.indent();
    delete yymsp[-2].minor.yy0;
    delete yymsp[0].minor.yy0;
  yy_destructor(yypParser,175,&yymsp[-3].minor);
  yy_destructor(yypParser,34,&yymsp[-1].minor);
}
        break;
      case 232: /* foreach_stmt ::= foreach_header RPAREN stmt */
{
    ps->gen.unindent(true);
    ps->closure.popScope();
  yy_destructor(yypParser,176,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,108,&yymsp[0].minor);
}
        break;
      case 233: /* continue_stmt ::= CONTINUE */
{
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    delete yymsp[0].minor.yy0;

    ps->gen << "EUDContinue()" << std::endl;
}
        break;
      case 234: /* break_stmt ::= BREAK */
{
    writeTraceInfo(ps->gen, yymsp[0].minor.yy0);
    delete yymsp[0].minor.yy0;

    ps->gen << "EUDBreak()" << std::endl;
}
        break;
      case 235: /* return_stmt ::= RETURN exprList */
{
    writeTraceInfo(ps->gen, yymsp[-1].minor.yy0);
    delete yymsp[-1].minor.yy0;

    ps->gen << "EUDReturn(" << yymsp[0].minor.yy0->data << ")" << std::endl;
    delete yymsp[0].minor.yy0;
}
        break;
      case 236: /* expr ::= CONDITIONNAME LPAREN fArgs RPAREN */
      case 237: /* expr ::= KILLS LPAREN fArgs RPAREN */ yytestcase(yyruleno==237);
      case 240: /* expr ::= ACTIONNAME LPAREN fArgs RPAREN */ yytestcase(yyruleno==240);
      case 241: /* expr ::= ACTIONALLPNAME LPAREN fArgs RPAREN */ yytestcase(yyruleno==241);
{
    yymsp[-3].minor.yy0->data = yymsp[-3].minor.yy0->data + "(" + yymsp[-1].minor.yy0->data + ")";
    delete yymsp[-1].minor.yy0;
    yygotominor.yy0 = mkTokenTemp(yymsp[-3].minor.yy0);
  yy_destructor(yypParser,27,&yymsp[-2].minor);
  yy_destructor(yypParser,36,&yymsp[0].minor);
}
        break;
      case 238: /* actionStmt ::= ACTIONNAME LPAREN fArgs RPAREN SEMICOLON */
{
    writeTraceInfo(ps->gen, yymsp[-4].minor.yy0);
    ps->gen << "DoActions(" << yymsp[-4].minor.yy0->data << "(" << yymsp[-2].minor.yy0->data << "))" << std::endl;
    delete yymsp[-4].minor.yy0; delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      case 239: /* actionStmt ::= ACTIONALLPNAME LPAREN fArgs RPAREN SEMICOLON */
{
    writeTraceInfo(ps->gen, yymsp[-4].minor.yy0);
    ps->gen << "_ALL(" << yymsp[-4].minor.yy0->data << "(" << yymsp[-2].minor.yy0->data << "))" << std::endl;
    delete yymsp[-4].minor.yy0; delete yymsp[-2].minor.yy0;
  yy_destructor(yypParser,27,&yymsp[-3].minor);
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yy_destructor(yypParser,30,&yymsp[0].minor);
}
        break;
      default:
      /* (1) chunks ::= */ yytestcase(yyruleno==1);
      /* (107) commaSkippable ::= */ yytestcase(yyruleno==107);
      /* (220) for_init_stmt ::= */ yytestcase(yyruleno==220);
      /* (224) for_action_stmt ::= */ yytestcase(yyruleno==224);
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */

    throw_error(-1, "Unrecoverable error");
  ParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  ParseARG_FETCH;
#define TOKEN (yyminor.yy0)

    throw_error(-2, "General syntax error");
  ParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  ParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void Parse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ParseTOKENTYPE yyminor       /* The value for the token */
  ParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  ParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}


PyGenerator* pGen;
ClosureManager* closure;


std::string ParseString(const std::string& fname, const std::string& code, bool addComment)
{
    // Module name from fname
    // last \/ ~ first .
    auto lpos = fname.find_last_of("\\/");
    if(lpos == std::string::npos) lpos = 0;
    else lpos++;
    auto rpos = fname.find_first_of(".", lpos);
    if(rpos == std::string::npos) rpos = fname.size();
    currentModule = fname.substr(lpos, rpos - lpos);
    currentFile = fname;

#ifndef NDEBUG
    if(PARSER_DEBUG) ParseTrace(stdout, "--");
#endif

    // Main code
    Tokenizer tok(code);
    void* pParser = ParseAlloc (malloc);
    ParserStruct ps;
    Token* token;
    currentTokenizingLine = 0;
    pGen = &ps.gen;
    closure = &ps.closure;
    lambdaIndex = 0;

    if(PARSER_DEBUG) std::cout << "Parsing string [[[\n" << code.c_str() << "\n]]]\n";
    tmpIndex = 1;
    resetParserErrorNum();
    while ((token = tok.getToken()) != nullptr) {
        if (currentTokenizingLine != tok.getCurrentLine()) {
            currentTokenizingLine = tok.getCurrentLine();
            if(addComment) ps.gen << "# (Line " << currentTokenizingLine << ") " << trim(tok.getCurrentLineString()) << std::endl;
            if(PARSER_DEBUG) printf("# reading line %s\n", tok.getCurrentLineString().c_str());
        }
        int newTokType = getConvertedType(token->type);
        if (newTokType != -1) {
            Parse (pParser, newTokType, token, &ps);
        }
        else {
            throw_error(8104, "Invalid token");
        }
    }
    Parse (pParser, 0, nullptr, &ps);
    ParseFree(pParser, free );

    std::string ret = iwCollapse(ps.gen.str());
    if(getParseErrorNum() > 0) {
        ret += "\nraise RuntimeError('Compile error')\n";
    }

#ifndef NDEBUG
    if(PARSER_DEBUG) ParseTrace(NULL, "--");
#endif

    return ret;
}
